note
	description: "[
		Provided access to all the silhouettes to be placed on the
		VITP widgets referenced by the {ATTACK_UNIT}.
	]"
	author: "Jimmy J. Johnson"

deferred class
	SILHOUETTE_CONSTANTS

feature -- Access

	game: VITP_GAME
			-- The game in which this object resides.
			-- Deferred here but defined in {VITP_WIDGET} to which this
			-- class will untimately be combined through inheritance.
		deferred
		end

--	silhouette (a_unit: ATTACK_UNIT): SILHOUETTE
--			-- The silhouette for `a_unit'
--			-- This returns a copy of the picture as produced below, because a picture
--			-- will be placed into many widgets (there is a "Shokaku" widget for each
--			-- view in which the `Shokaku' is to be displayed.
--		do
--			if attached silhouette_table.item (a_unit) as func then
--				Result := func.item
--			else
--				check attached silhouette_table.item (game.Mutsu) as func_2 then
--					-- Run the function obtained from the table
--					Result := func_2.item
--				end
--			end
--		end

	silhouette_coordinates (a_unit: ATTACK_UNIT): ARRAYED_LIST [EV_COORDINATE]
			-- The points that outline the picture of `a_unit' to be
			-- placed on an {ATTACK_UNIT_WIDGET}
		local
			list: ARRAYED_LIST [EV_COORDINATE]
		do
			if attached silhouette_table.item (a_unit) as func then
				list := func.item
			elseif a_unit = game.nagato then
				list := Mutsu_sil
			elseif a_unit = game.fuso then
				list := Mutsu_sil
			elseif a_unit = game.akagi then
				list := Mutsu_sil
			else
				list := default_sil
			end
			Result := list	--.to_array
		end

feature {NONE} -- Implementation

	silhouette_table: HASH_TABLE [FUNCTION [TUPLE, ARRAYED_LIST [EV_COORDINATE]], ATTACK_UNIT]
			-- Holds silhouettes for each attack unit, index by
			-- the name of that unit.
		once
			create Result.make (100)
			Result.extend (agent Shokaku_sil, game.shokaku)
			Result.extend (agent Zuikaku_sil, game.zuikaku)

			Result.extend (agent Mutsu_sil, game.mutsu)

			Result.extend (agent Amphibious_symbol_sil, game.yokosuka)
			Result.extend (agent Amphibious_symbol_sil, game.sasebo)
			Result.extend (agent Amphibious_symbol_sil, game.kure)

			Result.extend (agent Mitsubishi_a6m_zero_sil, game.airflot_21)
			Result.extend (agent Mitsubishi_a6m_zero_sil, game.airflot_22)
			Result.extend (agent Mitsubishi_a6m_zero_sil, game.airflot_23)
			Result.extend (agent Mitsubishi_a6m_zero_sil, game.airflot_24)
			Result.extend (agent Mitsubishi_a6m_zero_sil, game.airflot_25)
			Result.extend (agent Mitsubishi_a6m_zero_sil, game.airflot_26)

			Result.extend (agent Amphibious_symbol_sil, game.marines_1)
			Result.extend (agent Amphibious_symbol_sil, game.marines_2)
			Result.extend (agent Amphibious_symbol_sil, game.marines_3)
			Result.extend (agent Amphibious_symbol_sil, game.marines_4)
			Result.extend (agent Amphibious_symbol_sil, game.marines_5)


			Result.extend (agent Grummen_f4f_wildcat_sil, game.seventh_af)
			Result.extend (agent Grummen_f4f_wildcat_sil, game.fifth_af)
			Result.extend (agent Grummen_f4f_wildcat_sil, game.tenth_af)
			Result.extend (agent Grummen_f4f_wildcat_sil, game.eleventh_af)
			Result.extend (agent Grummen_f4f_wildcat_sil, game.raaf)
			Result.extend (agent Grummen_f4f_wildcat_sil, game.rnzaf)
			Result.extend (agent Grummen_f4f_wildcat_sil, game.marine)
			Result.extend (agent Grummen_f4f_wildcat_sil, game.thirteenth_af)
			Result.extend (agent Grummen_f4f_wildcat_sil, game.fourteenth_af)
			Result.extend (agent Grummen_f4f_wildcat_sil, game.naval)
		end

feature -- 	Japanese units (turn 1, row 1)

	default_sil: ARRAYED_LIST [EV_COORDINATE]
			-- Points decribing a default (i.e. rectangle) silhouette
		once
				-- Can use "once", because the points are copied in
				-- {EV_MODEL_POLYGON}.`make_from_coordintes'
			create Result.make (0)
				-- Points generated by Grabber application
			Result.extend (create {EV_COORDINATE}.make_precise (0, 0))
			Result.extend (create {EV_COORDINATE}.make_precise (1000, 0))
			Result.extend (create {EV_COORDINATE}.make_precise (1000, 400))
			Result.extend (create {EV_COORDINATE}.make_precise (0, 400))
		end

	shokaku_sil: ARRAYED_LIST [EV_COORDINATE]
			-- Points decribing the Shokaku silhouette
		once
				-- Can use "once", because the points are copied in
				-- {EV_MODEL_POLYGON}.`make_from_coordintes'
			create Result.make (0)
				-- Points generated by Grabber application
			Result.extend (create {EV_COORDINATE}.make_precise (0, 0))
			Result.extend (create {EV_COORDINATE}.make_precise (15, 18))
			Result.extend (create {EV_COORDINATE}.make_precise (21, 57))
			Result.extend (create {EV_COORDINATE}.make_precise (1663, 85))
			Result.extend (create {EV_COORDINATE}.make_precise (1665, 65))
			Result.extend (create {EV_COORDINATE}.make_precise (1675, 58))
			Result.extend (create {EV_COORDINATE}.make_precise (1662, 52))
			Result.extend (create {EV_COORDINATE}.make_precise (1647, 48))
			Result.extend (create {EV_COORDINATE}.make_precise (1647, 29))
			Result.extend (create {EV_COORDINATE}.make_precise (1582, 29))
			Result.extend (create {EV_COORDINATE}.make_precise (1582, 20))
			Result.extend (create {EV_COORDINATE}.make_precise (1512, 18))
			Result.extend (create {EV_COORDINATE}.make_precise (1512, 27))
			Result.extend (create {EV_COORDINATE}.make_precise (1493, 27))
			Result.extend (create {EV_COORDINATE}.make_precise (1493, 17))
			Result.extend (create {EV_COORDINATE}.make_precise (1507, 7))
			Result.extend (create {EV_COORDINATE}.make_precise (1515, 5))
			Result.extend (create {EV_COORDINATE}.make_precise (1521, 6))
			Result.extend (create {EV_COORDINATE}.make_precise (1527, 12))
			Result.extend (create {EV_COORDINATE}.make_precise (1528, 18))
			Result.extend (create {EV_COORDINATE}.make_precise (1553, 19))
			Result.extend (create {EV_COORDINATE}.make_precise (1556, 11))
			Result.extend (create {EV_COORDINATE}.make_precise (1568, 5))
			Result.extend (create {EV_COORDINATE}.make_precise (1578, 5))
			Result.extend (create {EV_COORDINATE}.make_precise (1595, 13))
			Result.extend (create {EV_COORDINATE}.make_precise (1598, 27))
			Result.extend (create {EV_COORDINATE}.make_precise (1608, 29))
			Result.extend (create {EV_COORDINATE}.make_precise (1610, 14))
			Result.extend (create {EV_COORDINATE}.make_precise (1627, 3))
			Result.extend (create {EV_COORDINATE}.make_precise (1455, 0))
			Result.extend (create {EV_COORDINATE}.make_precise (1455, -18))
			Result.extend (create {EV_COORDINATE}.make_precise (1437, -18))
			Result.extend (create {EV_COORDINATE}.make_precise (1437, -26))
			Result.extend (create {EV_COORDINATE}.make_precise (1431, -26))
			Result.extend (create {EV_COORDINATE}.make_precise (1430, -19))
			Result.extend (create {EV_COORDINATE}.make_precise (1368, -20))
			Result.extend (create {EV_COORDINATE}.make_precise (1369, -32))
			Result.extend (create {EV_COORDINATE}.make_precise (1348, -33))
			Result.extend (create {EV_COORDINATE}.make_precise (1349, 1))
			Result.extend (create {EV_COORDINATE}.make_precise (1285, 0))
			Result.extend (create {EV_COORDINATE}.make_precise (1280, -14))
			Result.extend (create {EV_COORDINATE}.make_precise (1277, -18))
			Result.extend (create {EV_COORDINATE}.make_precise (1269, -19))
			Result.extend (create {EV_COORDINATE}.make_precise (1270, -31))
			Result.extend (create {EV_COORDINATE}.make_precise (1262, -35))
			Result.extend (create {EV_COORDINATE}.make_precise (1256, -32))
			Result.extend (create {EV_COORDINATE}.make_precise (1257, -4))
			Result.extend (create {EV_COORDINATE}.make_precise (1207, -1))
			Result.extend (create {EV_COORDINATE}.make_precise (1200, 2))
			Result.extend (create {EV_COORDINATE}.make_precise (1183, 0))
			Result.extend (create {EV_COORDINATE}.make_precise (1181, -13))
			Result.extend (create {EV_COORDINATE}.make_precise (1172, -13))
			Result.extend (create {EV_COORDINATE}.make_precise (1166, -3))
			Result.extend (create {EV_COORDINATE}.make_precise (1148, -5))
			Result.extend (create {EV_COORDINATE}.make_precise (1148, -16))
			Result.extend (create {EV_COORDINATE}.make_precise (1137, -17))
			Result.extend (create {EV_COORDINATE}.make_precise (1128, -4))
			Result.extend (create {EV_COORDINATE}.make_precise (1088, -4))
			Result.extend (create {EV_COORDINATE}.make_precise (1064, -12))
			Result.extend (create {EV_COORDINATE}.make_precise (1060, -18))
			Result.extend (create {EV_COORDINATE}.make_precise (1060, -31))
			Result.extend (create {EV_COORDINATE}.make_precise (1061, -36))
			Result.extend (create {EV_COORDINATE}.make_precise (1054, -36))
			Result.extend (create {EV_COORDINATE}.make_precise (1053, -17))
			Result.extend (create {EV_COORDINATE}.make_precise (641, -20))
			Result.extend (create {EV_COORDINATE}.make_precise (639, -35))
			Result.extend (create {EV_COORDINATE}.make_precise (636, -40))
			Result.extend (create {EV_COORDINATE}.make_precise (636, -60))
			Result.extend (create {EV_COORDINATE}.make_precise (632, -62))
			Result.extend (create {EV_COORDINATE}.make_precise (626, -64))
			Result.extend (create {EV_COORDINATE}.make_precise (625, -29))
			Result.extend (create {EV_COORDINATE}.make_precise (618, -29))
			Result.extend (create {EV_COORDINATE}.make_precise (617, -34))
			Result.extend (create {EV_COORDINATE}.make_precise (612, -35))
			Result.extend (create {EV_COORDINATE}.make_precise (612, -57))
			Result.extend (create {EV_COORDINATE}.make_precise (606, -65))
			Result.extend (create {EV_COORDINATE}.make_precise (601, -71))
			Result.extend (create {EV_COORDINATE}.make_precise (601, -83))
			Result.extend (create {EV_COORDINATE}.make_precise (596, -87))
			Result.extend (create {EV_COORDINATE}.make_precise (590, -93))
			Result.extend (create {EV_COORDINATE}.make_precise (584, -93))
			Result.extend (create {EV_COORDINATE}.make_precise (584, -81))
			Result.extend (create {EV_COORDINATE}.make_precise (576, -82))
			Result.extend (create {EV_COORDINATE}.make_precise (578, -67))
			Result.extend (create {EV_COORDINATE}.make_precise (541, -66))
			Result.extend (create {EV_COORDINATE}.make_precise (542, -52))
			Result.extend (create {EV_COORDINATE}.make_precise (531, -52))
			Result.extend (create {EV_COORDINATE}.make_precise (531, -36))
			Result.extend (create {EV_COORDINATE}.make_precise (512, -35))
			Result.extend (create {EV_COORDINATE}.make_precise (512, -17))
			Result.extend (create {EV_COORDINATE}.make_precise (428, -21))
			Result.extend (create {EV_COORDINATE}.make_precise (428, -28))
			Result.extend (create {EV_COORDINATE}.make_precise (421, -33))
			Result.extend (create {EV_COORDINATE}.make_precise (418, -28))
			Result.extend (create {EV_COORDINATE}.make_precise (418, -20))
			Result.extend (create {EV_COORDINATE}.make_precise (318, -20))
			Result.extend (create {EV_COORDINATE}.make_precise (315, -32))
			Result.extend (create {EV_COORDINATE}.make_precise (306, -33))
			Result.extend (create {EV_COORDINATE}.make_precise (302, -22))
			Result.extend (create {EV_COORDINATE}.make_precise (270, -18))
			Result.extend (create {EV_COORDINATE}.make_precise (267, -24))
			Result.extend (create {EV_COORDINATE}.make_precise (183, -27))
			Result.extend (create {EV_COORDINATE}.make_precise (179, -32))
			Result.extend (create {EV_COORDINATE}.make_precise (68, -32))
			Result.extend (create {EV_COORDINATE}.make_precise (66, -23))
			Result.extend (create {EV_COORDINATE}.make_precise (162, -18))
			Result.extend (create {EV_COORDINATE}.make_precise (171, -12))
			Result.extend (create {EV_COORDINATE}.make_precise (168, 0))
			Result.extend (create {EV_COORDINATE}.make_precise (131, -3))
			Result.extend (create {EV_COORDINATE}.make_precise (131, -17))
			Result.extend (create {EV_COORDINATE}.make_precise (112, -19))
			Result.extend (create {EV_COORDINATE}.make_precise (112, 0))
			Result.extend (create {EV_COORDINATE}.make_precise (82, -2))
			Result.extend (create {EV_COORDINATE}.make_precise (82, -18))
			Result.extend (create {EV_COORDINATE}.make_precise (70, -19))
			Result.extend (create {EV_COORDINATE}.make_precise (69, 0))
			Result.extend (create {EV_COORDINATE}.make_precise (17, 3))
		end

	Zuikaku_sil: ARRAYED_LIST [EV_COORDINATE]
			-- Points decribing the Zuikaku silhouette
		once
			create Result.make (0)
				-- Points generated by Grabber application
			Result.extend (create {EV_COORDINATE}.make_precise (0, 0))
			Result.extend (create {EV_COORDINATE}.make_precise (12, 10))
			Result.extend (create {EV_COORDINATE}.make_precise (17, 48))
			Result.extend (create {EV_COORDINATE}.make_precise (1443, 110))
			Result.extend (create {EV_COORDINATE}.make_precise (1458, 82))
			Result.extend (create {EV_COORDINATE}.make_precise (1444, 82))
			Result.extend (create {EV_COORDINATE}.make_precise (1437, 74))
			Result.extend (create {EV_COORDINATE}.make_precise (1437, 61))
			Result.extend (create {EV_COORDINATE}.make_precise (1440, 57))
			Result.extend (create {EV_COORDINATE}.make_precise (1436, 53))
			Result.extend (create {EV_COORDINATE}.make_precise (1432, 61))
			Result.extend (create {EV_COORDINATE}.make_precise (1403, 63))
			Result.extend (create {EV_COORDINATE}.make_precise (1395, 59))
			Result.extend (create {EV_COORDINATE}.make_precise (1383, 59))
			Result.extend (create {EV_COORDINATE}.make_precise (1381, 53))
			Result.extend (create {EV_COORDINATE}.make_precise (1370, 46))
			Result.extend (create {EV_COORDINATE}.make_precise (1328, 45))
			Result.extend (create {EV_COORDINATE}.make_precise (1317, 58))
			Result.extend (create {EV_COORDINATE}.make_precise (1304, 57))
			Result.extend (create {EV_COORDINATE}.make_precise (1306, 42))
			Result.extend (create {EV_COORDINATE}.make_precise (1312, 35))
			Result.extend (create {EV_COORDINATE}.make_precise (1327, 35))
			Result.extend (create {EV_COORDINATE}.make_precise (1337, 42))
			Result.extend (create {EV_COORDINATE}.make_precise (1337, 51))
			Result.extend (create {EV_COORDINATE}.make_precise (1350, 50))
			Result.extend (create {EV_COORDINATE}.make_precise (1352, 40))
			Result.extend (create {EV_COORDINATE}.make_precise (1385, 40))
			Result.extend (create {EV_COORDINATE}.make_precise (1395, 47))
			Result.extend (create {EV_COORDINATE}.make_precise (1396, 67))
			Result.extend (create {EV_COORDINATE}.make_precise (1403, 70))
			Result.extend (create {EV_COORDINATE}.make_precise (1404, 46))
			Result.extend (create {EV_COORDINATE}.make_precise (1408, 42))
			Result.extend (create {EV_COORDINATE}.make_precise (1423, 41))
			Result.extend (create {EV_COORDINATE}.make_precise (1424, 36))
			Result.extend (create {EV_COORDINATE}.make_precise (1272, 31))
			Result.extend (create {EV_COORDINATE}.make_precise (1264, 22))
			Result.extend (create {EV_COORDINATE}.make_precise (1265, 15))
			Result.extend (create {EV_COORDINATE}.make_precise (1254, 15))
			Result.extend (create {EV_COORDINATE}.make_precise (1255, 7))
			Result.extend (create {EV_COORDINATE}.make_precise (1250, 2))
			Result.extend (create {EV_COORDINATE}.make_precise (1242, -2))
			Result.extend (create {EV_COORDINATE}.make_precise (1237, -2))
			Result.extend (create {EV_COORDINATE}.make_precise (1233, 1))
			Result.extend (create {EV_COORDINATE}.make_precise (1240, 4))
			Result.extend (create {EV_COORDINATE}.make_precise (1249, 15))
			Result.extend (create {EV_COORDINATE}.make_precise (1194, 16))
			Result.extend (create {EV_COORDINATE}.make_precise (1193, 4))
			Result.extend (create {EV_COORDINATE}.make_precise (1183, 5))
			Result.extend (create {EV_COORDINATE}.make_precise (1183, -1))
			Result.extend (create {EV_COORDINATE}.make_precise (1174, -1))
			Result.extend (create {EV_COORDINATE}.make_precise (1178, 23))
			Result.extend (create {EV_COORDINATE}.make_precise (1170, 32))
			Result.extend (create {EV_COORDINATE}.make_precise (1140, 33))
			Result.extend (create {EV_COORDINATE}.make_precise (1139, 26))
			Result.extend (create {EV_COORDINATE}.make_precise (1115, 25))
			Result.extend (create {EV_COORDINATE}.make_precise (1114, 14))
			Result.extend (create {EV_COORDINATE}.make_precise (1107, 14))
			Result.extend (create {EV_COORDINATE}.make_precise (1109, 4))
			Result.extend (create {EV_COORDINATE}.make_precise (1106, -1))
			Result.extend (create {EV_COORDINATE}.make_precise (1090, -1))
			Result.extend (create {EV_COORDINATE}.make_precise (1098, 2))
			Result.extend (create {EV_COORDINATE}.make_precise (1102, 11))
			Result.extend (create {EV_COORDINATE}.make_precise (1096, 18))
			Result.extend (create {EV_COORDINATE}.make_precise (1087, 25))
			Result.extend (create {EV_COORDINATE}.make_precise (1032, 24))
			Result.extend (create {EV_COORDINATE}.make_precise (1032, 16))
			Result.extend (create {EV_COORDINATE}.make_precise (932, 14))
			Result.extend (create {EV_COORDINATE}.make_precise (930, -11))
			Result.extend (create {EV_COORDINATE}.make_precise (921, -12))
			Result.extend (create {EV_COORDINATE}.make_precise (917, -10))
			Result.extend (create {EV_COORDINATE}.make_precise (916, -5))
			Result.extend (create {EV_COORDINATE}.make_precise (921, 0))
			Result.extend (create {EV_COORDINATE}.make_precise (922, 14))
			Result.extend (create {EV_COORDINATE}.make_precise (863, 17))
			Result.extend (create {EV_COORDINATE}.make_precise (861, 9))
			Result.extend (create {EV_COORDINATE}.make_precise (562, 2))
			Result.extend (create {EV_COORDINATE}.make_precise (560, -16))
			Result.extend (create {EV_COORDINATE}.make_precise (555, -17))
			Result.extend (create {EV_COORDINATE}.make_precise (555, -22))
			Result.extend (create {EV_COORDINATE}.make_precise (561, -22))
			Result.extend (create {EV_COORDINATE}.make_precise (560, -30))
			Result.extend (create {EV_COORDINATE}.make_precise (554, -30))
			Result.extend (create {EV_COORDINATE}.make_precise (553, -36))
			Result.extend (create {EV_COORDINATE}.make_precise (548, -30))
			Result.extend (create {EV_COORDINATE}.make_precise (549, -13))
			Result.extend (create {EV_COORDINATE}.make_precise (540, -13))
			Result.extend (create {EV_COORDINATE}.make_precise (539, -19))
			Result.extend (create {EV_COORDINATE}.make_precise (532, -19))
			Result.extend (create {EV_COORDINATE}.make_precise (534, -39))
			Result.extend (create {EV_COORDINATE}.make_precise (525, -41))
			Result.extend (create {EV_COORDINATE}.make_precise (526, -53))
			Result.extend (create {EV_COORDINATE}.make_precise (531, -49))
			Result.extend (create {EV_COORDINATE}.make_precise (526, -65))
			Result.extend (create {EV_COORDINATE}.make_precise (511, -66))
			Result.extend (create {EV_COORDINATE}.make_precise (511, -51))
			Result.extend (create {EV_COORDINATE}.make_precise (471, -51))
			Result.extend (create {EV_COORDINATE}.make_precise (471, -31))
			Result.extend (create {EV_COORDINATE}.make_precise (466, -30))
			Result.extend (create {EV_COORDINATE}.make_precise (466, -23))
			Result.extend (create {EV_COORDINATE}.make_precise (459, -24))
			Result.extend (create {EV_COORDINATE}.make_precise (454, -19))
			Result.extend (create {EV_COORDINATE}.make_precise (451, -14))
			Result.extend (create {EV_COORDINATE}.make_precise (450, -3))
			Result.extend (create {EV_COORDINATE}.make_precise (388, -5))
			Result.extend (create {EV_COORDINATE}.make_precise (381, -10))
			Result.extend (create {EV_COORDINATE}.make_precise (380, -15))
			Result.extend (create {EV_COORDINATE}.make_precise (361, -15))
			Result.extend (create {EV_COORDINATE}.make_precise (358, -9))
			Result.extend (create {EV_COORDINATE}.make_precise (309, -10))
			Result.extend (create {EV_COORDINATE}.make_precise (304, -14))
			Result.extend (create {EV_COORDINATE}.make_precise (278, -16))
			Result.extend (create {EV_COORDINATE}.make_precise (275, -20))
			Result.extend (create {EV_COORDINATE}.make_precise (272, -13))
			Result.extend (create {EV_COORDINATE}.make_precise (173, -14))
			Result.extend (create {EV_COORDINATE}.make_precise (155, -20))
			Result.extend (create {EV_COORDINATE}.make_precise (153, -24))
			Result.extend (create {EV_COORDINATE}.make_precise (60, -25))
			Result.extend (create {EV_COORDINATE}.make_precise (59, -19))
			Result.extend (create {EV_COORDINATE}.make_precise (81, -16))
			Result.extend (create {EV_COORDINATE}.make_precise (87, -21))
			Result.extend (create {EV_COORDINATE}.make_precise (104, -15))
			Result.extend (create {EV_COORDINATE}.make_precise (115, -14))
			Result.extend (create {EV_COORDINATE}.make_precise (128, -19))
			Result.extend (create {EV_COORDINATE}.make_precise (148, -16))
			Result.extend (create {EV_COORDINATE}.make_precise (149, 0))
			Result.extend (create {EV_COORDINATE}.make_precise (116, -1))
			Result.extend (create {EV_COORDINATE}.make_precise (116, -20))
			Result.extend (create {EV_COORDINATE}.make_precise (107, -19))
			Result.extend (create {EV_COORDINATE}.make_precise (107, 0))
			Result.extend (create {EV_COORDINATE}.make_precise (101, 4))
			Result.extend (create {EV_COORDINATE}.make_precise (85, 4))
			Result.extend (create {EV_COORDINATE}.make_precise (82, 0))
			Result.extend (create {EV_COORDINATE}.make_precise (74, 0))
			Result.extend (create {EV_COORDINATE}.make_precise (76, -19))
			Result.extend (create {EV_COORDINATE}.make_precise (66, -19))
			Result.extend (create {EV_COORDINATE}.make_precise (66, 1))
		end


	Mutsu_sil: ARRAYED_LIST [EV_COORDINATE]
			-- Points decribing the Mutsu silhouette
		once
			create Result.make (0)
				-- Points generated by Grabber application
			Result.extend (create {EV_COORDINATE}.make_precise (0, 0))
			Result.extend (create {EV_COORDINATE}.make_precise (22, 39))
			Result.extend (create {EV_COORDINATE}.make_precise (36, 64))
			Result.extend (create {EV_COORDINATE}.make_precise (46, 79))
			Result.extend (create {EV_COORDINATE}.make_precise (1951, 77))
			Result.extend (create {EV_COORDINATE}.make_precise (1950, 64))
			Result.extend (create {EV_COORDINATE}.make_precise (1946, 28))
			Result.extend (create {EV_COORDINATE}.make_precise (1943, 24))
			Result.extend (create {EV_COORDINATE}.make_precise (1943, 18))
			Result.extend (create {EV_COORDINATE}.make_precise (1930, 18))
			Result.extend (create {EV_COORDINATE}.make_precise (1935, -28))
			Result.extend (create {EV_COORDINATE}.make_precise (1978, -26))
			Result.extend (create {EV_COORDINATE}.make_precise (1981, -52))
			Result.extend (create {EV_COORDINATE}.make_precise (1938, -59))
			Result.extend (create {EV_COORDINATE}.make_precise (1924, 15))
			Result.extend (create {EV_COORDINATE}.make_precise (1593, 25))
			Result.extend (create {EV_COORDINATE}.make_precise (1594, 10))
			Result.extend (create {EV_COORDINATE}.make_precise (1689, -2))
			Result.extend (create {EV_COORDINATE}.make_precise (1689, -8))
			Result.extend (create {EV_COORDINATE}.make_precise (1587, -1))
			Result.extend (create {EV_COORDINATE}.make_precise (1581, -6))
			Result.extend (create {EV_COORDINATE}.make_precise (1570, -9))
			Result.extend (create {EV_COORDINATE}.make_precise (1556, -10))
			Result.extend (create {EV_COORDINATE}.make_precise (1501, -12))
			Result.extend (create {EV_COORDINATE}.make_precise (1502, -17))
			Result.extend (create {EV_COORDINATE}.make_precise (1487, -16))
			Result.extend (create {EV_COORDINATE}.make_precise (1485, -10))
			Result.extend (create {EV_COORDINATE}.make_precise (1477, -10))
			Result.extend (create {EV_COORDINATE}.make_precise (1476, 15))
			Result.extend (create {EV_COORDINATE}.make_precise (1498, 15))
			Result.extend (create {EV_COORDINATE}.make_precise (1495, 26))
			Result.extend (create {EV_COORDINATE}.make_precise (1463, 22))
			Result.extend (create {EV_COORDINATE}.make_precise (1465, -18))
			Result.extend (create {EV_COORDINATE}.make_precise (1559, -31))
			Result.extend (create {EV_COORDINATE}.make_precise (1558, -39))
			Result.extend (create {EV_COORDINATE}.make_precise (1465, -32))
			Result.extend (create {EV_COORDINATE}.make_precise (1466, -53))
			Result.extend (create {EV_COORDINATE}.make_precise (1462, -87))
			Result.extend (create {EV_COORDINATE}.make_precise (1458, -55))
			Result.extend (create {EV_COORDINATE}.make_precise (1354, -107))
			Result.extend (create {EV_COORDINATE}.make_precise (1456, -49))
			Result.extend (create {EV_COORDINATE}.make_precise (1455, -31))
			Result.extend (create {EV_COORDINATE}.make_precise (1448, -35))
			Result.extend (create {EV_COORDINATE}.make_precise (1428, -40))
			Result.extend (create {EV_COORDINATE}.make_precise (1391, -37))
			Result.extend (create {EV_COORDINATE}.make_precise (1391, -51))
			Result.extend (create {EV_COORDINATE}.make_precise (1381, -51))
			Result.extend (create {EV_COORDINATE}.make_precise (1381, -43))
			Result.extend (create {EV_COORDINATE}.make_precise (1358, -42))
			Result.extend (create {EV_COORDINATE}.make_precise (1359, -36))
			Result.extend (create {EV_COORDINATE}.make_precise (1349, -42))
			Result.extend (create {EV_COORDINATE}.make_precise (1345, -16))
			Result.extend (create {EV_COORDINATE}.make_precise (1366, -13))
			Result.extend (create {EV_COORDINATE}.make_precise (1366, -7))
			Result.extend (create {EV_COORDINATE}.make_precise (1343, -8))
			Result.extend (create {EV_COORDINATE}.make_precise (1340, -2))
			Result.extend (create {EV_COORDINATE}.make_precise (1216, 2))
			Result.extend (create {EV_COORDINATE}.make_precise (1216, -7))
			Result.extend (create {EV_COORDINATE}.make_precise (1198, -7))
			Result.extend (create {EV_COORDINATE}.make_precise (1190, 1))
			Result.extend (create {EV_COORDINATE}.make_precise (1189, -68))
			Result.extend (create {EV_COORDINATE}.make_precise (1184, -72))
			Result.extend (create {EV_COORDINATE}.make_precise (1188, -83))
			Result.extend (create {EV_COORDINATE}.make_precise (1201, -83))
			Result.extend (create {EV_COORDINATE}.make_precise (1202, -92))
			Result.extend (create {EV_COORDINATE}.make_precise (1208, -104))
			Result.extend (create {EV_COORDINATE}.make_precise (1212, -113))
			Result.extend (create {EV_COORDINATE}.make_precise (1200, -113))
			Result.extend (create {EV_COORDINATE}.make_precise (1204, -139))
			Result.extend (create {EV_COORDINATE}.make_precise (1180, -140))
			Result.extend (create {EV_COORDINATE}.make_precise (1179, -117))
			Result.extend (create {EV_COORDINATE}.make_precise (1172, -116))
			Result.extend (create {EV_COORDINATE}.make_precise (1163, -120))
			Result.extend (create {EV_COORDINATE}.make_precise (1152, -157))
			Result.extend (create {EV_COORDINATE}.make_precise (1151, -191))
			Result.extend (create {EV_COORDINATE}.make_precise (1189, -191))
			Result.extend (create {EV_COORDINATE}.make_precise (1190, -197))
			Result.extend (create {EV_COORDINATE}.make_precise (1152, -200))
			Result.extend (create {EV_COORDINATE}.make_precise (1152, -284))
			Result.extend (create {EV_COORDINATE}.make_precise (1152, -346))
			Result.extend (create {EV_COORDINATE}.make_precise (1145, -346))
			Result.extend (create {EV_COORDINATE}.make_precise (1142, -218))
			Result.extend (create {EV_COORDINATE}.make_precise (1126, -219))
			Result.extend (create {EV_COORDINATE}.make_precise (1126, -211))
			Result.extend (create {EV_COORDINATE}.make_precise (1131, -208))
			Result.extend (create {EV_COORDINATE}.make_precise (1132, -197))
			Result.extend (create {EV_COORDINATE}.make_precise (1125, -197))
			Result.extend (create {EV_COORDINATE}.make_precise (1124, -191))
			Result.extend (create {EV_COORDINATE}.make_precise (1130, -187))
			Result.extend (create {EV_COORDINATE}.make_precise (1129, -47))
			Result.extend (create {EV_COORDINATE}.make_precise (1110, -48))
			Result.extend (create {EV_COORDINATE}.make_precise (1110, -57))
			Result.extend (create {EV_COORDINATE}.make_precise (1070, -59))
			Result.extend (create {EV_COORDINATE}.make_precise (1071, -50))
			Result.extend (create {EV_COORDINATE}.make_precise (1065, -50))
			Result.extend (create {EV_COORDINATE}.make_precise (1062, -54))
			Result.extend (create {EV_COORDINATE}.make_precise (1056, -54))
			Result.extend (create {EV_COORDINATE}.make_precise (1054, -50))
			Result.extend (create {EV_COORDINATE}.make_precise (1028, -51))
			Result.extend (create {EV_COORDINATE}.make_precise (1036, -36))
			Result.extend (create {EV_COORDINATE}.make_precise (1020, -37))
			Result.extend (create {EV_COORDINATE}.make_precise (1020, -83))
			Result.extend (create {EV_COORDINATE}.make_precise (1027, -85))
			Result.extend (create {EV_COORDINATE}.make_precise (1029, -99))
			Result.extend (create {EV_COORDINATE}.make_precise (1022, -99))
			Result.extend (create {EV_COORDINATE}.make_precise (1021, -94))
			Result.extend (create {EV_COORDINATE}.make_precise (1016, -94))
			Result.extend (create {EV_COORDINATE}.make_precise (1019, -103))
			Result.extend (create {EV_COORDINATE}.make_precise (1003, -103))
			Result.extend (create {EV_COORDINATE}.make_precise (1003, -150))
			Result.extend (create {EV_COORDINATE}.make_precise (994, -157))
			Result.extend (create {EV_COORDINATE}.make_precise (961, -158))
			Result.extend (create {EV_COORDINATE}.make_precise (944, -148))
			Result.extend (create {EV_COORDINATE}.make_precise (948, -136))
			Result.extend (create {EV_COORDINATE}.make_precise (942, -131))
			Result.extend (create {EV_COORDINATE}.make_precise (942, -109))
			Result.extend (create {EV_COORDINATE}.make_precise (935, -114))
			Result.extend (create {EV_COORDINATE}.make_precise (927, -108))
			Result.extend (create {EV_COORDINATE}.make_precise (929, -100))
			Result.extend (create {EV_COORDINATE}.make_precise (919, -98))
			Result.extend (create {EV_COORDINATE}.make_precise (925, -88))
			Result.extend (create {EV_COORDINATE}.make_precise (924, -81))
			Result.extend (create {EV_COORDINATE}.make_precise (912, -82))
			Result.extend (create {EV_COORDINATE}.make_precise (913, -90))
			Result.extend (create {EV_COORDINATE}.make_precise (904, -97))
			Result.extend (create {EV_COORDINATE}.make_precise (895, -91))
			Result.extend (create {EV_COORDINATE}.make_precise (899, -82))
			Result.extend (create {EV_COORDINATE}.make_precise (895, -73))
			Result.extend (create {EV_COORDINATE}.make_precise (905, -68))
			Result.extend (create {EV_COORDINATE}.make_precise (904, -43))
			Result.extend (create {EV_COORDINATE}.make_precise (893, -42))
			Result.extend (create {EV_COORDINATE}.make_precise (892, -35))
			Result.extend (create {EV_COORDINATE}.make_precise (867, -34))
			Result.extend (create {EV_COORDINATE}.make_precise (858, -45))
			Result.extend (create {EV_COORDINATE}.make_precise (856, -64))
			Result.extend (create {EV_COORDINATE}.make_precise (839, -64))
			Result.extend (create {EV_COORDINATE}.make_precise (839, -54))
			Result.extend (create {EV_COORDINATE}.make_precise (808, -54))
			Result.extend (create {EV_COORDINATE}.make_precise (809, -69))
			Result.extend (create {EV_COORDINATE}.make_precise (803, -68))
			Result.extend (create {EV_COORDINATE}.make_precise (805, -86))
			Result.extend (create {EV_COORDINATE}.make_precise (810, -88))
			Result.extend (create {EV_COORDINATE}.make_precise (805, -95))
			Result.extend (create {EV_COORDINATE}.make_precise (789, -95))
			Result.extend (create {EV_COORDINATE}.make_precise (785, -93))
			Result.extend (create {EV_COORDINATE}.make_precise (780, -94))
			Result.extend (create {EV_COORDINATE}.make_precise (782, -100))
			Result.extend (create {EV_COORDINATE}.make_precise (771, -101))
			Result.extend (create {EV_COORDINATE}.make_precise (772, -107))
			Result.extend (create {EV_COORDINATE}.make_precise (754, -107))
			Result.extend (create {EV_COORDINATE}.make_precise (748, -126))
			Result.extend (create {EV_COORDINATE}.make_precise (761, -126))
			Result.extend (create {EV_COORDINATE}.make_precise (758, -134))
			Result.extend (create {EV_COORDINATE}.make_precise (758, -183))
			Result.extend (create {EV_COORDINATE}.make_precise (752, -191))
			Result.extend (create {EV_COORDINATE}.make_precise (745, -192))
			Result.extend (create {EV_COORDINATE}.make_precise (744, -198))
			Result.extend (create {EV_COORDINATE}.make_precise (757, -200))
			Result.extend (create {EV_COORDINATE}.make_precise (788, -203))
			Result.extend (create {EV_COORDINATE}.make_precise (799, -206))
			Result.extend (create {EV_COORDINATE}.make_precise (801, -212))
			Result.extend (create {EV_COORDINATE}.make_precise (758, -214))
			Result.extend (create {EV_COORDINATE}.make_precise (753, -219))
			Result.extend (create {EV_COORDINATE}.make_precise (736, -219))
			Result.extend (create {EV_COORDINATE}.make_precise (735, -228))
			Result.extend (create {EV_COORDINATE}.make_precise (757, -236))
			Result.extend (create {EV_COORDINATE}.make_precise (758, -247))
			Result.extend (create {EV_COORDINATE}.make_precise (751, -247))
			Result.extend (create {EV_COORDINATE}.make_precise (753, -253))
			Result.extend (create {EV_COORDINATE}.make_precise (754, -267))
			Result.extend (create {EV_COORDINATE}.make_precise (742, -268))
			Result.extend (create {EV_COORDINATE}.make_precise (740, -261))
			Result.extend (create {EV_COORDINATE}.make_precise (733, -261))
			Result.extend (create {EV_COORDINATE}.make_precise (735, -281))
			Result.extend (create {EV_COORDINATE}.make_precise (705, -282))
			Result.extend (create {EV_COORDINATE}.make_precise (705, -271))
			Result.extend (create {EV_COORDINATE}.make_precise (688, -270))
			Result.extend (create {EV_COORDINATE}.make_precise (688, -260))
			Result.extend (create {EV_COORDINATE}.make_precise (676, -260))
			Result.extend (create {EV_COORDINATE}.make_precise (676, -255))
			Result.extend (create {EV_COORDINATE}.make_precise (684, -253))
			Result.extend (create {EV_COORDINATE}.make_precise (682, -249))
			Result.extend (create {EV_COORDINATE}.make_precise (674, -251))
			Result.extend (create {EV_COORDINATE}.make_precise (672, -245))
			Result.extend (create {EV_COORDINATE}.make_precise (680, -235))
			Result.extend (create {EV_COORDINATE}.make_precise (683, -222))
			Result.extend (create {EV_COORDINATE}.make_precise (656, -220))
			Result.extend (create {EV_COORDINATE}.make_precise (655, -211))
			Result.extend (create {EV_COORDINATE}.make_precise (660, -192))
			Result.extend (create {EV_COORDINATE}.make_precise (659, -149))
			Result.extend (create {EV_COORDINATE}.make_precise (653, -142))
			Result.extend (create {EV_COORDINATE}.make_precise (646, -138))
			Result.extend (create {EV_COORDINATE}.make_precise (647, -118))
			Result.extend (create {EV_COORDINATE}.make_precise (632, -119))
			Result.extend (create {EV_COORDINATE}.make_precise (630, -75))
			Result.extend (create {EV_COORDINATE}.make_precise (645, -71))
			Result.extend (create {EV_COORDINATE}.make_precise (645, -52))
			Result.extend (create {EV_COORDINATE}.make_precise (643, -20))
			Result.extend (create {EV_COORDINATE}.make_precise (614, -20))
			Result.extend (create {EV_COORDINATE}.make_precise (617, -34))
			Result.extend (create {EV_COORDINATE}.make_precise (636, -36))
			Result.extend (create {EV_COORDINATE}.make_precise (635, -59))
			Result.extend (create {EV_COORDINATE}.make_precise (624, -58))
			Result.extend (create {EV_COORDINATE}.make_precise (624, -68))
			Result.extend (create {EV_COORDINATE}.make_precise (622, -75))
			Result.extend (create {EV_COORDINATE}.make_precise (615, -76))
			Result.extend (create {EV_COORDINATE}.make_precise (615, -70))
			Result.extend (create {EV_COORDINATE}.make_precise (602, -72))
			Result.extend (create {EV_COORDINATE}.make_precise (593, -75))
			Result.extend (create {EV_COORDINATE}.make_precise (593, -63))
			Result.extend (create {EV_COORDINATE}.make_precise (568, -60))
			Result.extend (create {EV_COORDINATE}.make_precise (552, -63))
			Result.extend (create {EV_COORDINATE}.make_precise (536, -55))
			Result.extend (create {EV_COORDINATE}.make_precise (503, -56))
			Result.extend (create {EV_COORDINATE}.make_precise (501, -53))
			Result.extend (create {EV_COORDINATE}.make_precise (424, -61))
			Result.extend (create {EV_COORDINATE}.make_precise (424, -55))
			Result.extend (create {EV_COORDINATE}.make_precise (499, -43))
			Result.extend (create {EV_COORDINATE}.make_precise (508, -42))
			Result.extend (create {EV_COORDINATE}.make_precise (516, -40))
			Result.extend (create {EV_COORDINATE}.make_precise (520, -31))
			Result.extend (create {EV_COORDINATE}.make_precise (519, 4))
			Result.extend (create {EV_COORDINATE}.make_precise (490, 3))
			Result.extend (create {EV_COORDINATE}.make_precise (490, -3))
			Result.extend (create {EV_COORDINATE}.make_precise (507, -5))
			Result.extend (create {EV_COORDINATE}.make_precise (509, -27))
			Result.extend (create {EV_COORDINATE}.make_precise (499, -28))
			Result.extend (create {EV_COORDINATE}.make_precise (499, -35))
			Result.extend (create {EV_COORDINATE}.make_precise (495, -40))
			Result.extend (create {EV_COORDINATE}.make_precise (486, -40))
			Result.extend (create {EV_COORDINATE}.make_precise (484, -28))
			Result.extend (create {EV_COORDINATE}.make_precise (419, -28))
			Result.extend (create {EV_COORDINATE}.make_precise (404, -21))
			Result.extend (create {EV_COORDINATE}.make_precise (297, -35))
			Result.extend (create {EV_COORDINATE}.make_precise (297, -27))
			Result.extend (create {EV_COORDINATE}.make_precise (391, -8))
			Result.extend (create {EV_COORDINATE}.make_precise (391, 3))
			Result.extend (create {EV_COORDINATE}.make_precise (331, 1))
			Result.extend (create {EV_COORDINATE}.make_precise (327, -7))
			Result.extend (create {EV_COORDINATE}.make_precise (317, -8))
			Result.extend (create {EV_COORDINATE}.make_precise (310, 0))
			Result.extend (create {EV_COORDINATE}.make_precise (273, 0))
			Result.extend (create {EV_COORDINATE}.make_precise (272, -12))
			Result.extend (create {EV_COORDINATE}.make_precise (257, -13))
			Result.extend (create {EV_COORDINATE}.make_precise (254, -9))
			Result.extend (create {EV_COORDINATE}.make_precise (244, -11))
			Result.extend (create {EV_COORDINATE}.make_precise (243, -3))
			Result.extend (create {EV_COORDINATE}.make_precise (105, -5))
			Result.extend (create {EV_COORDINATE}.make_precise (99, -8))
			Result.extend (create {EV_COORDINATE}.make_precise (56, -8))
			Result.extend (create {EV_COORDINATE}.make_precise (49, -13))
			Result.extend (create {EV_COORDINATE}.make_precise (40, -14))
			Result.extend (create {EV_COORDINATE}.make_precise (36, -10))
			Result.extend (create {EV_COORDINATE}.make_precise (12, -8))
			Result.extend (create {EV_COORDINATE}.make_precise (10, -73))
			Result.extend (create {EV_COORDINATE}.make_precise (3, -75))
			Result.extend (create {EV_COORDINATE}.make_precise (5, -13))
			Result.extend (create {EV_COORDINATE}.make_precise (1, -12))
		end

	Mitsubishi_a6m_zero_sil: ARRAYED_LIST [EV_COORDINATE]
			-- Points decribing one of the three plane silhouettes
			-- on the Japanese {AIR_UNIT_WIDGETS}
		once
			create Result.make (0)
				-- Points generated by Grabber application
			Result.extend (create {EV_COORDINATE}.make_precise (0, 0))
			Result.extend (create {EV_COORDINATE}.make_precise (-17, 0))
			Result.extend (create {EV_COORDINATE}.make_precise (-27, -3))
			Result.extend (create {EV_COORDINATE}.make_precise (-39, -11))
			Result.extend (create {EV_COORDINATE}.make_precise (-41, -22))
			Result.extend (create {EV_COORDINATE}.make_precise (-37, -31))
			Result.extend (create {EV_COORDINATE}.make_precise (-27, -36))
			Result.extend (create {EV_COORDINATE}.make_precise (-19, -39))
			Result.extend (create {EV_COORDINATE}.make_precise (-1, -41))
			Result.extend (create {EV_COORDINATE}.make_precise (1, -57))
			Result.extend (create {EV_COORDINATE}.make_precise (4, -64))
			Result.extend (create {EV_COORDINATE}.make_precise (10, -67))
			Result.extend (create {EV_COORDINATE}.make_precise (18, -68))
			Result.extend (create {EV_COORDINATE}.make_precise (30, -69))
			Result.extend (create {EV_COORDINATE}.make_precise (43, -69))
			Result.extend (create {EV_COORDINATE}.make_precise (58, -67))
			Result.extend (create {EV_COORDINATE}.make_precise (76, -66))
			Result.extend (create {EV_COORDINATE}.make_precise (99, -66))
			Result.extend (create {EV_COORDINATE}.make_precise (129, -453))
			Result.extend (create {EV_COORDINATE}.make_precise (132, -465))
			Result.extend (create {EV_COORDINATE}.make_precise (137, -480))
			Result.extend (create {EV_COORDINATE}.make_precise (144, -492))
			Result.extend (create {EV_COORDINATE}.make_precise (152, -503))
			Result.extend (create {EV_COORDINATE}.make_precise (163, -510))
			Result.extend (create {EV_COORDINATE}.make_precise (175, -514))
			Result.extend (create {EV_COORDINATE}.make_precise (187, -514))
			Result.extend (create {EV_COORDINATE}.make_precise (199, -512))
			Result.extend (create {EV_COORDINATE}.make_precise (211, -505))
			Result.extend (create {EV_COORDINATE}.make_precise (221, -494))
			Result.extend (create {EV_COORDINATE}.make_precise (229, -482))
			Result.extend (create {EV_COORDINATE}.make_precise (237, -467))
			Result.extend (create {EV_COORDINATE}.make_precise (243, -450))
			Result.extend (create {EV_COORDINATE}.make_precise (309, -76))
			Result.extend (create {EV_COORDINATE}.make_precise (315, -69))
			Result.extend (create {EV_COORDINATE}.make_precise (323, -66))
			Result.extend (create {EV_COORDINATE}.make_precise (332, -63))
			Result.extend (create {EV_COORDINATE}.make_precise (363, -61))
			Result.extend (create {EV_COORDINATE}.make_precise (390, -58))
			Result.extend (create {EV_COORDINATE}.make_precise (411, -57))
			Result.extend (create {EV_COORDINATE}.make_precise (437, -55))
			Result.extend (create {EV_COORDINATE}.make_precise (463, -54))
			Result.extend (create {EV_COORDINATE}.make_precise (483, -51))
			Result.extend (create {EV_COORDINATE}.make_precise (513, -48))
			Result.extend (create {EV_COORDINATE}.make_precise (564, -189))
			Result.extend (create {EV_COORDINATE}.make_precise (567, -197))
			Result.extend (create {EV_COORDINATE}.make_precise (575, -205))
			Result.extend (create {EV_COORDINATE}.make_precise (581, -209))
			Result.extend (create {EV_COORDINATE}.make_precise (587, -212))
			Result.extend (create {EV_COORDINATE}.make_precise (596, -212))
			Result.extend (create {EV_COORDINATE}.make_precise (604, -207))
			Result.extend (create {EV_COORDINATE}.make_precise (613, -199))
			Result.extend (create {EV_COORDINATE}.make_precise (616, -188))
			Result.extend (create {EV_COORDINATE}.make_precise (619, -173))
			Result.extend (create {EV_COORDINATE}.make_precise (634, -47))
			Result.extend (create {EV_COORDINATE}.make_precise (637, -39))
			Result.extend (create {EV_COORDINATE}.make_precise (643, -33))
			Result.extend (create {EV_COORDINATE}.make_precise (655, -30))
			Result.extend (create {EV_COORDINATE}.make_precise (708, -23))
			Result.extend (create {EV_COORDINATE}.make_precise (706, -17))
			Result.extend (create {EV_COORDINATE}.make_precise (645, -9))
			Result.extend (create {EV_COORDINATE}.make_precise (639, -4))
			Result.extend (create {EV_COORDINATE}.make_precise (634, 4))
			Result.extend (create {EV_COORDINATE}.make_precise (618, 144))
			Result.extend (create {EV_COORDINATE}.make_precise (615, 153))
			Result.extend (create {EV_COORDINATE}.make_precise (608, 161))
			Result.extend (create {EV_COORDINATE}.make_precise (599, 169))
			Result.extend (create {EV_COORDINATE}.make_precise (587, 174))
			Result.extend (create {EV_COORDINATE}.make_precise (576, 168))
			Result.extend (create {EV_COORDINATE}.make_precise (566, 157))
			Result.extend (create {EV_COORDINATE}.make_precise (518, 14))
			Result.extend (create {EV_COORDINATE}.make_precise (515, 9))
			Result.extend (create {EV_COORDINATE}.make_precise (506, 9))
			Result.extend (create {EV_COORDINATE}.make_precise (478, 11))
			Result.extend (create {EV_COORDINATE}.make_precise (448, 12))
			Result.extend (create {EV_COORDINATE}.make_precise (408, 16))
			Result.extend (create {EV_COORDINATE}.make_precise (380, 17))
			Result.extend (create {EV_COORDINATE}.make_precise (351, 20))
			Result.extend (create {EV_COORDINATE}.make_precise (333, 21))
			Result.extend (create {EV_COORDINATE}.make_precise (322, 26))
			Result.extend (create {EV_COORDINATE}.make_precise (313, 32))
			Result.extend (create {EV_COORDINATE}.make_precise (309, 38))
			Result.extend (create {EV_COORDINATE}.make_precise (246, 402))
			Result.extend (create {EV_COORDINATE}.make_precise (240, 418))
			Result.extend (create {EV_COORDINATE}.make_precise (235, 431))
			Result.extend (create {EV_COORDINATE}.make_precise (228, 443))
			Result.extend (create {EV_COORDINATE}.make_precise (218, 456))
			Result.extend (create {EV_COORDINATE}.make_precise (205, 468))
			Result.extend (create {EV_COORDINATE}.make_precise (188, 472))
			Result.extend (create {EV_COORDINATE}.make_precise (174, 472))
			Result.extend (create {EV_COORDINATE}.make_precise (161, 467))
			Result.extend (create {EV_COORDINATE}.make_precise (147, 457))
			Result.extend (create {EV_COORDINATE}.make_precise (140, 446))
			Result.extend (create {EV_COORDINATE}.make_precise (133, 433))
			Result.extend (create {EV_COORDINATE}.make_precise (129, 417))
			Result.extend (create {EV_COORDINATE}.make_precise (126, 402))
			Result.extend (create {EV_COORDINATE}.make_precise (123, 381))
			Result.extend (create {EV_COORDINATE}.make_precise (104, 381))
			Result.extend (create {EV_COORDINATE}.make_precise (77, 379))
			Result.extend (create {EV_COORDINATE}.make_precise (103, 377))
			Result.extend (create {EV_COORDINATE}.make_precise (125, 377))
			Result.extend (create {EV_COORDINATE}.make_precise (101, 27))
			Result.extend (create {EV_COORDINATE}.make_precise (78, 25))
			Result.extend (create {EV_COORDINATE}.make_precise (61, 27))
			Result.extend (create {EV_COORDINATE}.make_precise (44, 29))
			Result.extend (create {EV_COORDINATE}.make_precise (30, 29))
			Result.extend (create {EV_COORDINATE}.make_precise (19, 28))
			Result.extend (create {EV_COORDINATE}.make_precise (6, 24))
			Result.extend (create {EV_COORDINATE}.make_precise (1, 14))
		end

	Grummen_f4f_wildcat_sil: ARRAYED_LIST [EV_COORDINATE]
			-- Points decribing one of the two plane silhouettes
			-- on the Allied {AIR_UNIT_WIDGETS}
		once
			create Result.make (0)
				-- Points generated by Grabber application
			Result.extend (create {EV_COORDINATE}.make_precise (0, 0))
			Result.extend (create {EV_COORDINATE}.make_precise (4, -5))
			Result.extend (create {EV_COORDINATE}.make_precise (13, -5))
			Result.extend (create {EV_COORDINATE}.make_precise (23, -7))
			Result.extend (create {EV_COORDINATE}.make_precise (26, -35))
			Result.extend (create {EV_COORDINATE}.make_precise (27, -57))
			Result.extend (create {EV_COORDINATE}.make_precise (28, -76))
			Result.extend (create {EV_COORDINATE}.make_precise (30, -92))
			Result.extend (create {EV_COORDINATE}.make_precise (33, -100))
			Result.extend (create {EV_COORDINATE}.make_precise (35, -88))
			Result.extend (create {EV_COORDINATE}.make_precise (35, -79))
			Result.extend (create {EV_COORDINATE}.make_precise (38, -58))
			Result.extend (create {EV_COORDINATE}.make_precise (39, -37))
			Result.extend (create {EV_COORDINATE}.make_precise (39, -25))
			Result.extend (create {EV_COORDINATE}.make_precise (41, -16))
			Result.extend (create {EV_COORDINATE}.make_precise (41, -7))
			Result.extend (create {EV_COORDINATE}.make_precise (46, -5))
			Result.extend (create {EV_COORDINATE}.make_precise (46, -13))
			Result.extend (create {EV_COORDINATE}.make_precise (51, -19))
			Result.extend (create {EV_COORDINATE}.make_precise (49, -37))
			Result.extend (create {EV_COORDINATE}.make_precise (53, -43))
			Result.extend (create {EV_COORDINATE}.make_precise (60, -47))
			Result.extend (create {EV_COORDINATE}.make_precise (72, -49))
			Result.extend (create {EV_COORDINATE}.make_precise (88, -54))
			Result.extend (create {EV_COORDINATE}.make_precise (104, -55))
			Result.extend (create {EV_COORDINATE}.make_precise (120, -57))
			Result.extend (create {EV_COORDINATE}.make_precise (128, -58))
			Result.extend (create {EV_COORDINATE}.make_precise (130, -62))
			Result.extend (create {EV_COORDINATE}.make_precise (151, -62))
			Result.extend (create {EV_COORDINATE}.make_precise (154, -65))
			Result.extend (create {EV_COORDINATE}.make_precise (173, -449))
			Result.extend (create {EV_COORDINATE}.make_precise (176, -455))
			Result.extend (create {EV_COORDINATE}.make_precise (182, -457))
			Result.extend (create {EV_COORDINATE}.make_precise (191, -459))
			Result.extend (create {EV_COORDINATE}.make_precise (201, -461))
			Result.extend (create {EV_COORDINATE}.make_precise (214, -461))
			Result.extend (create {EV_COORDINATE}.make_precise (225, -461))
			Result.extend (create {EV_COORDINATE}.make_precise (236, -460))
			Result.extend (create {EV_COORDINATE}.make_precise (255, -459))
			Result.extend (create {EV_COORDINATE}.make_precise (274, -455))
			Result.extend (create {EV_COORDINATE}.make_precise (297, -449))
			Result.extend (create {EV_COORDINATE}.make_precise (349, -64))
			Result.extend (create {EV_COORDINATE}.make_precise (352, -59))
			Result.extend (create {EV_COORDINATE}.make_precise (357, -56))
			Result.extend (create {EV_COORDINATE}.make_precise (378, -53))
			Result.extend (create {EV_COORDINATE}.make_precise (393, -52))
			Result.extend (create {EV_COORDINATE}.make_precise (408, -50))
			Result.extend (create {EV_COORDINATE}.make_precise (427, -48))
			Result.extend (create {EV_COORDINATE}.make_precise (442, -46))
			Result.extend (create {EV_COORDINATE}.make_precise (458, -44))
			Result.extend (create {EV_COORDINATE}.make_precise (479, -41))
			Result.extend (create {EV_COORDINATE}.make_precise (493, -39))
			Result.extend (create {EV_COORDINATE}.make_precise (512, -37))
			Result.extend (create {EV_COORDINATE}.make_precise (527, -32))
			Result.extend (create {EV_COORDINATE}.make_precise (542, -31))
			Result.extend (create {EV_COORDINATE}.make_precise (560, -26))
			Result.extend (create {EV_COORDINATE}.make_precise (574, -24))
			Result.extend (create {EV_COORDINATE}.make_precise (616, -160))
			Result.extend (create {EV_COORDINATE}.make_precise (619, -163))
			Result.extend (create {EV_COORDINATE}.make_precise (625, -165))
			Result.extend (create {EV_COORDINATE}.make_precise (631, -166))
			Result.extend (create {EV_COORDINATE}.make_precise (638, -166))
			Result.extend (create {EV_COORDINATE}.make_precise (646, -166))
			Result.extend (create {EV_COORDINATE}.make_precise (657, -166))
			Result.extend (create {EV_COORDINATE}.make_precise (665, -164))
			Result.extend (create {EV_COORDINATE}.make_precise (676, -160))
			Result.extend (create {EV_COORDINATE}.make_precise (690, -26))
			Result.extend (create {EV_COORDINATE}.make_precise (650, -11))
			Result.extend (create {EV_COORDINATE}.make_precise (659, -9))
			Result.extend (create {EV_COORDINATE}.make_precise (666, -7))
			Result.extend (create {EV_COORDINATE}.make_precise (669, -4))
			Result.extend (create {EV_COORDINATE}.make_precise (681, -3))
			Result.extend (create {EV_COORDINATE}.make_precise (693, 0))
			Result.extend (create {EV_COORDINATE}.make_precise (684, 3))
			Result.extend (create {EV_COORDINATE}.make_precise (674, 4))
			Result.extend (create {EV_COORDINATE}.make_precise (666, 8))
			Result.extend (create {EV_COORDINATE}.make_precise (651, 10))
			Result.extend (create {EV_COORDINATE}.make_precise (690, 29))
			Result.extend (create {EV_COORDINATE}.make_precise (677, 160))
			Result.extend (create {EV_COORDINATE}.make_precise (666, 164))
			Result.extend (create {EV_COORDINATE}.make_precise (655, 166))
			Result.extend (create {EV_COORDINATE}.make_precise (644, 167))
			Result.extend (create {EV_COORDINATE}.make_precise (629, 166))
			Result.extend (create {EV_COORDINATE}.make_precise (614, 164))
			Result.extend (create {EV_COORDINATE}.make_precise (574, 26))
			Result.extend (create {EV_COORDINATE}.make_precise (560, 29))
			Result.extend (create {EV_COORDINATE}.make_precise (543, 31))
			Result.extend (create {EV_COORDINATE}.make_precise (526, 35))
			Result.extend (create {EV_COORDINATE}.make_precise (508, 37))
			Result.extend (create {EV_COORDINATE}.make_precise (493, 39))
			Result.extend (create {EV_COORDINATE}.make_precise (475, 42))
			Result.extend (create {EV_COORDINATE}.make_precise (459, 44))
			Result.extend (create {EV_COORDINATE}.make_precise (441, 47))
			Result.extend (create {EV_COORDINATE}.make_precise (427, 49))
			Result.extend (create {EV_COORDINATE}.make_precise (409, 51))
			Result.extend (create {EV_COORDINATE}.make_precise (394, 53))
			Result.extend (create {EV_COORDINATE}.make_precise (377, 54))
			Result.extend (create {EV_COORDINATE}.make_precise (359, 55))
			Result.extend (create {EV_COORDINATE}.make_precise (355, 58))
			Result.extend (create {EV_COORDINATE}.make_precise (352, 63))
			Result.extend (create {EV_COORDINATE}.make_precise (297, 450))
			Result.extend (create {EV_COORDINATE}.make_precise (287, 454))
			Result.extend (create {EV_COORDINATE}.make_precise (274, 455))
			Result.extend (create {EV_COORDINATE}.make_precise (259, 457))
			Result.extend (create {EV_COORDINATE}.make_precise (245, 459))
			Result.extend (create {EV_COORDINATE}.make_precise (234, 460))
			Result.extend (create {EV_COORDINATE}.make_precise (222, 460))
			Result.extend (create {EV_COORDINATE}.make_precise (212, 461))
			Result.extend (create {EV_COORDINATE}.make_precise (197, 460))
			Result.extend (create {EV_COORDINATE}.make_precise (183, 457))
			Result.extend (create {EV_COORDINATE}.make_precise (176, 456))
			Result.extend (create {EV_COORDINATE}.make_precise (171, 450))
			Result.extend (create {EV_COORDINATE}.make_precise (157, 70))
			Result.extend (create {EV_COORDINATE}.make_precise (155, 65))
			Result.extend (create {EV_COORDINATE}.make_precise (151, 61))
			Result.extend (create {EV_COORDINATE}.make_precise (127, 61))
			Result.extend (create {EV_COORDINATE}.make_precise (122, 58))
			Result.extend (create {EV_COORDINATE}.make_precise (107, 58))
			Result.extend (create {EV_COORDINATE}.make_precise (90, 56))
			Result.extend (create {EV_COORDINATE}.make_precise (75, 52))
			Result.extend (create {EV_COORDINATE}.make_precise (62, 49))
			Result.extend (create {EV_COORDINATE}.make_precise (55, 46))
			Result.extend (create {EV_COORDINATE}.make_precise (49, 39))
			Result.extend (create {EV_COORDINATE}.make_precise (49, 31))
			Result.extend (create {EV_COORDINATE}.make_precise (48, 18))
			Result.extend (create {EV_COORDINATE}.make_precise (46, 14))
			Result.extend (create {EV_COORDINATE}.make_precise (45, 5))
			Result.extend (create {EV_COORDINATE}.make_precise (40, 6))
			Result.extend (create {EV_COORDINATE}.make_precise (41, 33))
			Result.extend (create {EV_COORDINATE}.make_precise (40, 46))
			Result.extend (create {EV_COORDINATE}.make_precise (39, 62))
			Result.extend (create {EV_COORDINATE}.make_precise (38, 76))
			Result.extend (create {EV_COORDINATE}.make_precise (36, 90))
			Result.extend (create {EV_COORDINATE}.make_precise (33, 103))
			Result.extend (create {EV_COORDINATE}.make_precise (29, 95))
			Result.extend (create {EV_COORDINATE}.make_precise (28, 83))
			Result.extend (create {EV_COORDINATE}.make_precise (28, 73))
			Result.extend (create {EV_COORDINATE}.make_precise (27, 55))
			Result.extend (create {EV_COORDINATE}.make_precise (28, 40))
			Result.extend (create {EV_COORDINATE}.make_precise (26, 35))
			Result.extend (create {EV_COORDINATE}.make_precise (25, 11))
			Result.extend (create {EV_COORDINATE}.make_precise (23, 8))
			Result.extend (create {EV_COORDINATE}.make_precise (15, 9))
			Result.extend (create {EV_COORDINATE}.make_precise (3, 5))
			Result.extend (create {EV_COORDINATE}.make_precise (-2, 4))
		end

	amphibious_symbol_sil: ARRAYED_LIST [EV_COORDINATE]
			-- Points decribing the silhouette on
			-- the {AMPHIBIOUS_UNIT_WIDGETS}
		once
			create Result.make (0)
				-- Points generated by Grabber application
			Result.extend (create {EV_COORDINATE}.make_precise (0, 0))
			Result.extend (create {EV_COORDINATE}.make_precise (657, -6))
			Result.extend (create {EV_COORDINATE}.make_precise (672, 0))
			Result.extend (create {EV_COORDINATE}.make_precise (685, 12))
			Result.extend (create {EV_COORDINATE}.make_precise (696, 30))
			Result.extend (create {EV_COORDINATE}.make_precise (696, 53))
			Result.extend (create {EV_COORDINATE}.make_precise (706, 457))
			Result.extend (create {EV_COORDINATE}.make_precise (703, 467))
			Result.extend (create {EV_COORDINATE}.make_precise (691, 479))
			Result.extend (create {EV_COORDINATE}.make_precise (677, 485))
			Result.extend (create {EV_COORDINATE}.make_precise (662, 487))
			Result.extend (create {EV_COORDINATE}.make_precise (24, 489))
			Result.extend (create {EV_COORDINATE}.make_precise (134, 413))
			Result.extend (create {EV_COORDINATE}.make_precise (625, 88))
			Result.extend (create {EV_COORDINATE}.make_precise (637, 95))
			Result.extend (create {EV_COORDINATE}.make_precise (647, 154))
			Result.extend (create {EV_COORDINATE}.make_precise (652, 367))
			Result.extend (create {EV_COORDINATE}.make_precise (630, 375))
			Result.extend (create {EV_COORDINATE}.make_precise (614, 374))
			Result.extend (create {EV_COORDINATE}.make_precise (134, 77))
			Result.extend (create {EV_COORDINATE}.make_precise (129, 66))
			Result.extend (create {EV_COORDINATE}.make_precise (140, 57))
			Result.extend (create {EV_COORDINATE}.make_precise (555, 55))
			Result.extend (create {EV_COORDINATE}.make_precise (556, 63))
			Result.extend (create {EV_COORDINATE}.make_precise (51, 389))
			Result.extend (create {EV_COORDINATE}.make_precise (37, 392))
			Result.extend (create {EV_COORDINATE}.make_precise (29, 385))
			Result.extend (create {EV_COORDINATE}.make_precise (27, 92))
			Result.extend (create {EV_COORDINATE}.make_precise (36, 88))
			Result.extend (create {EV_COORDINATE}.make_precise (46, 90))
			Result.extend (create {EV_COORDINATE}.make_precise (569, 422))
			Result.extend (create {EV_COORDINATE}.make_precise (103, 429))
			Result.extend (create {EV_COORDINATE}.make_precise (21, 486))
			Result.extend (create {EV_COORDINATE}.make_precise (-12, 480))
			Result.extend (create {EV_COORDINATE}.make_precise (-26, 469))
			Result.extend (create {EV_COORDINATE}.make_precise (-32, 453))
			Result.extend (create {EV_COORDINATE}.make_precise (-35, 27))
			Result.extend (create {EV_COORDINATE}.make_precise (-27, 15))
			Result.extend (create {EV_COORDINATE}.make_precise (-17, 5))
		end


end
