note
	description: "[
		One of the classes that decompose the numourous VITP widgets 
		into more managable groups.  This class models the widgets
		that contain all the Allied units for turns one through nine.
		]"
	author:    "Jimmy J. Johnson"
	date:      "5/15/24"
	copyright: "Copyright (c) 2024, Jimmy J. Johnson"
	license:   "Eiffel Forum v2 (http://www.eiffel.com/licensing/forum.txt)"

class
	ALLIED_FORCES_WIDGET_FACTORY

inherit

	WIDGET_FACTORY
		redefine
			make_widgets,
			extend_widgets,
			pair_widgets,
			fill_widgets
		end

create
	make

feature {NONE} -- Initialization

	make_widgets
			-- Create widgets for the corresponding game item
		do
			create allied_forces_widgets.make (100)
			Precursor {WIDGET_FACTORY}
				-- Turn 1, on battleship row (Pearl Harbor)
			create nevada_widget.make (game.nevada)
			create arizona_widget.make (game.arizona)
			create west_virginia_widget.make (game.west_virginia)
			create tennessee_widget.make (game.tennessee)
			create oklahoma_widget.make (game.oklahoma)
			create maryland_widget.make (game.maryland)
			create california_widget.make (game.california)
			create pennsylvania_widget.make (game.pennsylvania)
			create new_orleans_widget.make (game.new_orleans)
			create san_francisco_widget.make (game.san_francisco)
			create seventh_af_widget.make (game.seventh_af)
				-- Turn 1, at sea (cannot move)
			create hermes_widget.make (game.hermes)
			create revenge_widget.make (game.revenge)
			create prince_of_wales_widget.make (game.prince_of_wales)
			create repulse_widget.make (game.repulse)
			create fifth_af_widget.make (game.fifth_af)
			create louisville_widget.make (game.louisville)
			create pensacola_widget.make (game.pensacola)
			create indianapolis_widget.make (game.indianapolis)
			create minneapolis_widget.make (game.minneapolis)
				-- Turn 1, in port (may move)
			create houston_widget.make (game.houston)
			create exeter_widget.make (game.exeter)
			create de_ruyter_widget.make (game.de_ruyter)
			create australia_ship_widget.make (game.australia_ship)
			create canberra_widget.make (game.canberra)
				-- Turn 1, Location uncertain (group W)
			create enterprise_widget.make (game.enterprise)
			create salt_lake_city_widget.make (game.salt_lake_city)
			create northampton_widget.make (game.northampton)
			create chester_widget.make (game.chester)
				-- Turn 1, Location uncertain (group X)
			create lexington_widget.make (game.lexington)
			create chicago_widget.make (game.chicago)
			create portland_widget.make (game.portland)
			create astoria_widget.make (game.astoria)
				-- Turn 1, Location uncertain (group Y)
			create saratoga_widget.make (game.saratoga)
				-- Turn 1, Location uncertain (group Z)
			create hornet_widget.make (game.hornet)
			create yorktown_widget.make (game.yorktown)
			create vincennes_widget.make (game.vincennes)
			create quincy_widget.make (game.quincy)
				-- Turn_2
			create royal_sovereign_widget.make (game.royal_sovereign)
			create ramilies_widget.make (game.ramilies)
			create resolution_widget.make (game.resolution)
			create warspite_widget.make (game.warspite)
			create indomitable_widget.make (game.indomitable)
			create formidable_widget.make (game.formidable)
			create cornwall_widget.make (game.cornwall)
			create dorestshire_widget.make (game.dorestshire)
			create new_mexico_widget.make (game.new_mexico)
			create idaho_widget.make (game.idaho)
			create tenth_af_widget.make (game.tenth_af)
			create eleventh_af_widget.make (game.eleventh_af)
				-- Turn 3
			create north_carolina_widget.make (game.north_carolina)
			create mississippi_widget.make (game.mississippi)
			create colorado_widget.make (game.colorado)
			create marines_1_widget.make (game.marines_1)
			create marines_2_widget.make (game.marines_2)
			create raaf_widget.make (game.raaf)
			create rnzaf_widget.make (game.rnzaf)
			create valiant_widget.make (game.valiant)
			create illustrious_widget.make (game.illustrious)
				-- Turn 4
			create south_dakota_widget.make (game.south_dakota)
			create indiana_widget.make (game.indiana)
			create washington_widget.make (game.washington)
			create wasp_widget.make (game.wasp)
			create marine_widget.make (game.marine)
			create thirteenth_af_widget.make (game.thirteenth_af)
			create devonshire_widget.make (game.devonshire)
			create shropshire_widget.make (game.shropshire)
			create first_027_removal_widget.make (game.first_027_removal)
			create second_027_removal_widget.make (game.second_027_removal)
				-- Turn 5
			create massachusetts_widget.make (game.massachusetts)
			create wichita_widget.make (game.wichita)
			create victorious_widget.make (game.victorious)
			create marines_3_widget.make (game.marines_3)
			create fourteenth_af_widget.make (game.fourteenth_af)
			create naval_widget.make (game.naval)
			create resolution_removal_widget.make (game.resolution_removal)
			create revenge_removal_widget.make (game.revenge_removal)
			create valiant_removal_widget.make (game.valiant_removal)
			create warspite_removal_widget.make (game.warspite_removal)
				-- Turn 6
			create alabama_widget.make (game.alabama)
			create essex_widget.make (game.essex)
			create cv_10_widget.make (game.cv_10)
			create cv_16_widget.make (game.cv_16)
			create independence_widget.make (game.independence)
			create princeton_widget.make (game.princeton)
			create belleau_wood_widget.make (game.belleau_wood)
			create cowpens_widget.make (game.cowpens)
			create monterey_widget.make (game.monterey)
			create baltimore_widget.make (game.baltimore)
			create boston_widget.make (game.boston)
			create marines_4_widget.make (game.marines_4)
			create victorious_removal_widget.make (game.victorious_removal)
				-- Turn 7
			create iowa_widget.make (game.iowa)
			create new_jersey_widget.make (game.new_jersey)
			create intrepid_widget.make (game.intrepid)
			create cv_12_widget.make (game.cv_12)
			create bunker_hill_widget.make (game.bunker_hill)
			create cv_18_widget.make (game.cv_18)
			create bataan_widget.make (game.bataan)
			create cabot_widget.make (game.cabot)
			create langley_ii_widget.make (game.langley_ii)
			create canberra_ii_widget.make (game.canberra_ii)
			create quincy_ii_widget.make (game.quincy_ii)
			create f_boat_widget.make (game.f_boat)
			create third_027_removal_widget.make (game.third_027_removal)
			create first_443_removal_widget.make (game.first_443_removal)
				-- Turn 8
			create wisconsin_widget.make (game.wisconsin)
			create missouri_widget.make (game.missouri)
			create ticonderoga_widget.make (game.ticonderoga)
			create san_jacinto_widget.make (game.san_jacinto)
			create marines_5_widget.make (game.marines_5)
				-- Turn 9
			create new_york_widget.make (game.new_york)
			create texas_widget.make (game.texas)
			create alaska_widget.make (game.alaska)
			create franklin_widget.make (game.franklin)
			create shangri_la_widget.make (game.shangri_la)
		end

feature -- Access

	allied_forces_widgets: VITP_WIDGET_TABLE [ATTACK_UNIT_WIDGET, ATTACK_UNIT]
			-- Keeps track of Allied attack units turns 2 to 9

feature -- Access (Allied unit widgets turn 2 to 9)

		-- On Battleship Row (Pearl Harbor)
	nevada_widget: SHIP_WIDGET
	arizona_widget: SHIP_WIDGET
	west_virginia_widget: SHIP_WIDGET
	tennessee_widget: SHIP_WIDGET
	oklahoma_widget: SHIP_WIDGET
	maryland_widget: SHIP_WIDGET
	california_widget: SHIP_WIDGET
	pennsylvania_widget: SHIP_WIDGET
	new_orleans_widget: SHIP_WIDGET
	san_francisco_widget: SHIP_WIDGET
	seventh_af_widget: ALLIED_AIR_UNIT_WIDGET
		-- At sea (cannot move)
	hermes_widget: SHIP_WIDGET
	revenge_widget: SHIP_WIDGET
	prince_of_wales_widget: SHIP_WIDGET
	repulse_widget: SHIP_WIDGET
	fifth_af_widget: ALLIED_AIR_UNIT_WIDGET
	louisville_widget: SHIP_WIDGET
	pensacola_widget: SHIP_WIDGET
	indianapolis_widget: SHIP_WIDGET
	minneapolis_widget: SHIP_WIDGET
		-- In port (may move)
	houston_widget: SHIP_WIDGET
	exeter_widget: SHIP_WIDGET
	de_ruyter_widget: SHIP_WIDGET
	australia_ship_widget: SHIP_WIDGET
	canberra_widget: SHIP_WIDGET
		-- Location Uncertain, group W
	enterprise_widget: SHIP_WIDGET
	salt_lake_city_widget: SHIP_WIDGET
	northampton_widget: SHIP_WIDGET
	chester_widget: SHIP_WIDGET
		-- Location Uncertain, group X
	lexington_widget: SHIP_WIDGET
	chicago_widget: SHIP_WIDGET
	portland_widget: SHIP_WIDGET
	astoria_widget: SHIP_WIDGET
		-- Location Uncertain, group Y
	saratoga_widget: SHIP_WIDGET
		-- Location Uncertain, group W
	hornet_widget: SHIP_WIDGET
	yorktown_widget: SHIP_WIDGET
	vincennes_widget: SHIP_WIDGET
	quincy_widget: SHIP_WIDGET
		-- Turn 2
	royal_sovereign_widget: SHIP_WIDGET
	ramilies_widget: SHIP_WIDGET
	resolution_widget: SHIP_WIDGET
	warspite_widget: SHIP_WIDGET
	indomitable_widget: SHIP_WIDGET
	formidable_widget: SHIP_WIDGET
	cornwall_widget: SHIP_WIDGET
	dorestshire_widget: SHIP_WIDGET
	new_mexico_widget: SHIP_WIDGET
	idaho_widget: SHIP_WIDGET
	tenth_af_widget: ALLIED_AIR_UNIT_WIDGET
	eleventh_af_widget: ALLIED_AIR_UNIT_WIDGET
		-- Turn 3
	north_carolina_widget: SHIP_WIDGET
	mississippi_widget: SHIP_WIDGET
	colorado_widget: SHIP_WIDGET
	marines_1_widget: AMPHIBIOUS_UNIT_wIDGET
	marines_2_widget: AMPHIBIOUS_UNIT_WIDGET
	raaf_widget: ALLIED_AIR_UNIT_WIDGET
	rnzaf_widget: ALLIED_AIR_UNIT_WIDGET
	valiant_widget: SHIP_WIDGET
	illustrious_widget: SHIP_WIDGET
		-- Turn 4
	south_dakota_widget: SHIP_WIDGET
	indiana_widget: SHIP_WIDGET
	washington_widget: SHIP_WIDGET
	wasp_widget: SHIP_WIDGET
	marine_widget: ALLIED_AIR_UNIT_WIDGET
	thirteenth_af_widget: ALLIED_AIR_UNIT_WIDGET
	devonshire_widget: SHIP_WIDGET
	shropshire_widget: SHIP_WIDGET
	first_027_removal_widget: SHIP_WIDGET
	second_027_removal_widget: SHIP_WIDGET
		-- Turn 5
	massachusetts_widget: SHIP_WIDGET
	wichita_widget: SHIP_WIDGET
	victorious_widget: SHIP_WIDGET
	marines_3_widget: AMPHIBIOUS_UNIT_WIDGET
	fourteenth_af_widget: ALLIED_AIR_UNIT_WIDGET
	naval_widget: ALLIED_AIR_UNIT_WIDGET
	resolution_removal_widget: SHIP_WIDGET
	revenge_removal_widget: SHIP_WIDGET
	valiant_removal_widget: SHIP_WIDGET
	warspite_removal_widget: SHIP_WIDGET
		-- Turn 6
	alabama_widget: SHIP_WIDGET
	essex_widget: SHIP_WIDGET
	cv_10_widget: SHIP_WIDGET
	cv_16_widget: SHIP_WIDGET
	independence_widget: SHIP_WIDGET
	princeton_widget: SHIP_WIDGET
	belleau_wood_widget: SHIP_WIDGET
	cowpens_widget: SHIP_WIDGET
	monterey_widget: SHIP_WIDGET
	baltimore_widget: SHIP_WIDGET
	boston_widget: SHIP_WIDGET
	marines_4_widget: AMPHIBIOUS_UNIT_WIDGET
	victorious_removal_widget: SHIP_WIDGET
		-- Turn 7
	iowa_widget: SHIP_WIDGET
	new_jersey_widget: SHIP_WIDGET
	intrepid_widget: SHIP_WIDGET
	cv_12_widget: SHIP_WIDGET
	bunker_hill_widget: SHIP_WIDGET
	cv_18_widget: SHIP_WIDGET
	bataan_widget: SHIP_WIDGET
	cabot_widget: SHIP_WIDGET
	langley_ii_widget: SHIP_WIDGET
	canberra_ii_widget: SHIP_WIDGET
	quincy_ii_widget: SHIP_WIDGET
	f_boat_widget: SUBMARINE_WIDGET
	third_027_removal_widget: SHIP_WIDGET
	first_443_removal_widget: SHIP_WIDGET
		-- Turn 8
	wisconsin_widget: SHIP_WIDGET
	missouri_widget: SHIP_WIDGET
	ticonderoga_widget: SHIP_WIDGET
	san_jacinto_widget: SHIP_WIDGET
	marines_5_widget: AMPHIBIOUS_UNIT_WIDGET
		-- Turn 9
	new_york_widget: SHIP_WIDGET
	texas_widget: SHIP_WIDGET
	alaska_widget: SHIP_WIDGET
	franklin_widget: SHIP_WIDGET
	shangri_la_widget: SHIP_WIDGET

feature {NONE} -- Implementation

	extend_widgets
			-- Put turn-two to turn-nine allied {ATTACK_UNIT_WIDGET} into `world'.
		do
			create allied_forces_widgets.make (100)
				-- On Battleship Row (Pearl Harbor)
			allied_forces_widgets.extend (nevada_widget, game.nevada)
			allied_forces_widgets.extend (arizona_widget, game.arizona)
			allied_forces_widgets.extend (west_virginia_widget, game.west_virginia)
			allied_forces_widgets.extend (tennessee_widget, game.tennessee)
			allied_forces_widgets.extend (oklahoma_widget, game.oklahoma)
			allied_forces_widgets.extend (maryland_widget, game.maryland)
			allied_forces_widgets.extend (california_widget, game.california)
			allied_forces_widgets.extend (pennsylvania_widget, game.pennsylvania)
			allied_forces_widgets.extend (new_orleans_widget, game.new_orleans)
			allied_forces_widgets.extend (san_francisco_widget, game.san_francisco)
			allied_forces_widgets.extend (seventh_af_widget, game.seventh_af)
				-- At sea (cannot move)
			allied_forces_widgets.extend (hermes_widget, game.hermes)
			allied_forces_widgets.extend (revenge_widget, game.revenge)
			allied_forces_widgets.extend (prince_of_wales_widget, game.prince_of_wales)
			allied_forces_widgets.extend (repulse_widget, game.repulse)
			allied_forces_widgets.extend (fifth_af_widget, game.fifth_af)
			allied_forces_widgets.extend (louisville_widget, game.louisville)
			allied_forces_widgets.extend (pensacola_widget, game.pensacola)
			allied_forces_widgets.extend (indianapolis_widget, game.indianapolis)
			allied_forces_widgets.extend (minneapolis_widget, game.minneapolis)
				-- In port (may move)
			allied_forces_widgets.extend (houston_widget, game.houston)
			allied_forces_widgets.extend (exeter_widget, game.exeter)
			allied_forces_widgets.extend (de_ruyter_widget, game.de_ruyter)
			allied_forces_widgets.extend (australia_ship_widget, game.australia_ship)
			allied_forces_widgets.extend (canberra_widget, game.canberra)
				-- Location Uncertain, group W
			allied_forces_widgets.extend (enterprise_widget, game.enterprise)
			allied_forces_widgets.extend (salt_lake_city_widget, game.salt_lake_city)
			allied_forces_widgets.extend (northampton_widget, game.northampton)
			allied_forces_widgets.extend (chester_widget, game.chester)
				-- Location Uncertain, group X
			allied_forces_widgets.extend (lexington_widget, game.lexington)
			allied_forces_widgets.extend (chicago_widget, game.chicago)
			allied_forces_widgets.extend (portland_widget, game.portland)
			allied_forces_widgets.extend (astoria_widget, game.astoria)
				-- Location Uncertain, group Y
			allied_forces_widgets.extend (saratoga_widget, game.saratoga)
				-- Location Uncertain (group Z
			allied_forces_widgets.extend (hornet_widget, game.hornet)
			allied_forces_widgets.extend (yorktown_widget, game.yorktown)
			allied_forces_widgets.extend (vincennes_widget, game.vincennes)
			allied_forces_widgets.extend (quincy_widget, game.quincy)
				-- Turn 2
			allied_forces_widgets.extend (royal_sovereign_widget, game.royal_sovereign)
			allied_forces_widgets.extend (ramilies_widget, game.ramilies)
			allied_forces_widgets.extend (resolution_widget, game.resolution)
			allied_forces_widgets.extend (warspite_widget, game.warspite)
			allied_forces_widgets.extend (indomitable_widget, game.indomitable)
			allied_forces_widgets.extend (formidable_widget, game.formidable)
			allied_forces_widgets.extend (cornwall_widget, game.cornwall)
			allied_forces_widgets.extend (dorestshire_widget, game.dorestshire)
			allied_forces_widgets.extend (new_mexico_widget, game.new_mexico)
			allied_forces_widgets.extend (idaho_widget, game.idaho)
			allied_forces_widgets.extend (eleventh_af_widget, game.eleventh_af)
				-- Turn 3
			allied_forces_widgets.extend (north_carolina_widget, game.north_carolina)
			allied_forces_widgets.extend (mississippi_widget, game.mississippi)
			allied_forces_widgets.extend (colorado_widget, game.colorado)
			allied_forces_widgets.extend (marines_1_widget, game.marines_1)
			allied_forces_widgets.extend (marines_2_widget, game.marines_2)
			allied_forces_widgets.extend (raaf_widget, game.raaf)
			allied_forces_widgets.extend (rnzaf_widget, game.rnzaf)
			allied_forces_widgets.extend (valiant_widget, game.valiant)
			allied_forces_widgets.extend (illustrious_widget, game.illustrious)
				-- Turn 4
			allied_forces_widgets.extend (south_dakota_widget, game.south_dakota)
			allied_forces_widgets.extend (indiana_widget, game.indiana)
			allied_forces_widgets.extend (washington_widget, game.washington)
			allied_forces_widgets.extend (wasp_widget, game.wasp)
			allied_forces_widgets.extend (marine_widget, game.marine)
			allied_forces_widgets.extend (thirteenth_af_widget, game.thirteenth_af)
			allied_forces_widgets.extend (devonshire_widget, game.devonshire)
			allied_forces_widgets.extend (shropshire_widget, game.shropshire)
--			allied_forces_widgets.extend (first_027_removal_widget, game.first_027_removal)
--			allied_forces_widgets.extend (second_027_removal_widget, game.second_027_removal)
				-- Turn 5
			allied_forces_widgets.extend (massachusetts_widget, game.massachusetts)
			allied_forces_widgets.extend (wichita_widget, game.wichita)
			allied_forces_widgets.extend (victorious_widget, game.victorious)
			allied_forces_widgets.extend (marines_3_widget, game.marines_3)
			allied_forces_widgets.extend (fourteenth_af_widget, game.fourteenth_af)
			allied_forces_widgets.extend (naval_widget, game.naval)
--			allied_forces_widgets.extend (resolution_removal_widget, game.resolution_removal)
--			allied_forces_widgets.extend (revenge_removal_widget, game.revenge_removal)
--			allied_forces_widgets.extend (valiant_removal_widget, game.valiant_removal)
--			allied_forces_widgets.extend (warspite_removal_widget, game.warspite_removal)
				-- Turn 6
			allied_forces_widgets.extend (alabama_widget, game.alabama)
			allied_forces_widgets.extend (essex_widget, game.essex)
			allied_forces_widgets.extend (cv_10_widget, game.cv_10)
			allied_forces_widgets.extend (cv_16_widget, game.cv_16)
			allied_forces_widgets.extend (independence_widget, game.independence)
			allied_forces_widgets.extend (princeton_widget, game.princeton)
			allied_forces_widgets.extend (belleau_wood_widget, game.belleau_wood)
			allied_forces_widgets.extend (cowpens_widget, game.cowpens)
			allied_forces_widgets.extend (monterey_widget, game.monterey)
			allied_forces_widgets.extend (baltimore_widget, game.baltimore)
			allied_forces_widgets.extend (boston_widget, game.boston)
			allied_forces_widgets.extend (marines_4_widget, game.marines_4)
--			allied_forces_widgets.extend (victorious_removal_widget, game.victorious_removal)
				-- Turn 7
			allied_forces_widgets.extend (iowa_widget, game.iowa)
			allied_forces_widgets.extend (new_jersey_widget, game.new_jersey)
			allied_forces_widgets.extend (intrepid_widget, game.intrepid)
			allied_forces_widgets.extend (cv_12_widget, game.cv_12)
			allied_forces_widgets.extend (bunker_hill_widget, game.bunker_hill)
			allied_forces_widgets.extend (cv_18_widget, game.cv_18)
			allied_forces_widgets.extend (bataan_widget, game.bataan)
			allied_forces_widgets.extend (cabot_widget, game.cabot)
			allied_forces_widgets.extend (langley_ii_widget, game.langley_ii)
			allied_forces_widgets.extend (canberra_ii_widget, game.canberra_ii)
			allied_forces_widgets.extend (quincy_ii_widget, game.quincy_ii)
			allied_forces_widgets.extend (f_boat_widget, game.f_boat)
				-- Turn 8
			allied_forces_widgets.extend (wisconsin_widget, game.wisconsin)
			allied_forces_widgets.extend (missouri_widget, game.missouri)
			allied_forces_widgets.extend (ticonderoga_widget, game.ticonderoga)
			allied_forces_widgets.extend (san_jacinto_widget, game.san_jacinto)
			allied_forces_widgets.extend (marines_5_widget, game.marines_5)
				-- Turn 9
			allied_forces_widgets.extend (new_york_widget, game.new_york)
			allied_forces_widgets.extend (texas_widget, game.texas)
			allied_forces_widgets.extend (alaska_widget, game.alaska)
			allied_forces_widgets.extend (franklin_widget, game.franklin)
			allied_forces_widgets.extend (shangri_la_widget, game.shangri_la)
			widgets.merge (allied_forces_widgets)
		end

	pair_widgets
			-- Associate turn-two to turn-nine widgets with a unit
		do
				-- On Battleship Row (Pearl Harbor)
			allied_forces_widgets.force (nevada_widget, game.nevada)
			allied_forces_widgets.force (arizona_widget, game.arizona)
			allied_forces_widgets.force (west_virginia_widget, game.west_virginia)
			allied_forces_widgets.force (tennessee_widget, game.tennessee)
			allied_forces_widgets.force (oklahoma_widget, game.oklahoma)
			allied_forces_widgets.force (maryland_widget, game.maryland)
			allied_forces_widgets.force (california_widget, game.california)
			allied_forces_widgets.force (pennsylvania_widget, game.pennsylvania)
			allied_forces_widgets.force (new_orleans_widget, game.new_orleans)
			allied_forces_widgets.force (san_francisco_widget, game.san_francisco)
			allied_forces_widgets.force (seventh_af_widget, game.seventh_af)
				-- At sea (cannot move)
			allied_forces_widgets.force (hermes_widget, game.hermes)
			allied_forces_widgets.force (revenge_widget, game.revenge)
			allied_forces_widgets.force (prince_of_wales_widget, game.prince_of_wales)
			allied_forces_widgets.force (repulse_widget, game.repulse)
			allied_forces_widgets.force (fifth_af_widget, game.fifth_af)
			allied_forces_widgets.force (louisville_widget, game.louisville)
			allied_forces_widgets.force (pensacola_widget, game.pensacola)
			allied_forces_widgets.force (indianapolis_widget, game.indianapolis)
			allied_forces_widgets.force (minneapolis_widget, game.minneapolis)
				-- In port (may move)
			allied_forces_widgets.force (houston_widget, game.houston)
			allied_forces_widgets.force (exeter_widget, game.exeter)
			allied_forces_widgets.force (de_ruyter_widget, game.de_ruyter)
			allied_forces_widgets.force (australia_ship_widget, game.australia_ship)
			allied_forces_widgets.force (canberra_widget, game.canberra)
				-- Location Uncertain, group W
			allied_forces_widgets.force (enterprise_widget, game.enterprise)
			allied_forces_widgets.force (salt_lake_city_widget, game.salt_lake_city)
			allied_forces_widgets.force (northampton_widget, game.northampton)
			allied_forces_widgets.force (chester_widget, game.chester)
				-- Location Uncertain, group X
			allied_forces_widgets.force (lexington_widget, game.lexington)
			allied_forces_widgets.force (chicago_widget, game.chicago)
			allied_forces_widgets.force (portland_widget, game.portland)
			allied_forces_widgets.force (astoria_widget, game.astoria)
				-- Location Uncertain, group Y
			allied_forces_widgets.force (saratoga_widget, game.saratoga)
				-- Location Uncertain (group Z
			allied_forces_widgets.force (hornet_widget, game.hornet)
			allied_forces_widgets.force (yorktown_widget, game.yorktown)
			allied_forces_widgets.force (vincennes_widget, game.vincennes)
			allied_forces_widgets.force (quincy_widget, game.quincy)
				-- Turn 2
			allied_forces_widgets.force (royal_sovereign_widget, game.royal_sovereign)
			allied_forces_widgets.force (ramilies_widget, game.ramilies)
			allied_forces_widgets.force (resolution_widget, game.resolution)
			allied_forces_widgets.force (warspite_widget, game.warspite)
			allied_forces_widgets.force (indomitable_widget, game.indomitable)
			allied_forces_widgets.force (formidable_widget, game.formidable)
			allied_forces_widgets.force (cornwall_widget, game.cornwall)
			allied_forces_widgets.force (dorestshire_widget, game.dorestshire)
			allied_forces_widgets.force (new_mexico_widget, game.new_mexico)
			allied_forces_widgets.force (idaho_widget, game.idaho)
			allied_forces_widgets.force (tenth_af_widget, game.tenth_af)
			allied_forces_widgets.force (eleventh_af_widget, game.eleventh_af)
				-- Turn 3
			allied_forces_widgets.force (north_carolina_widget, game.north_carolina)
			allied_forces_widgets.force (mississippi_widget, game.mississippi)
			allied_forces_widgets.force (colorado_widget, game.colorado)
			allied_forces_widgets.force (marines_1_widget, game.marines_1)
			allied_forces_widgets.force (marines_2_widget, game.marines_2)
			allied_forces_widgets.force (raaf_widget, game.raaf)
			allied_forces_widgets.force (rnzaf_widget, game.rnzaf)
			allied_forces_widgets.force (valiant_widget, game.valiant)
			allied_forces_widgets.force (illustrious_widget, game.illustrious)
				-- Turn 4
			allied_forces_widgets.force (south_dakota_widget, game.south_dakota)
			allied_forces_widgets.force (indiana_widget, game.indiana)
			allied_forces_widgets.force (washington_widget, game.washington)
			allied_forces_widgets.force (wasp_widget, game.wasp)
			allied_forces_widgets.force (marine_widget, game.marine)
			allied_forces_widgets.force (thirteenth_af_widget, game.thirteenth_af)
			allied_forces_widgets.force (devonshire_widget, game.devonshire)
			allied_forces_widgets.force (shropshire_widget, game.shropshire)
--			allied_forces_widgets.force (first_027_removal_widget, game.first_027_removal)
--			allied_forces_widgets.force (second_027_removal_widget, game.second_027_removal)
				-- Turn 5
			allied_forces_widgets.force (massachusetts_widget, game.massachusetts)
			allied_forces_widgets.force (wichita_widget, game.wichita)
			allied_forces_widgets.force (victorious_widget, game.victorious)
			allied_forces_widgets.force (marines_3_widget, game.marines_3)
			allied_forces_widgets.force (fourteenth_af_widget, game.fourteenth_af)
			allied_forces_widgets.force (naval_widget, game.naval)
--			allied_forces_widgets.force (resolution_removal_widget, game.resolution_removal)
--			allied_forces_widgets.force (revenge_removal_widget, game.revenge_removal)
--			allied_forces_widgets.force (valiant_removal_widget, game.valiant_removal)
--			allied_forces_widgets.force (warspite_removal_widget, game.warspite_removal)
				-- Turn 6
			allied_forces_widgets.force (alabama_widget, game.alabama)
			allied_forces_widgets.force (essex_widget, game.essex)
			allied_forces_widgets.force (cv_10_widget, game.cv_10)
			allied_forces_widgets.force (cv_16_widget, game.cv_16)
			allied_forces_widgets.force (independence_widget, game.independence)
			allied_forces_widgets.force (princeton_widget, game.princeton)
			allied_forces_widgets.force (belleau_wood_widget, game.belleau_wood)
			allied_forces_widgets.force (cowpens_widget, game.cowpens)
			allied_forces_widgets.force (monterey_widget, game.monterey)
			allied_forces_widgets.force (baltimore_widget, game.baltimore)
			allied_forces_widgets.force (boston_widget, game.boston)
			allied_forces_widgets.force (marines_4_widget, game.marines_4)
--			allied_forces_widgets.force (victorious_removal_widget, game.victorious_removal)
				-- Turn 7
			allied_forces_widgets.force (iowa_widget, game.iowa)
			allied_forces_widgets.force (new_jersey_widget, game.new_jersey)
			allied_forces_widgets.force (intrepid_widget, game.intrepid)
			allied_forces_widgets.force (cv_12_widget, game.cv_12)
			allied_forces_widgets.force (bunker_hill_widget, game.bunker_hill)
			allied_forces_widgets.force (cv_18_widget, game.cv_18)
			allied_forces_widgets.force (bataan_widget, game.bataan)
			allied_forces_widgets.force (cabot_widget, game.cabot)
			allied_forces_widgets.force (langley_ii_widget, game.langley_ii)
			allied_forces_widgets.force (canberra_ii_widget, game.canberra_ii)
			allied_forces_widgets.force (quincy_ii_widget, game.quincy_ii)
			allied_forces_widgets.force (f_boat_widget, game.f_boat)
				-- Turn 8
			allied_forces_widgets.force (wisconsin_widget, game.wisconsin)
			allied_forces_widgets.force (missouri_widget, game.missouri)
			allied_forces_widgets.force (ticonderoga_widget, game.ticonderoga)
			allied_forces_widgets.force (san_jacinto_widget, game.san_jacinto)
			allied_forces_widgets.force (marines_5_widget, game.marines_5)
				-- Turn 9
			allied_forces_widgets.force (new_york_widget, game.new_york)
			allied_forces_widgets.force (texas_widget, game.texas)
			allied_forces_widgets.force (alaska_widget, game.alaska)
			allied_forces_widgets.force (franklin_widget, game.franklin)
			allied_forces_widgets.force (shangri_la_widget, game.shangri_la)
		end

	fill_widgets
			-- Call `set_target' to give each widget a target.
		do
				-- On Battleship Row (Pearl Harbor)
			nevada_widget.set_target (game.nevada)
			arizona_widget.set_target (game.arizona)
			west_virginia_widget.set_target (game.west_virginia)
			tennessee_widget.set_target (game.tennessee)
			oklahoma_widget.set_target (game.oklahoma)
			maryland_widget.set_target (game.maryland)
			california_widget.set_target (game.california)
			pennsylvania_widget.set_target (game.pennsylvania)
			new_orleans_widget.set_target (game.new_orleans)
			san_francisco_widget.set_target (game.san_francisco)
			seventh_af_widget.set_target (game.seventh_af)
				-- At sea (cannot move)
			hermes_widget.set_target (game.hermes)
			revenge_widget.set_target (game.revenge)
			prince_of_wales_widget.set_target (game.prince_of_wales)
			repulse_widget.set_target (game.repulse)
			fifth_af_widget.set_target (game.fifth_af)
			louisville_widget.set_target (game.louisville)
			pensacola_widget.set_target (game.pensacola)
			indianapolis_widget.set_target (game.indianapolis)
			minneapolis_widget.set_target (game.minneapolis)
				-- In port (may move)
			houston_widget.set_target (game.houston)
			exeter_widget.set_target (game.exeter)
			de_ruyter_widget.set_target (game.de_ruyter)
			australia_ship_widget.set_target (game.australia_ship)
			canberra_widget.set_target (game.canberra)
				-- Location Uncertain, group W
			enterprise_widget.set_target (game.enterprise)
			salt_lake_city_widget.set_target (game.salt_lake_city)
			northampton_widget.set_target (game.northampton)
			chester_widget.set_target (game.chester)
				-- Location Uncertain, group X
			lexington_widget.set_target (game.lexington)
			chicago_widget.set_target (game.chicago)
			portland_widget.set_target (game.portland)
			astoria_widget.set_target (game.astoria)
				-- Location Uncertain, group Y
			saratoga_widget.set_target (game.saratoga)
				-- Location Uncertain, group W
			hornet_widget.set_target (game.hornet)
			yorktown_widget.set_target (game.yorktown)
			vincennes_widget.set_target (game.vincennes)
			quincy_widget.set_target (game.quincy)
				-- Turn 2
			royal_sovereign_widget.set_target (game.royal_sovereign)
			ramilies_widget.set_target (game.ramilies)
			resolution_widget.set_target (game.resolution)
			warspite_widget.set_target (game.warspite)
			indomitable_widget.set_target (game.indomitable)
			formidable_widget.set_target (game.formidable)
			cornwall_widget.set_target (game.cornwall)
			dorestshire_widget.set_target (game.dorestshire)
			new_mexico_widget.set_target (game.new_mexico)
			idaho_widget.set_target (game.idaho)
			tenth_af_widget.set_target (game.tenth_af)
			eleventh_af_widget.set_target (game.eleventh_af)
				-- Turn 3
			north_carolina_widget.set_target (game.north_carolina)
			mississippi_widget.set_target (game.mississippi)
			colorado_widget.set_target (game.colorado)
			marines_1_widget.set_target (game.marines_1)
			marines_2_widget.set_target (game.marines_2)
			raaf_widget.set_target (game.raaf)
			rnzaf_widget.set_target (game.rnzaf)
			valiant_widget.set_target (game.valiant)
			illustrious_widget.set_target (game.illustrious)
				-- Turn 4
			south_dakota_widget.set_target (game.south_dakota)
			indiana_widget.set_target (game.indiana)
			washington_widget.set_target (game.washington)
			wasp_widget.set_target (game.wasp)
			marine_widget.set_target (game.marine)
			thirteenth_af_widget.set_target (game.thirteenth_af)
			devonshire_widget.set_target (game.devonshire)
			shropshire_widget.set_target (game.shropshire)
			first_027_removal_widget.set_target (game.first_027_removal)
			second_027_removal_widget.set_target (game.second_027_removal)
				-- Turn 5
			massachusetts_widget.set_target (game.massachusetts)
			wichita_widget.set_target (game.wichita)
			victorious_widget.set_target (game.victorious)
			marines_3_widget.set_target (game.marines_3)
			fourteenth_af_widget.set_target (game.fourteenth_af)
			naval_widget.set_target (game.naval)
			resolution_removal_widget.set_target (game.resolution)
			revenge_removal_widget.set_target (game.revenge)
			valiant_removal_widget.set_target (game.valiant_removal)
			warspite_removal_widget.set_target (game.warspite)
				-- Turn 6
			alabama_widget.set_target (game.alabama)
			essex_widget.set_target (game.essex)
			cv_10_widget.set_target (game.cv_10)
			cv_16_widget.set_target (game.cv_16)
			independence_widget.set_target (game.independence)
			princeton_widget.set_target (game.princeton)
			belleau_wood_widget.set_target (game.belleau_wood)
			cowpens_widget.set_target (game.cowpens)
			monterey_widget.set_target (game.monterey)
			baltimore_widget.set_target (game.baltimore)
			boston_widget.set_target (game.boston)
			marines_4_widget.set_target (game.marines_4)
			victorious_removal_widget.set_target (game.victorious_removal)
				-- Turn 7
			iowa_widget.set_target (game.iowa)
			new_jersey_widget.set_target (game.new_jersey)
			intrepid_widget.set_target (game.intrepid)
			cv_12_widget.set_target (game.cv_12)
			bunker_hill_widget.set_target (game.bunker_hill)
			cv_18_widget.set_target (game.cv_18)
			bataan_widget.set_target (game.bataan)
			cabot_widget.set_target (game.cabot)
			langley_ii_widget.set_target (game.langley_ii)
			canberra_ii_widget.set_target (game.canberra_ii)
			quincy_ii_widget.set_target (game.quincy_ii)
			f_boat_widget.set_target (game.f_boat)
			third_027_removal_widget.set_target (game.third_027_removal)
			first_443_removal_widget.set_target (game.first_443_removal)
				-- Turn 8
			wisconsin_widget.set_target (game.wisconsin)
			missouri_widget.set_target (game.missouri)
			ticonderoga_widget.set_target (game.ticonderoga)
			san_jacinto_widget.set_target (game.san_jacinto)
			marines_5_widget.set_target (game.marines_5)
				-- Turn 9
			new_york_widget.set_target (game.new_york)
			texas_widget.set_target (game.texas)
			alaska_widget.set_target (game.alaska)
			franklin_widget.set_target (game.franklin)
			shangri_la_widget.set_target (game.shangri_la)
		end

end
