note
	description: "[
		Widget representing a {PORT}.
		]"
	author: "Jimmy J. Johnson"

class
	YOKOSUKA_NAVY_YARD_WIDGET

inherit

	RED_PORT_WIDGET
		redefine
			create_interface_objects,
			set_fonts_and_colors,
			position_widgets,
			build_land
		end

create
	make

feature {NONE} -- Initialization

	create_interface_objects
			-- Initialize attributes
		do
			Precursor {RED_PORT_WIDGET}
			hokkaido := hokkaido_imp
			honshu := honshu_imp
			shikoku := shikoku_imp
			kyushu := kyushu_imp
			kunashir := kunashir_imp
			shikotan := shikotan_imp
			iturup := iturup_imp
			urup := urup_imp
			create reinforcements_text.make_with_text ("Japanese Reinforcements")
			create title_text.make_with_text ("VICTORY    PACIFIC")
			create in_the_text.make_with_text (" in%Nthe")
			create copyright_text.make_with_text ("%
				%  Copyright 2020  Jimmy J. Johnson   Boone, CO %N %
				% Based on the game of same name %N %
				% Copyright 1977 The Avalon Hill Game Company, Balto MD")
			extend (reinforcements_text)
			extend (title_text)
			extend (in_the_text)
			extend (copyright_text)
		end

	set_fonts_and_colors
			-- Set the default fonts for any text widgets and set
			-- the default colors for any contained widgets.
		local
			f: EV_FONT
		do
			Precursor {RED_PORT_WIDGET}
			reinforcements_text.set_font (Subtext_font)
				-- Set up the `copyright_text'
			create f
			f.set_height (3)
--			f.set_shape ({EV_FONT_CONSTANTS}.shape_italic)
--			f.set_family ({EV_FONT_CONSTANTS}.family_sans)
			copyright_text.set_font (f)
				-- Set up the `title_text', leaving room with
				-- spaces for placement of the `in_the_text'
			create f
			f.set_height (25)
			f.set_shape ({EV_FONT_CONSTANTS}.shape_italic)
			f.set_family ({EV_FONT_CONSTANTS}.family_sans)
			title_text.set_font (f)
				-- Set up the `in_the_text'
			create f
			f.set_height (12)
			f.set_shape ({EV_FONT_CONSTANTS}.shape_italic)
			f.set_family ({EV_FONT_CONSTANTS}.family_sans)
			in_the_text.set_font (f)
		end

	position_widgets
			-- Move Current and contained widgets to correct
			-- location and set their their sizes
		do
			Precursor {RED_PORT_WIDGET}
				-- position widets
			translate_widget (Current, 453, -295)

			set_x_y (367, 105)
			name_mt.set_x_y (328, 143)
			anchor.set_x_y (335, 130)
			marker.set_x_y (360, 120)
			reinforcements_text.set_x_y (318, 117)
				-- These texts are placed on top of Asia
			title_text.set_x_y (135, 35)
--			in_the_text.set_x_y (110, 35)
			in_the_text.set_x_y (title_text.x + 5, title_text.y - 2)
			copyright_text.set_x_y (50, 55)

--			translate_widget (name_mt, -127, 437)
--			translate_widget (dot, -120, 420)
--			translate_widget (reinforcements_text, -150, 410)
--			translate_widget (title_text, -440, 320)
--			translate_widget (in_the_text, -325, 318)
--			translate_widget (copyright_text, -430, 345)
----			marker.center_on_dot (dot)
--			marker.set_x_y (dot.x, dot.y)
----			anchor.center_on_dot (dot)
--			anchor.set_x_y (dot.x, dot.y)
--			translate_widget (marker, 20, -3)
--			translate_widget (anchor, 0, 3)
			scale_widget (land, 0.13)
			rotate_widget (land, 13.0)
		end

	build_land
			-- Add widgets to Current
		do
			Precursor {RED_PORT_WIDGET}
				-- Initialize attributes
			land.extend (hokkaido)
			land.extend (honshu)
			land.extend (shikoku)
			land.extend (kyushu)
			land.extend (kunashir)
			land.extend (shikotan)
			land.extend (iturup)
			land.extend (urup)
		end

	reinforcements_text: EV_MODEL_TEXT
			-- Extra text about reinforcement placement

	title_text: EV_MODEL_TEXT
			-- The name of game at top left of board.

	in_the_text: EV_MODEL_TEXT
			-- Part of the title text

	copyright_text: EV_MODEL_TEXT
			-- Small text under the `title_text'

feature -- Access

--	defining_figure: EV_MODEL
--			-- The figure to be used to determine if other figures
--			-- overlap this one or for capturing mouse events
--		do
--			Result := honshu
--		end

feature -- Status report

	is_red: BOOLEAN = True
			-- Does Current represent a red (i.e. major) port?

feature {NONE} -- Implementation

	hokkaido: EV_MODEL_POLYGON
	honshu: EV_MODEL_POLYGON
	shikoku: EV_MODEL_POLYGON
	kyushu: EV_MODEL_POLYGON
	kunashir: EV_MODEL_POLYGON
	shikotan: EV_MODEL_POLYGON
	iturup: EV_MODEL_POLYGON
	urup: EV_MODEL_POLYGON

feature {NONE} -- Implementation

	hokkaido_imp: EV_MODEL_POLYGON
			-- Make the polygon
		do
			create Result
				-- Points generated by Grabber application
			Result.extend_point (create {EV_COORDINATE}.make_precise (0, 0))
			Result.extend_point (create {EV_COORDINATE}.make_precise (3.1111111111111995, 2.2222222222222001))
			Result.extend_point (create {EV_COORDINATE}.make_precise (5.3333333333333712, 7.1111111111111143))
			Result.extend_point (create {EV_COORDINATE}.make_precise (9.7777777777778283, 9.3333333333333144))
			Result.extend_point (create {EV_COORDINATE}.make_precise (15.555555555555543, 17.777777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (22.666666666666629, 26.2222222222222))
			Result.extend_point (create {EV_COORDINATE}.make_precise (30.222222222222172, 35.555555555555543))
			Result.extend_point (create {EV_COORDINATE}.make_precise (30.222222222222172, 38.2222222222222))
			Result.extend_point (create {EV_COORDINATE}.make_precise (38.222222222222172, 49.333333333333314))
			Result.extend_point (create {EV_COORDINATE}.make_precise (46.666666666666629, 58.2222222222222))
			Result.extend_point (create {EV_COORDINATE}.make_precise (48.444444444444457, 61.333333333333314))
			Result.extend_point (create {EV_COORDINATE}.make_precise (64, 73.333333333333314))
			Result.extend_point (create {EV_COORDINATE}.make_precise (66.666666666666629, 76.888888888888857))
			Result.extend_point (create {EV_COORDINATE}.make_precise (81.777777777777828, 84))
			Result.extend_point (create {EV_COORDINATE}.make_precise (79.555555555555543, 85.777777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (82.222222222222172, 89.777777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (89.333333333333371, 90.222222222222172))
			Result.extend_point (create {EV_COORDINATE}.make_precise (92.8888888888888, 92))
			Result.extend_point (create {EV_COORDINATE}.make_precise (93.333333333333371, 89.333333333333314))
			Result.extend_point (create {EV_COORDINATE}.make_precise (100.8888888888888, 89.333333333333314))
			Result.extend_point (create {EV_COORDINATE}.make_precise (97.333333333333371, 94.666666666666629))
			Result.extend_point (create {EV_COORDINATE}.make_precise (100.8888888888888, 95.111111111111086))
			Result.extend_point (create {EV_COORDINATE}.make_precise (102.66666666666663, 91.111111111111086))
			Result.extend_point (create {EV_COORDINATE}.make_precise (105.77777777777783, 90.222222222222172))
			Result.extend_point (create {EV_COORDINATE}.make_precise (106.22222222222217, 95.111111111111086))
			Result.extend_point (create {EV_COORDINATE}.make_precise (110.22222222222217, 100.88888888888886))
			Result.extend_point (create {EV_COORDINATE}.make_precise (114.22222222222217, 100.88888888888886))
			Result.extend_point (create {EV_COORDINATE}.make_precise (129.33333333333337, 101.33333333333331))
			Result.extend_point (create {EV_COORDINATE}.make_precise (132.8888888888888, 98.666666666666629))
			Result.extend_point (create {EV_COORDINATE}.make_precise (136.44444444444446, 96))
			Result.extend_point (create {EV_COORDINATE}.make_precise (139.55555555555554, 92))
			Result.extend_point (create {EV_COORDINATE}.make_precise (144.44444444444446, 85.333333333333314))
			Result.extend_point (create {EV_COORDINATE}.make_precise (148.8888888888888, 84.444444444444457))
			Result.extend_point (create {EV_COORDINATE}.make_precise (149.33333333333337, 81.777777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (152, 79.555555555555543))
			Result.extend_point (create {EV_COORDINATE}.make_precise (153.77777777777783, 75.111111111111086))
			Result.extend_point (create {EV_COORDINATE}.make_precise (156, 77.333333333333314))
			Result.extend_point (create {EV_COORDINATE}.make_precise (157.33333333333337, 80))
			Result.extend_point (create {EV_COORDINATE}.make_precise (155.55555555555554, 84.888888888888857))
			Result.extend_point (create {EV_COORDINATE}.make_precise (152.8888888888888, 88.888888888888857))
			Result.extend_point (create {EV_COORDINATE}.make_precise (150.66666666666663, 90.666666666666629))
			Result.extend_point (create {EV_COORDINATE}.make_precise (151.1111111111112, 93.777777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (148.44444444444446, 95.111111111111086))
			Result.extend_point (create {EV_COORDINATE}.make_precise (146.22222222222217, 99.555555555555543))
			Result.extend_point (create {EV_COORDINATE}.make_precise (144.8888888888888, 106.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (144, 108.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (143.1111111111112, 113.33333333333331))
			Result.extend_point (create {EV_COORDINATE}.make_precise (145.33333333333337, 115.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (146.22222222222217, 119.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (149.33333333333337, 120.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (151.55555555555554, 127.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (152.8888888888888, 134.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (153.77777777777783, 138.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (153.77777777777783, 141.77777777777777))
			Result.extend_point (create {EV_COORDINATE}.make_precise (156.8888888888888, 141.77777777777777))
			Result.extend_point (create {EV_COORDINATE}.make_precise (163.1111111111112, 140.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (168, 136.88888888888886))
			Result.extend_point (create {EV_COORDINATE}.make_precise (169.33333333333337, 135.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (172.44444444444446, 135.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (176.8888888888888, 135.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (176, 137.77777777777777))
			Result.extend_point (create {EV_COORDINATE}.make_precise (172, 139.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (167.55555555555554, 140.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (165.33333333333337, 144.88888888888886))
			Result.extend_point (create {EV_COORDINATE}.make_precise (164, 147.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (160.44444444444446, 148))
			Result.extend_point (create {EV_COORDINATE}.make_precise (153.33333333333337, 148))
			Result.extend_point (create {EV_COORDINATE}.make_precise (149.77777777777783, 151.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (146.66666666666663, 151.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (145.33333333333337, 155.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (142.66666666666663, 158.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (137.77777777777783, 160.88888888888886))
			Result.extend_point (create {EV_COORDINATE}.make_precise (133.77777777777783, 159.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (133.77777777777783, 156.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (130.22222222222217, 158.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (128.44444444444446, 160.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (130.66666666666663, 162.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (126.66666666666663, 163.99999999999994))
			Result.extend_point (create {EV_COORDINATE}.make_precise (120.44444444444446, 162.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (116.44444444444446, 163.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (109.77777777777783, 161.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (105.33333333333337, 160.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (96.444444444444457, 164.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (86.666666666666629, 172.88888888888886))
			Result.extend_point (create {EV_COORDINATE}.make_precise (79.555555555555543, 179.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (71.555555555555543, 188.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (65.333333333333371, 199.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (63.555555555555543, 205.77777777777777))
			Result.extend_point (create {EV_COORDINATE}.make_precise (64.444444444444457, 208.88888888888886))
			Result.extend_point (create {EV_COORDINATE}.make_precise (64, 214.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (62.666666666666629, 219.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (60.444444444444457, 220.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (60.444444444444457, 224.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (56.444444444444457, 223.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (54.222222222222172, 219.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (48, 216.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (46.222222222222172, 214.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (42.222222222222172, 213.77777777777777))
			Result.extend_point (create {EV_COORDINATE}.make_precise (37.777777777777828, 211.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (29.333333333333371, 206.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (25.777777777777828, 206.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (24, 203.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (17.777777777777828, 199.99999999999994))
			Result.extend_point (create {EV_COORDINATE}.make_precise (13.777777777777828, 196.88888888888886))
			Result.extend_point (create {EV_COORDINATE}.make_precise (11.555555555555543, 192.88888888888886))
			Result.extend_point (create {EV_COORDINATE}.make_precise (5.7777777777778283, 193.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-0.88888888888880047, 187.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-8.8888888888888005, 183.99999999999994))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-17.333333333333371, 183.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-24.8888888888888, 187.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-29.777777777777715, 191.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-34.666666666666629, 195.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-42.666666666666629, 203.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-46.666666666666629, 197.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-50.222222222222172, 191.99999999999994))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-56.444444444444457, 186.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-60.444444444444457, 187.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-63.555555555555543, 185.77777777777777))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-66.666666666666629, 187.99999999999994))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-69.333333333333371, 192.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-71.555555555555543, 198.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-73.777777777777715, 203.99999999999994))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-72.444444444444457, 206.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-68.444444444444457, 208.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-64, 211.99999999999994))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-61.777777777777715, 215.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-57.777777777777715, 213.77777777777777))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-54.222222222222172, 213.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-52, 216.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-48.444444444444457, 219.99999999999994))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-45.777777777777715, 221.77777777777777))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-43.555555555555543, 227.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-39.555555555555543, 227.99999999999994))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-36, 229.77777777777777))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-33.777777777777715, 233.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-36, 234.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-38.222222222222172, 236.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-41.777777777777715, 239.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-45.777777777777715, 237.77777777777777))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-50.222222222222172, 236.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-54.666666666666629, 236.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-55.111111111111086, 234.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-59.111111111111086, 233.77777777777777))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-59.111111111111086, 236.88888888888886))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-62.666666666666629, 239.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-65.333333333333371, 239.99999999999994))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-67.555555555555543, 243.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-67.555555555555543, 248.88888888888886))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-71.555555555555543, 251.99999999999994))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-76.444444444444457, 252.88888888888886))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-76.8888888888888, 256.88888888888886))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-78.666666666666629, 259.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-80.444444444444457, 256.88888888888886))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-83.555555555555543, 256.88888888888886))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-86.666666666666629, 250.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-88.444444444444457, 243.99999999999994))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-84.8888888888888, 237.77777777777777))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-84.8888888888888, 232.88888888888886))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-81.777777777777715, 232.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-80.8888888888888, 224.88888888888886))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-82.222222222222172, 219.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-86.666666666666629, 213.77777777777777))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-89.333333333333371, 213.77777777777777))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-92, 211.99999999999994))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-93.777777777777715, 207.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-96.444444444444457, 208.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-96.8888888888888, 204.88888888888886))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-98.222222222222172, 199.99999999999994))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-95.111111111111086, 197.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-93.777777777777715, 192.88888888888886))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-95.555555555555543, 185.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-92.8888888888888, 179.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-84.8888888888888, 179.99999999999994))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-83.555555555555543, 175.99999999999994))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-80, 174.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-79.555555555555543, 171.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-76.444444444444457, 173.77777777777777))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-73.777777777777715, 172.88888888888886))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-74.222222222222172, 170.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-70.666666666666629, 166.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-69.777777777777715, 163.99999999999994))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-64, 160.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-63.555555555555543, 155.99999999999994))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-66.222222222222172, 153.33333333333331))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-67.111111111111086, 150.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-69.777777777777715, 148.88888888888886))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-72.444444444444457, 144.88888888888886))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-71.555555555555543, 139.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-67.555555555555543, 139.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-66.222222222222172, 136.88888888888886))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-61.777777777777715, 140.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-58.222222222222172, 141.33333333333331))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-57.777777777777715, 144.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-54.222222222222172, 144))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-51.111111111111086, 147.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-43.111111111111086, 144))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-36.8888888888888, 144.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-30.666666666666629, 145.33333333333331))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-24.8888888888888, 142.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-22.666666666666629, 135.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-22.666666666666629, 129.77777777777777))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-24.8888888888888, 126.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-24, 121.77777777777777))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-26.222222222222172, 120.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-26.666666666666629, 115.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-24.8888888888888, 109.33333333333331))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-17.777777777777715, 107.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-12.444444444444457, 100.88888888888886))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-12, 85.777777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-12.8888888888888, 79.111111111111086))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-9.3333333333333712, 70.666666666666629))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-6.6666666666666288, 62.2222222222222))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-5.3333333333333712, 60.888888888888857))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-5.7777777777777146, 50.666666666666657))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-8.4444444444444571, 38.666666666666657))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-12.8888888888888, 27.111111111111114))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-15.111111111111086, 23.111111111111114))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-16, 18.2222222222222))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-13.333333333333371, 14.2222222222222))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-12, 10.666666666666657))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-13.777777777777715, 7.1111111111111143))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-12.8888888888888, 4.4444444444444571))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-10.666666666666629, 7.1111111111111143))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-8.4444444444444571, 8))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-3.1111111111110858, 5.7777777777777715))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-2.2222222222221717, 2.2222222222222001))
		end

	honshu_imp: EV_MODEL_POLYGON
			-- Make the polygon
		do
			create Result
				-- Points generated by Grabber application
			Result.extend_point (create {EV_COORDINATE}.make_precise (-71.555555555555543, 267.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-69.777777777777715, 267.99999999999994))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-66.666666666666629, 271.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-63.111111111111086, 268.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-59.111111111111086, 270.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-58.222222222222172, 274.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-59.111111111111086, 280.88888888888886))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-56.444444444444457, 290.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-51.111111111111086, 291.99999999999994))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-49.333333333333371, 286.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-44.444444444444457, 283.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-38.666666666666629, 286.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-35.555555555555543, 287.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-31.111111111111086, 281.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-32, 276.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-29.333333333333371, 271.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-34.222222222222172, 263.99999999999994))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-36, 267.99999999999994))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-39.555555555555543, 270.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-43.555555555555543, 269.77777777777777))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-47.111111111111086, 271.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-50.666666666666629, 273.77777777777777))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-53.333333333333371, 272.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-51.111111111111086, 262.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-46.666666666666629, 252.88888888888886))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-46.222222222222172, 248.88888888888886))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-43.111111111111086, 252.88888888888886))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-38.666666666666629, 252.88888888888886))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-33.333333333333371, 257.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-30.222222222222172, 260.88888888888886))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-26.222222222222172, 259.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-21.333333333333371, 256.88888888888886))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-20.8888888888888, 259.99999999999994))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-22.222222222222172, 263.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-24.444444444444457, 279.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-24.444444444444457, 284.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-26.222222222222172, 283.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-24.8888888888888, 287.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-23.111111111111086, 295.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-21.333333333333371, 306.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-19.111111111111086, 310.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-15.555555555555543, 310.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-10.666666666666629, 314.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-4, 327.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-4.4444444444444571, 331.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1.3333333333333712, 333.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-3.5555555555555429, 333.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-0.88888888888880047, 340.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1.7777777777778283, 343.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (0.44444444444445708, 347.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (3.1111111111111995, 350.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (3.5555555555555429, 362.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (5.3333333333333712, 366.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (4, 370.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (6.2222222222222854, 372.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (2.2222222222222854, 376.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (2.2222222222222854, 381.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (0, 382.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (0.44444444444445708, 387.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1.7777777777777146, 389.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1.7777777777777146, 392.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-3.5555555555555429, 396.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-3.5555555555555429, 400.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-8, 398.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-9.3333333333333712, 401.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-12, 401.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-12, 404.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-12.8888888888888, 407.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-16.444444444444457, 412.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-16, 417.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-20.8888888888888, 419.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-17.777777777777715, 421.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-20.444444444444457, 426.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-17.777777777777715, 427.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-19.555555555555543, 431.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-20.8888888888888, 433.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-18.666666666666629, 437.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-17.777777777777715, 440.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-15.111111111111086, 442.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-17.333333333333371, 443.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-20.444444444444457, 439.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-22.666666666666629, 436.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-28, 435.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-29.777777777777715, 438.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-36.444444444444457, 439.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-41.777777777777715, 446.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-44.444444444444457, 454.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-45.333333333333371, 461.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-43.111111111111086, 471.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-41.333333333333371, 476.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-39.111111111111086, 486.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-40, 497.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-40.444444444444457, 510.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-42.222222222222172, 512.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-43.111111111111086, 519.55555555555543))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-50.666666666666629, 521.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-52.8888888888888, 531.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-57.777777777777715, 542.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-58.666666666666629, 550.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-61.777777777777715, 551.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-60.8888888888888, 560.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-58.222222222222172, 569.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-53.333333333333371, 580.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-47.111111111111086, 587.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-52, 590.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-58.666666666666629, 591.55555555555543))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-64.444444444444457, 597.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-68.8888888888888, 604.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-68.444444444444457, 613.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-69.777777777777715, 618.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-75.111111111111086, 622.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-80.8888888888888, 623.55555555555543))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-83.555555555555543, 625.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-87.111111111111086, 626.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-88.8888888888888, 630.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-89.777777777777715, 634.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-93.777777777777715, 635.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-96, 632.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-98.222222222222172, 631.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-94.666666666666629, 629.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-93.333333333333371, 627.55555555555543))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-94.666666666666629, 621.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-96.8888888888888, 619.55555555555543))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-98.666666666666629, 615.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-98.666666666666629, 611.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-93.777777777777715, 607.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-88.444444444444457, 602.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-84.444444444444457, 598.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-84.8888888888888, 594.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-89.777777777777715, 592.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-91.555555555555543, 594.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-95.555555555555543, 594.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-95.111111111111086, 597.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-96.8888888888888, 602.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-100.8888888888888, 603.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-104.8888888888888, 607.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-102.66666666666663, 610.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-100, 615.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-100, 619.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-103.11111111111109, 619.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-106.66666666666663, 618.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-111.11111111111109, 615.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-120.44444444444446, 616.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-125.77777777777771, 619.55555555555543))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-129.33333333333337, 624.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-128, 626.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-128.8888888888888, 628.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-125.77777777777771, 630.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-125.77777777777771, 634.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-128.8888888888888, 635.55555555555543))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-129.33333333333337, 641.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-133.77777777777771, 643.55555555555543))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-134.22222222222217, 647.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-137.33333333333337, 650.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-142.22222222222217, 650.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-143.55555555555554, 647.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-145.33333333333337, 645.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-142.66666666666663, 642.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-144.44444444444446, 640.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-144, 634.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-141.77777777777771, 634.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-144.44444444444446, 629.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-142.66666666666663, 627.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-140, 627.55555555555543))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-137.33333333333337, 624.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-144, 625.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-154.22222222222217, 626.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-155.11111111111109, 629.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-161.33333333333331, 633.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-163.55555555555549, 635.55555555555543))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-162.66666666666663, 639.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-165.77777777777771, 642.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-169.33333333333331, 646.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-169.33333333333331, 651.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-175.11111111111109, 649.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-183.11111111111109, 647.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-191.11111111111109, 648.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-200.4444444444444, 647.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-206.66666666666663, 649.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-216.8888888888888, 651.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-222.22222222222217, 653.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-221.33333333333331, 647.55555555555543))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-220.4444444444444, 649.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-214.22222222222217, 647.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-213.33333333333331, 644.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-210.22222222222217, 644.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-209.77777777777771, 639.55555555555543))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-214.22222222222217, 639.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-215.11111111111109, 642.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-217.33333333333331, 640.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-222.22222222222217, 641.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-225.77777777777771, 638.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-225.33333333333331, 635.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-228, 641.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-225.33333333333331, 644.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-225.77777777777771, 646.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-230.22222222222217, 643.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-230.66666666666663, 638.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-234.22222222222217, 636.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-241.33333333333331, 635.55555555555543))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-246.22222222222217, 643.55555555555543))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-244, 650.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-238.66666666666663, 651.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-236.8888888888888, 656.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-229.77777777777771, 656.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-227.11111111111109, 661.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-228, 663.55555555555543))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-230.66666666666663, 663.55555555555543))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-228.4444444444444, 667.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-232.4444444444444, 667.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-232.4444444444444, 671.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-234.22222222222217, 668.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-237.33333333333331, 667.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-238.22222222222217, 665.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-240, 667.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-241.33333333333331, 669.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-244, 668.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-247.11111111111109, 670.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-253.77777777777771, 673.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-257.77777777777771, 678.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-262.66666666666663, 686.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-263.55555555555549, 689.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-267.11111111111109, 695.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-271.11111111111109, 705.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-274.22222222222217, 710.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-279.55555555555549, 711.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-279.55555555555549, 715.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-282.22222222222217, 711.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-291.55555555555549, 712.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-299.11111111111109, 706.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-297.33333333333331, 700.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-300, 696.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-305.77777777777771, 695.55555555555543))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-308.4444444444444, 691.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-311.55555555555549, 691.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-310.66666666666663, 684.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-308.8888888888888, 683.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-311.55555555555549, 678.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-308.4444444444444, 677.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-307.11111111111109, 674.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-309.77777777777771, 671.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-314.66666666666663, 668.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-309.33333333333331, 665.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-304, 662.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-300.4444444444444, 656.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-299.55555555555549, 651.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-296.4444444444444, 650.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-296.4444444444444, 647.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-300.8888888888888, 646.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-304.8888888888888, 646.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-304.8888888888888, 648.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-312.4444444444444, 651.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-315.55555555555549, 655.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-319.55555555555549, 662.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-317.77777777777771, 667.55555555555543))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-318.22222222222217, 670.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-321.77777777777771, 671.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-328.4444444444444, 673.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-331.55555555555549, 671.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-330.66666666666663, 666.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-326.66666666666663, 663.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-324, 659.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-320.8888888888888, 654.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-318.22222222222217, 651.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-316.4444444444444, 648.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-320.8888888888888, 646.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-326.22222222222217, 641.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-338.22222222222217, 641.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-342.22222222222217, 644.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-348.4444444444444, 646.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-352.4444444444444, 649.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-358.22222222222217, 651.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-358.22222222222217, 656.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-352.8888888888888, 656.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-345.33333333333326, 653.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-345.33333333333326, 658.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-350.66666666666663, 658.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-355.99999999999994, 657.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-360.8888888888888, 657.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-365.77777777777771, 659.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-371.11111111111109, 658.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-375.55555555555549, 656.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-379.99999999999994, 658.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-384.8888888888888, 659.55555555555543))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-387.99999999999994, 663.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-393.77777777777771, 665.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-394.66666666666663, 662.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-399.11111111111109, 664.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-396.8888888888888, 667.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-400.8888888888888, 671.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-402.22222222222217, 666.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-409.77777777777771, 666.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-414.66666666666663, 667.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-415.11111111111109, 671.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-415.55555555555549, 677.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-431.11111111111109, 677.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-431.55555555555549, 670.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-427.99999999999994, 666.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-431.11111111111109, 665.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-436.4444444444444, 666.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-437.77777777777771, 669.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-438.66666666666663, 675.55555555555543))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-442.22222222222217, 678.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-441.77777777777771, 684.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-445.77777777777771, 686.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-443.11111111111109, 687.55555555555543))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-440.4444444444444, 686.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-436.4444444444444, 687.55555555555543))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-435.55555555555549, 690.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-439.99999999999994, 690.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-444.8888888888888, 691.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-450.22222222222217, 688.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-455.11111111111109, 686.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-458.66666666666663, 683.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-463.99999999999994, 682.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-469.33333333333326, 682.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-470.66666666666663, 684.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-474.22222222222217, 682.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-476.4444444444444, 684.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-479.11111111111109, 682.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-481.33333333333326, 685.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-481.33333333333326, 688.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-484.8888888888888, 689.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-486.22222222222217, 686.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-489.77777777777771, 686.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-489.33333333333326, 683.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-485.77777777777771, 681.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-491.55555555555549, 680.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-495.99999999999994, 679.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-498.66666666666663, 683.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-500.8888888888888, 686.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-502.22222222222217, 677.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-503.55555555555549, 673.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-502.22222222222217, 669.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-501.77777777777771, 664.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-495.55555555555549, 663.55555555555543))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-495.99999999999994, 661.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-492.4444444444444, 661.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-489.77777777777771, 663.55555555555543))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-479.11111111111109, 660.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-475.99999999999994, 655.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-471.55555555555549, 651.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-470.22222222222217, 646.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-468.8888888888888, 647.55555555555543))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-461.33333333333326, 646.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-451.55555555555549, 638.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-440.4444444444444, 626.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-431.99999999999994, 615.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-421.77777777777771, 610.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-423.55555555555549, 606.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-418.22222222222217, 603.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-415.11111111111109, 601.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-408.8888888888888, 599.55555555555543))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-406.22222222222217, 593.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-402.22222222222217, 593.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-397.33333333333326, 594.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-393.77777777777771, 599.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-391.55555555555549, 603.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-388.8888888888888, 603.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-383.55555555555549, 599.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-377.33333333333326, 599.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-363.99999999999994, 599.55555555555543))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-360.4444444444444, 596.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-354.22222222222217, 597.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-347.55555555555549, 595.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-342.22222222222217, 591.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-334.66666666666663, 587.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-331.11111111111109, 591.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-324, 590.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-320.8888888888888, 592.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-316.4444444444444, 591.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-310.22222222222217, 587.55555555555543))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-304, 585.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-300, 590.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-303.55555555555549, 594.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-302.66666666666663, 599.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-297.77777777777771, 597.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-293.77777777777771, 596.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-291.55555555555549, 599.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-289.77777777777771, 601.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-285.77777777777771, 599.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-285.77777777777771, 601.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-282.22222222222217, 600.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-282.22222222222217, 598.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-278.22222222222217, 598.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-276, 595.55555555555543))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-278.22222222222217, 593.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-273.77777777777771, 594.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-271.55555555555549, 593.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-271.55555555555549, 587.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-268, 587.55555555555543))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-267.11111111111109, 591.55555555555543))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-264, 591.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-264.4444444444444, 586.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-264.4444444444444, 583.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-267.11111111111109, 582.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-270.66666666666663, 580.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-272, 584.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-272.8888888888888, 578.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-273.33333333333331, 573.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-270.22222222222217, 571.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-266.66666666666663, 562.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-264, 561.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-264.4444444444444, 558.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-260, 555.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-256.4444444444444, 551.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-252.4444444444444, 546.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-248, 544.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-244.4444444444444, 539.55555555555543))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-239.11111111111109, 533.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-236, 523.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-236, 519.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-235.11111111111109, 517.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-236, 514.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-236, 508.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-238.66666666666663, 508.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-237.77777777777771, 502.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-235.55555555555549, 501.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-236, 495.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-229.33333333333331, 492.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-225.77777777777771, 493.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-220.4444444444444, 489.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-216, 487.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-210.22222222222217, 486.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-208, 488.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-208.4444444444444, 491.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-212, 491.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-212.4444444444444, 495.55555555555543))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-211.11111111111109, 497.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-216, 499.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-219.11111111111109, 499.55555555555543))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-222.22222222222217, 505.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-225.33333333333331, 505.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-227.11111111111109, 502.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-228.8888888888888, 506.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-229.77777777777771, 511.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-224.8888888888888, 513.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-223.55555555555549, 510.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-225.77777777777771, 510.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-221.33333333333331, 508.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-221.33333333333331, 513.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-221.33333333333331, 518.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-220.8888888888888, 526.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-216.8888888888888, 528.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-209.77777777777771, 527.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-205.77777777777771, 521.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-200.4444444444444, 516.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-192, 515.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-180.8888888888888, 510.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-174.22222222222217, 505.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-167.55555555555549, 504.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-157.33333333333331, 495.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-153.33333333333337, 494.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-151.11111111111109, 491.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-151.11111111111109, 488.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-146.22222222222217, 484.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-144, 478.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-142.22222222222217, 468.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-136.8888888888888, 466.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-132.8888888888888, 461.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-123.55555555555554, 459.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-116, 452.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-112.44444444444446, 445.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-112.44444444444446, 434.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-110.22222222222217, 427.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-102.66666666666663, 415.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-99.111111111111086, 414.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-96.444444444444457, 403.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-92.8888888888888, 387.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-91.555555555555543, 383.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-87.555555555555543, 378.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-85.333333333333371, 362.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-85.777777777777715, 354.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-88, 354.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-91.111111111111086, 351.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-93.777777777777715, 353.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-96.8888888888888, 353.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-97.777777777777715, 349.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-102.22222222222217, 342.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-98.222222222222172, 343.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-96, 344.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-91.555555555555543, 340.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-87.555555555555543, 327.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-86.666666666666629, 320.88888888888886))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-88.8888888888888, 317.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-89.777777777777715, 309.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-92.8888888888888, 306.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-91.555555555555543, 303.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-86.666666666666629, 296.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-84, 295.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-82.222222222222172, 297.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-77.777777777777715, 294.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-74.666666666666629, 291.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-73.333333333333371, 279.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-72.8888888888888, 275.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-75.111111111111086, 274.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-72.444444444444457, 273.33333333333326))
		end

	shikoku_imp: EV_MODEL_POLYGON
			-- Make the polygon
		do
			create Result
				-- Points generated by Grabber application
			Result.extend_point (create {EV_COORDINATE}.make_precise (-407.55555555555549, 677.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-407.99999999999994, 680.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-404.4444444444444, 682.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-403.11111111111109, 687.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-394.66666666666663, 685.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-388.8888888888888, 683.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-384.8888888888888, 685.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-378.66666666666663, 680.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-384.8888888888888, 679.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-383.55555555555549, 669.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-377.33333333333326, 670.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-369.77777777777771, 665.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-364.4444444444444, 662.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-357.77777777777771, 663.55555555555543))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-352.8888888888888, 662.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-353.77777777777771, 665.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-343.99999999999994, 668.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-343.11111111111109, 672.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-335.55555555555549, 670.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-331.55555555555549, 675.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-331.99999999999994, 679.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-334.66666666666663, 682.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-331.11111111111109, 685.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-327.99999999999994, 690.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-330.66666666666663, 693.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-335.11111111111109, 700.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-340.4444444444444, 702.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-344.8888888888888, 709.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-352.4444444444444, 725.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-359.99999999999994, 715.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-362.66666666666663, 715.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-364.8888888888888, 711.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-370.22222222222217, 711.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-375.11111111111109, 710.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-383.55555555555549, 712.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-386.66666666666663, 716.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-391.99999999999994, 718.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-394.22222222222217, 721.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-395.11111111111109, 727.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-399.55555555555549, 732.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-401.33333333333326, 737.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-404.8888888888888, 738.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-405.33333333333326, 744.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-408.8888888888888, 745.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-406.66666666666663, 748.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-404.8888888888888, 753.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-407.55555555555549, 753.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-409.33333333333326, 751.55555555555543))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-412.8888888888888, 751.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-416.4444444444444, 752.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-419.11111111111109, 750.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-423.11111111111109, 751.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-421.77777777777771, 746.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-418.22222222222217, 745.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-420.8888888888888, 742.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-424.8888888888888, 743.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-428.8888888888888, 743.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-428.8888888888888, 739.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-431.99999999999994, 736.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-430.66666666666663, 734.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-430.22222222222217, 731.55555555555543))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-432.8888888888888, 730.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-428.4444444444444, 728.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-428.4444444444444, 725.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-429.77777777777771, 723.55555555555543))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-428.4444444444444, 721.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-433.33333333333326, 721.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-433.33333333333326, 719.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-435.11111111111109, 718.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-432.4444444444444, 713.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-435.11111111111109, 712.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-440.8888888888888, 715.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-445.77777777777771, 718.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-450.66666666666663, 719.55555555555543))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-446.66666666666663, 715.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-443.11111111111109, 714.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-438.22222222222217, 711.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-433.77777777777771, 708.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-431.11111111111109, 705.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-423.99999999999994, 701.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-419.99999999999994, 693.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-416.8888888888888, 687.55555555555543))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-416.4444444444444, 683.55555555555543))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-411.55555555555549, 680.44444444444446))
		end

	kyushu_imp: EV_MODEL_POLYGON
			-- Make the polygon
		do
			create Result
				-- Points generated by Grabber application
			Result.extend_point (create {EV_COORDINATE}.make_precise (-502.66666666666663, 687.55555555555543))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-496.4444444444444, 686.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-496.8888888888888, 692.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-496.8888888888888, 699.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-491.55555555555549, 703.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-486.66666666666663, 704.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-484.4444444444444, 706.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-477.77777777777771, 706.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-474.66666666666663, 703.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-472.4444444444444, 701.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-467.11111111111109, 701.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-463.55555555555549, 705.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-463.55555555555549, 713.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-466.66666666666663, 719.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-472.4444444444444, 719.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-475.99999999999994, 717.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-472.4444444444444, 722.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-467.11111111111109, 723.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-461.77777777777771, 725.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-455.55555555555549, 723.55555555555543))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-458.66666666666663, 730.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-455.99999999999994, 733.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-451.11111111111109, 733.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-451.99999999999994, 736.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-455.11111111111109, 737.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-455.11111111111109, 740.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-450.66666666666663, 740.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-451.55555555555549, 744.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-452.4444444444444, 748.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-457.77777777777771, 748.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-456.8888888888888, 751.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-458.22222222222217, 756.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-459.99999999999994, 755.55555555555543))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-462.66666666666663, 759.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-465.77777777777771, 760.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-463.55555555555549, 765.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-465.33333333333326, 770.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-467.11111111111109, 774.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-471.11111111111109, 782.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-474.66666666666663, 794.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-475.99999999999994, 800.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-474.66666666666663, 803.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-476.8888888888888, 808.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-475.99999999999994, 811.55555555555543))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-476.8888888888888, 814.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-478.66666666666663, 815.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-479.11111111111109, 820.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-480.8888888888888, 824.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-485.33333333333326, 826.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-487.55555555555549, 823.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-491.55555555555549, 821.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-495.55555555555549, 822.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-495.11111111111109, 827.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-492.4444444444444, 828.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-493.33333333333326, 830.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-491.11111111111109, 831.55555555555543))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-493.33333333333326, 834.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-496.8888888888888, 834.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-497.77777777777771, 837.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-501.77777777777771, 840.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-506.66666666666663, 842.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-512.44444444444434, 847.11111111111097))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-511.99999999999994, 843.11111111111097))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-513.77777777777771, 841.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-509.77777777777771, 839.55555555555532))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-508.44444444444434, 837.33333333333314))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-507.99999999999994, 832.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-506.22222222222217, 831.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-507.11111111111103, 826.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-508.8888888888888, 822.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-511.55555555555549, 821.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-509.77777777777771, 816.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-507.55555555555549, 815.55555555555543))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-505.77777777777771, 810.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-509.33333333333326, 806.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-512.44444444444434, 809.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-509.77777777777771, 813.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-511.99999999999994, 817.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-515.11111111111109, 817.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-518.22222222222217, 818.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-518.22222222222217, 823.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-516, 830.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-512.44444444444434, 831.55555555555543))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-513.77777777777771, 837.33333333333314))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-520, 837.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-519.55555555555543, 834.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-523.55555555555543, 832.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-532.44444444444434, 832.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-533.77777777777771, 827.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-536, 823.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-533.33333333333326, 824.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-531.11111111111109, 823.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-528, 819.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-528.8888888888888, 811.55555555555543))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-533.77777777777771, 808.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-533.77777777777771, 800.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-533.33333333333326, 795.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-534.66666666666663, 789.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-536.8888888888888, 785.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-537.77777777777771, 781.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-535.11111111111109, 780.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-532.8888888888888, 785.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-529.33333333333326, 786.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-524, 778.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-520.8888888888888, 775.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-519.11111111111109, 768.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-517.77777777777771, 764.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-514.22222222222217, 759.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-517.77777777777771, 759.55555555555543))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-520.8888888888888, 756.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-515.55555555555543, 754.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-515.55555555555543, 749.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-518.66666666666663, 747.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-520.44444444444434, 743.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-523.55555555555543, 743.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-524.8888888888888, 738.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-523.55555555555543, 735.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-527.11111111111109, 731.55555555555543))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-526.66666666666663, 724.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-529.33333333333326, 730.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-531.11111111111109, 728.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-535.55555555555543, 732.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-531.11111111111109, 734.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-532.44444444444434, 739.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-536.44444444444434, 745.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-535.11111111111109, 748.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-530.66666666666663, 745.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-528, 746.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-526.66666666666663, 751.55555555555543))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-527.11111111111109, 758.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-523.11111111111109, 758.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-521.77777777777771, 763.55555555555543))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-523.11111111111109, 768.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-524.44444444444434, 771.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-529.77777777777771, 771.55555555555543))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-532.8888888888888, 770.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-532.8888888888888, 775.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-536.44444444444434, 775.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-537.33333333333326, 778.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-541.33333333333326, 782.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-543.55555555555543, 777.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-543.11111111111109, 772.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-540, 762.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-537.33333333333326, 755.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-535.11111111111109, 754.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-535.11111111111109, 750.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-539.55555555555543, 750.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-544.44444444444434, 751.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-547.11111111111109, 755.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-549.77777777777771, 759.55555555555543))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-550.66666666666663, 763.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-552.44444444444434, 761.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-551.11111111111109, 755.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-552.44444444444434, 750.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-554.66666666666663, 748.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-559.11111111111109, 743.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-559.11111111111109, 738.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-557.77777777777771, 733.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-554.22222222222217, 736.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-551.11111111111109, 739.55555555555543))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-551.55555555555543, 743.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-549.77777777777771, 747.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-545.33333333333326, 745.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-546.22222222222217, 740.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-548.44444444444434, 735.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-552.8888888888888, 735.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-556.8888888888888, 731.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-559.11111111111109, 728.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-563.11111111111109, 727.55555555555543))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-560.8888888888888, 722.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-562.66666666666663, 720.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-565.33333333333326, 723.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-571.11111111111109, 729.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-569.77777777777771, 725.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-567.99999999999989, 719.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-563.99999999999989, 716.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-559.99999999999989, 719.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-556.8888888888888, 719.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-552.8888888888888, 719.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-551.11111111111109, 721.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-548.8888888888888, 715.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-555.55555555555543, 713.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-550.22222222222217, 713.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-548.44444444444434, 709.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-544.8888888888888, 709.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-544.44444444444434, 713.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-539.55555555555543, 713.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-540, 711.55555555555543))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-536.8888888888888, 710.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-536.44444444444434, 708.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-539.11111111111109, 706.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-535.55555555555543, 705.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-532.44444444444434, 702.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-530.22222222222217, 704.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-526.22222222222217, 703.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-524, 699.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-522.66666666666663, 692.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-517.33333333333326, 689.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-515.55555555555543, 691.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-511.11111111111103, 687.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-508.8888888888888, 688.8888888888888))
		end

	kunashir_imp: EV_MODEL_POLYGON
			-- Make the polygon
		do
			create Result
				-- Points generated by Grabber application
			Result.extend_point (create {EV_COORDINATE}.make_precise (191.1111111111112, 64.888888888888857))
			Result.extend_point (create {EV_COORDINATE}.make_precise (193.77777777777783, 64.888888888888857))
			Result.extend_point (create {EV_COORDINATE}.make_precise (197.77777777777783, 68.888888888888857))
			Result.extend_point (create {EV_COORDINATE}.make_precise (201.33333333333337, 70.222222222222172))
			Result.extend_point (create {EV_COORDINATE}.make_precise (205.33333333333337, 69.777777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (212, 68.888888888888857))
			Result.extend_point (create {EV_COORDINATE}.make_precise (210.22222222222217, 70.666666666666629))
			Result.extend_point (create {EV_COORDINATE}.make_precise (209.77777777777783, 74.222222222222172))
			Result.extend_point (create {EV_COORDINATE}.make_precise (204.8888888888888, 73.333333333333314))
			Result.extend_point (create {EV_COORDINATE}.make_precise (202.66666666666663, 75.111111111111086))
			Result.extend_point (create {EV_COORDINATE}.make_precise (199.1111111111112, 79.555555555555543))
			Result.extend_point (create {EV_COORDINATE}.make_precise (191.1111111111112, 80))
			Result.extend_point (create {EV_COORDINATE}.make_precise (189.33333333333337, 82.222222222222172))
			Result.extend_point (create {EV_COORDINATE}.make_precise (188.8888888888888, 84.888888888888857))
			Result.extend_point (create {EV_COORDINATE}.make_precise (183.1111111111112, 87.111111111111086))
			Result.extend_point (create {EV_COORDINATE}.make_precise (181.33333333333337, 90.222222222222172))
			Result.extend_point (create {EV_COORDINATE}.make_precise (180.44444444444446, 93.333333333333314))
			Result.extend_point (create {EV_COORDINATE}.make_precise (180, 95.555555555555543))
			Result.extend_point (create {EV_COORDINATE}.make_precise (177.33333333333337, 95.555555555555543))
			Result.extend_point (create {EV_COORDINATE}.make_precise (176, 101.33333333333331))
			Result.extend_point (create {EV_COORDINATE}.make_precise (170.22222222222217, 103.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (166.22222222222217, 106.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (166.22222222222217, 112.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (165.33333333333337, 119.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (164, 114.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (159.55555555555554, 116))
			Result.extend_point (create {EV_COORDINATE}.make_precise (157.77777777777783, 107.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (160, 107.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (160, 104.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (166.66666666666663, 100))
			Result.extend_point (create {EV_COORDINATE}.make_precise (173.33333333333337, 92.888888888888857))
			Result.extend_point (create {EV_COORDINATE}.make_precise (173.33333333333337, 90.666666666666629))
			Result.extend_point (create {EV_COORDINATE}.make_precise (179.55555555555554, 81.777777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (182.66666666666663, 80))
			Result.extend_point (create {EV_COORDINATE}.make_precise (185.33333333333337, 74.666666666666629))
			Result.extend_point (create {EV_COORDINATE}.make_precise (187.55555555555554, 69.777777777777771))
		end

	shikotan_imp: EV_MODEL_POLYGON
			-- Make the polygon
		do
			create Result
				-- Points generated by Grabber application
			Result.extend_point (create {EV_COORDINATE}.make_precise (212, 109.77777777777777))
			Result.extend_point (create {EV_COORDINATE}.make_precise (216.44444444444446, 108))
			Result.extend_point (create {EV_COORDINATE}.make_precise (224, 103.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (225.33333333333337, 106.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (227.1111111111112, 108.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (224, 109.33333333333331))
			Result.extend_point (create {EV_COORDINATE}.make_precise (221.33333333333337, 110.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (219.55555555555554, 113.33333333333331))
			Result.extend_point (create {EV_COORDINATE}.make_precise (217.33333333333337, 113.77777777777777))
			Result.extend_point (create {EV_COORDINATE}.make_precise (215.55555555555554, 116.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (213.77777777777783, 114.22222222222217))
		end

	iturup_imp: EV_MODEL_POLYGON
			-- Make the polygon
		do
			create Result
				-- Points generated by Grabber application
			Result.extend_point (create {EV_COORDINATE}.make_precise (274.22222222222217, 4.4444444444444571))
			Result.extend_point (create {EV_COORDINATE}.make_precise (275.55555555555554, 9.3333333333333144))
			Result.extend_point (create {EV_COORDINATE}.make_precise (277.33333333333337, 11.111111111111114))
			Result.extend_point (create {EV_COORDINATE}.make_precise (277.77777777777783, 15.555555555555543))
			Result.extend_point (create {EV_COORDINATE}.make_precise (283.55555555555554, 16.888888888888857))
			Result.extend_point (create {EV_COORDINATE}.make_precise (287.55555555555554, 15.111111111111114))
			Result.extend_point (create {EV_COORDINATE}.make_precise (290.66666666666663, 15.111111111111114))
			Result.extend_point (create {EV_COORDINATE}.make_precise (292.8888888888888, 12))
			Result.extend_point (create {EV_COORDINATE}.make_precise (297.33333333333337, 9.3333333333333144))
			Result.extend_point (create {EV_COORDINATE}.make_precise (297.77777777777783, 6.6666666666666572))
			Result.extend_point (create {EV_COORDINATE}.make_precise (302.22222222222217, 1.7777777777777715))
			Result.extend_point (create {EV_COORDINATE}.make_precise (305.77777777777783, 0.88888888888885731))
			Result.extend_point (create {EV_COORDINATE}.make_precise (306.22222222222217, -1.7777777777777999))
			Result.extend_point (create {EV_COORDINATE}.make_precise (314.22222222222217, -3.1111111111111427))
			Result.extend_point (create {EV_COORDINATE}.make_precise (317.33333333333337, -1.3333333333333428))
			Result.extend_point (create {EV_COORDINATE}.make_precise (317.33333333333337, 2.2222222222222001))
			Result.extend_point (create {EV_COORDINATE}.make_precise (314.66666666666663, 3.5555555555555429))
			Result.extend_point (create {EV_COORDINATE}.make_precise (316, 8))
			Result.extend_point (create {EV_COORDINATE}.make_precise (315.1111111111112, 10.666666666666657))
			Result.extend_point (create {EV_COORDINATE}.make_precise (313.33333333333337, 12.444444444444457))
			Result.extend_point (create {EV_COORDINATE}.make_precise (310.22222222222217, 12))
			Result.extend_point (create {EV_COORDINATE}.make_precise (306.66666666666663, 11.555555555555543))
			Result.extend_point (create {EV_COORDINATE}.make_precise (304.8888888888888, 12.444444444444457))
			Result.extend_point (create {EV_COORDINATE}.make_precise (301.77777777777783, 14.2222222222222))
			Result.extend_point (create {EV_COORDINATE}.make_precise (299.1111111111112, 16.444444444444457))
			Result.extend_point (create {EV_COORDINATE}.make_precise (294.66666666666663, 18.2222222222222))
			Result.extend_point (create {EV_COORDINATE}.make_precise (290.66666666666663, 18.666666666666657))
			Result.extend_point (create {EV_COORDINATE}.make_precise (287.1111111111112, 22.666666666666657))
			Result.extend_point (create {EV_COORDINATE}.make_precise (284.8888888888888, 24.888888888888857))
			Result.extend_point (create {EV_COORDINATE}.make_precise (281.77777777777783, 25.333333333333314))
			Result.extend_point (create {EV_COORDINATE}.make_precise (280.8888888888888, 27.111111111111114))
			Result.extend_point (create {EV_COORDINATE}.make_precise (278.22222222222217, 29.777777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (273.77777777777783, 34.2222222222222))
			Result.extend_point (create {EV_COORDINATE}.make_precise (273.77777777777783, 36.444444444444457))
			Result.extend_point (create {EV_COORDINATE}.make_precise (272, 35.111111111111114))
			Result.extend_point (create {EV_COORDINATE}.make_precise (267.55555555555554, 36))
			Result.extend_point (create {EV_COORDINATE}.make_precise (265.33333333333337, 36))
			Result.extend_point (create {EV_COORDINATE}.make_precise (264, 32.888888888888857))
			Result.extend_point (create {EV_COORDINATE}.make_precise (259.55555555555554, 35.111111111111114))
			Result.extend_point (create {EV_COORDINATE}.make_precise (260.8888888888888, 38.666666666666657))
			Result.extend_point (create {EV_COORDINATE}.make_precise (259.55555555555554, 40.888888888888857))
			Result.extend_point (create {EV_COORDINATE}.make_precise (256.8888888888888, 43.555555555555543))
			Result.extend_point (create {EV_COORDINATE}.make_precise (254.22222222222217, 45.777777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (252.8888888888888, 48))
			Result.extend_point (create {EV_COORDINATE}.make_precise (248.8888888888888, 48.888888888888857))
			Result.extend_point (create {EV_COORDINATE}.make_precise (245.33333333333337, 53.777777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (244, 56.888888888888857))
			Result.extend_point (create {EV_COORDINATE}.make_precise (242.22222222222217, 59.555555555555543))
			Result.extend_point (create {EV_COORDINATE}.make_precise (239.55555555555554, 61.333333333333314))
			Result.extend_point (create {EV_COORDINATE}.make_precise (236, 61.333333333333314))
			Result.extend_point (create {EV_COORDINATE}.make_precise (232.8888888888888, 62.666666666666657))
			Result.extend_point (create {EV_COORDINATE}.make_precise (232, 66.666666666666657))
			Result.extend_point (create {EV_COORDINATE}.make_precise (230.22222222222217, 69.333333333333314))
			Result.extend_point (create {EV_COORDINATE}.make_precise (226.66666666666663, 68.888888888888857))
			Result.extend_point (create {EV_COORDINATE}.make_precise (224.8888888888888, 68))
			Result.extend_point (create {EV_COORDINATE}.make_precise (226.22222222222217, 64))
			Result.extend_point (create {EV_COORDINATE}.make_precise (228.44444444444446, 62.666666666666657))
			Result.extend_point (create {EV_COORDINATE}.make_precise (228, 56.888888888888857))
			Result.extend_point (create {EV_COORDINATE}.make_precise (230.22222222222217, 60.444444444444457))
			Result.extend_point (create {EV_COORDINATE}.make_precise (232.44444444444446, 58.666666666666657))
			Result.extend_point (create {EV_COORDINATE}.make_precise (232.44444444444446, 56))
			Result.extend_point (create {EV_COORDINATE}.make_precise (231.55555555555554, 54.2222222222222))
			Result.extend_point (create {EV_COORDINATE}.make_precise (234.66666666666663, 55.555555555555543))
			Result.extend_point (create {EV_COORDINATE}.make_precise (238.66666666666663, 53.777777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (240.44444444444446, 49.333333333333314))
			Result.extend_point (create {EV_COORDINATE}.make_precise (236.8888888888888, 48))
			Result.extend_point (create {EV_COORDINATE}.make_precise (236, 45.333333333333314))
			Result.extend_point (create {EV_COORDINATE}.make_precise (237.77777777777783, 44))
			Result.extend_point (create {EV_COORDINATE}.make_precise (239.1111111111112, 46.2222222222222))
			Result.extend_point (create {EV_COORDINATE}.make_precise (242.66666666666663, 44.888888888888857))
			Result.extend_point (create {EV_COORDINATE}.make_precise (242.66666666666663, 42.2222222222222))
			Result.extend_point (create {EV_COORDINATE}.make_precise (245.33333333333337, 40))
			Result.extend_point (create {EV_COORDINATE}.make_precise (246.66666666666663, 41.777777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (250.66666666666663, 37.333333333333314))
			Result.extend_point (create {EV_COORDINATE}.make_precise (251.1111111111112, 33.777777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (254.66666666666663, 32.888888888888857))
			Result.extend_point (create {EV_COORDINATE}.make_precise (254.66666666666663, 29.333333333333314))
			Result.extend_point (create {EV_COORDINATE}.make_precise (255.55555555555554, 27.555555555555543))
			Result.extend_point (create {EV_COORDINATE}.make_precise (253.77777777777783, 25.333333333333314))
			Result.extend_point (create {EV_COORDINATE}.make_precise (258.22222222222217, 28))
			Result.extend_point (create {EV_COORDINATE}.make_precise (262.66666666666663, 26.666666666666657))
			Result.extend_point (create {EV_COORDINATE}.make_precise (263.1111111111112, 23.111111111111114))
			Result.extend_point (create {EV_COORDINATE}.make_precise (264.8888888888888, 20))
			Result.extend_point (create {EV_COORDINATE}.make_precise (269.33333333333337, 19.111111111111114))
			Result.extend_point (create {EV_COORDINATE}.make_precise (270.66666666666663, 16.444444444444457))
			Result.extend_point (create {EV_COORDINATE}.make_precise (269.33333333333337, 13.333333333333314))
			Result.extend_point (create {EV_COORDINATE}.make_precise (270.22222222222217, 8))
			Result.extend_point (create {EV_COORDINATE}.make_precise (272, 7.1111111111111143))
		end

	urup_imp: EV_MODEL_POLYGON
			-- Make the polygon
		do
			create Result
				-- Points generated by Grabber application
			Result.extend_point (create {EV_COORDINATE}.make_precise (380.8888888888888, -46.222222222222229))
			Result.extend_point (create {EV_COORDINATE}.make_precise (387.55555555555554, -47.111111111111114))
			Result.extend_point (create {EV_COORDINATE}.make_precise (388.44444444444446, -45.333333333333343))
			Result.extend_point (create {EV_COORDINATE}.make_precise (394.66666666666663, -46.666666666666686))
			Result.extend_point (create {EV_COORDINATE}.make_precise (392.44444444444446, -44.444444444444457))
			Result.extend_point (create {EV_COORDINATE}.make_precise (384.8888888888888, -38.222222222222229))
			Result.extend_point (create {EV_COORDINATE}.make_precise (378.22222222222206, -33.333333333333343))
			Result.extend_point (create {EV_COORDINATE}.make_precise (377.77777777777771, -28))
			Result.extend_point (create {EV_COORDINATE}.make_precise (375.55555555555554, -28))
			Result.extend_point (create {EV_COORDINATE}.make_precise (370.22222222222206, -20.888888888888886))
			Result.extend_point (create {EV_COORDINATE}.make_precise (367.55555555555554, -19.555555555555543))
			Result.extend_point (create {EV_COORDINATE}.make_precise (365.77777777777771, -20.444444444444457))
			Result.extend_point (create {EV_COORDINATE}.make_precise (359.1111111111112, -14.666666666666686))
			Result.extend_point (create {EV_COORDINATE}.make_precise (355.1111111111112, -8.8888888888888857))
			Result.extend_point (create {EV_COORDINATE}.make_precise (351.55555555555554, -5.7777777777777999))
			Result.extend_point (create {EV_COORDINATE}.make_precise (349.33333333333337, -5.3333333333333428))
			Result.extend_point (create {EV_COORDINATE}.make_precise (348.44444444444446, -3.5555555555555429))
			Result.extend_point (create {EV_COORDINATE}.make_precise (345.77777777777783, -4.4444444444444571))
			Result.extend_point (create {EV_COORDINATE}.make_precise (340.44444444444446, -4.4444444444444571))
			Result.extend_point (create {EV_COORDINATE}.make_precise (342.66666666666663, -7.1111111111111427))
			Result.extend_point (create {EV_COORDINATE}.make_precise (344, -11.111111111111143))
			Result.extend_point (create {EV_COORDINATE}.make_precise (347.1111111111112, -13.333333333333343))
			Result.extend_point (create {EV_COORDINATE}.make_precise (347.55555555555554, -15.555555555555543))
			Result.extend_point (create {EV_COORDINATE}.make_precise (350.66666666666663, -19.555555555555543))
			Result.extend_point (create {EV_COORDINATE}.make_precise (351.55555555555554, -22.222222222222229))
			Result.extend_point (create {EV_COORDINATE}.make_precise (356.8888888888888, -22.666666666666686))
			Result.extend_point (create {EV_COORDINATE}.make_precise (360.44444444444446, -25.333333333333343))
			Result.extend_point (create {EV_COORDINATE}.make_precise (360.44444444444446, -28))
			Result.extend_point (create {EV_COORDINATE}.make_precise (363.1111111111112, -29.333333333333343))
			Result.extend_point (create {EV_COORDINATE}.make_precise (362.66666666666663, -31.111111111111114))
			Result.extend_point (create {EV_COORDINATE}.make_precise (364.44444444444446, -32))
			Result.extend_point (create {EV_COORDINATE}.make_precise (366.66666666666663, -33.333333333333343))
			Result.extend_point (create {EV_COORDINATE}.make_precise (367.1111111111112, -35.555555555555543))
			Result.extend_point (create {EV_COORDINATE}.make_precise (369.77777777777771, -36.888888888888886))
			Result.extend_point (create {EV_COORDINATE}.make_precise (374.22222222222206, -37.777777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (375.55555555555554, -39.111111111111114))
			Result.extend_point (create {EV_COORDINATE}.make_precise (375.55555555555554, -42.222222222222229))
			Result.extend_point (create {EV_COORDINATE}.make_precise (377.33333333333337, -45.777777777777771))
		end

invariant

	correct_port: attached target_imp implies port = game.yokosuka_navy_yard

end
