note
	description: "[
		Widget that represents this VITP sea area.
		The points for land areas were obtained using the Grabber program,
		which allows one to trace a picture, say from Google Earth.
		The "Asia polygons" and the "Kamchatka polygons" were traced
		seperately, so they require different transformations.
		]"
	author: "Jimmy J. Johnson"

class
	JAPANESE_ISLANDS_WIDGET

inherit

	SEA_AREA_WIDGET
		redefine
			create_interface_objects,
			position_widgets,
			build_land,
			build_ocean
--			build_bounding_figure
		end

create
	make

feature {NONE} -- Initialization

	create_interface_objects
			-- Initialize attributes
		do
			Precursor {SEA_AREA_WIDGET}
			asia := asia_imp
			hainan := hainan_imp
			taiwan := taiwan_imp
			kamchatsky := kamchatsky_imp
			shumshu := shumshu_imp
			paramushir := paramushir_imp
			atlasov := atlasov_imp
			onekotan := onekotan_imp
			makanrushi := makanrushi_imp
			kharimkotan := kharimkotan_imp
			shiashkotan := shiashkotan_imp
			ekarma := ekarma_imp
			matua := matua_imp
			rasshua := rasshua_imp
			ketoy := ketoy_imp
			simushir := simushir_imp
			sakhalin := sakhalin_imp
		end

	position_widgets
			-- Move Current and contained widgets to correct
			-- location and set their their sizes
		do
			Precursor {SEA_AREA_WIDGET}
			name_mt.set_point_position (-75, 90)
			dot.set_point_position (-40, 80)
--			flag.center_on_dot (dot)
			flag.set_x_y (dot.x, dot.y)
			set_point_position (497, 0)
		end

	build_land
			-- Add any brown land to Current
		do
			Precursor {SEA_AREA_WIDGET}
				-- Add Asia polygons and tranform to match other widgets
			land.extend (asia)
			land.extend (hainan)
			land.extend (taiwan)
			asia.transform (asia_transform)
			hainan.transform (asia_transform)
			taiwan.transform (asia_transform)
				-- Add Kamchatka polygons and tranform to match other widgets
			land.extend (kamchatsky)
			land.extend (shumshu)
			land.extend (paramushir)
			land.extend (atlasov)
			land.extend (onekotan)
			land.extend (makanrushi)
			land.extend (kharimkotan)
			land.extend (shiashkotan)
			land.extend (ekarma)
			land.extend (matua)
			land.extend (rasshua)
			land.extend (ketoy)
			land.extend (simushir)
			land.extend (sakhalin)
			kamchatsky.transform (kamchatka_transform)
			shumshu.transform (kamchatka_transform)
			paramushir.transform (kamchatka_transform)
			atlasov.transform (kamchatka_transform)
			onekotan.transform (kamchatka_transform)
			makanrushi.transform (kamchatka_transform)
			kharimkotan.transform (kamchatka_transform)
			shiashkotan.transform (kamchatka_transform)
			ekarma.transform (kamchatka_transform)
			matua.transform (kamchatka_transform)
			rasshua.transform (kamchatka_transform)
			ketoy.transform (kamchatka_transform)
			simushir.transform (kamchatka_transform)
			sakhalin.transform (kamchatka_transform)
		end

	build_ocean
			-- Create the polygon representing the `ocean' here
			-- Redefined to add the points
		do
			Precursor {SEA_AREA_WIDGET}
				-- start at north-east corner
			ocean.extend_point (create {EV_COORDINATE}.make (0, 0))
			ocean.extend_point (create {EV_COORDINATE}.make (27, 98))
			ocean.extend_point (create {EV_COORDINATE}.make (-50, 180))
			ocean.extend_point (create {EV_COORDINATE}.make (-271, 200))
			ocean.extend_point (create {EV_COORDINATE}.make (-313, 159))
			ocean.extend_point (create {EV_COORDINATE}.make (-310, 0))		-- x is estimated
		end

--	build_bounding_figure
--			-- Add points to the `jj_bounding_figure'.
--			-- Redefined to use the tile edges as the bounding area
--		do
--			if has (jj_bounding_figure) then
--				prune_all (jj_bounding_figure)
--			end
--			create jj_bounding_figure
--			extend (jj_bounding_figure)
--				-- start at west-most point west of Singapore
--				-- start at north-east corner
--			jj_bounding_figure.extend_point (create {EV_COORDINATE}.make (0, 0))
--			jj_bounding_figure.extend_point (create {EV_COORDINATE}.make (27, 98))
--			jj_bounding_figure.extend_point (create {EV_COORDINATE}.make (-50, 180))
--			jj_bounding_figure.extend_point (create {EV_COORDINATE}.make (-271, 200))
--			jj_bounding_figure.extend_point (create {EV_COORDINATE}.make (-313, 159))
--			jj_bounding_figure.extend_point (create {EV_COORDINATE}.make (-310, 0))		-- x is estimated
--				-- Make adjustments
--			jj_bounding_figure.enable_closed
--			jj_bounding_figure.set_line_width (2)
--			translate_widget (jj_bounding_figure, 497, 0)
----			show_bounding_figure
--		end

feature -- Access

	asia: EV_MODEL_POLYGON
	hainan: EV_MODEL_POLYGON
	taiwan: EV_MODEL_POLYGON

feature -- Access

	kamchatsky: EV_MODEL_POLYGON
	shumshu: EV_MODEL_POLYGON
	paramushir: EV_MODEL_POLYGON
	atlasov: EV_MODEL_POLYGON
	onekotan: EV_MODEL_POLYGON
	makanrushi: EV_MODEL_POLYGON
	kharimkotan: EV_MODEL_POLYGON
	shiashkotan: EV_MODEL_POLYGON
	ekarma: EV_MODEL_POLYGON
	matua: EV_MODEL_POLYGON
	rasshua: EV_MODEL_POLYGON
	ketoy: EV_MODEL_POLYGON
	simushir: EV_MODEL_POLYGON
	sakhalin: EV_MODEL_POLYGON

feature {NONE} -- Implementation

	asia_point: EV_COORDINATE
			-- Reference point for transformations of the Asia
			-- polygons (i.e. `asia', `hainan', & `taiwan').
		local
			bb: EV_RECTANGLE
			mid_x: REAL_64
			mid_y: REAL_64
		once
			create Result.make_precise (0.0, 0.0)
				-- Estimate the mid_point
--3			create Result.make_precise (721.0, 176.0)
		end

	asia_move: EV_COORDINATE
			-- Distance in x- and y-directions to move the asia polygons.
		once
--			create Result.make ((-497 * (1/asia_scale)).rounded, 1)
--			create Result.make (-1838, 348)
--			create Result.make (-497, -11)
			create Result.make (-504, -12)
		end

	asia_scale: REAL_64 = 0.27
			-- Scale factor for Asia polygons.

	asia_angle: REAL_64 = 12.0
			-- Number of degrees to rotate the Asia polygons

	asia_transform: EV_MODEL_TRANSFORMATION
			-- Matrix to scale, rotate, and translate polygons
			-- depicting `asia', `hainan', and `taiwan'.
		local
			r, s, t: EV_MODEL_TRANSFORMATION
		once
			create r.make_zero
			create s.make_zero
			create t.make_zero
			t.translate (asia_move.x_precise, asia_move.y_precise)
--			s.scale (asia_scale, asia_scale, asia_point.x_precise, asia_point.y_precise, 0.0)
			s.scale (asia_scale, asia_scale, 0.0, 0.0, 0.0)
			r.rotate (degrees_to_radians (asia_angle), asia_point.x_precise, asia_point.y_precise)
			Result := t * r * s
--			Result := r * s * t
--			Result := s * t * r
		end

	kamchatka_point: EV_COORDINATE
			-- Reference point for transformations of the Kamchatka
			-- polygons (i.e. `kamchatsky', `shumshu', `paramushir',
			-- `atlasov', etc.).
		once
			create Result.make_precise (0.0, 0.0)
		end

	kamchatka_move: EV_COORDINATE
			-- Distance in x- and y-directions to move the kamchatka polygons.
		once
			create Result.make (-6, -2)
--			create Result.make (-118, 38)
		end

	kamchatka_scale: REAL_64 = 0.07
			-- Scale factor for Kamchatka polygons

	kamchatka_angle: REAL_64 = 12.0
			-- Number of degrees to rotate the Kamchatka polygons

	kamchatka_transform: EV_MODEL_TRANSFORMATION
			-- Matrix to scale, rotate, and translate polygons
			-- depicting `asia', `hainan', and `taiwan'.
		local
			r, s, t: EV_MODEL_TRANSFORMATION
		once
			create r.make_zero
			create s.make_zero
			create t.make_zero
			t.translate (kamchatka_move.x_precise, kamchatka_move.y_precise)
--			s.scale (kamchatka_scale, kamchatka_scale, kamchatka_point.x_precise, kamchatka_point.y_precise, 0.0)
			s.scale (kamchatka_scale, kamchatka_scale, 0.0, 0.0, 0.0)
			r.rotate (degrees_to_radians (kamchatka_angle), kamchatka_point.x_precise, kamchatka_point.y_precise)
			Result := t * r * s
--			Result := r * s * t
--			Result := s * t * r
		end

feature {NONE} -- Implmenetation (Asia polygons)

	polygon_from_file (a_name: STRING): EV_MODEL_POLYGON
			-- Create a polygon from the file beginning with `a_name'.
		local
			f: PLAIN_TEXT_FILE
			p: PATH
			x_loc, y_loc: REAL_64
		do
				-- Use the current "working directory"
				-- See execution parameters in EiffelStudio.
			create p.make_current
			p := p.appended ("/xy_land_files/" + a_name + ".txt")
			create f.make_with_path (p)
			f.open_read
--			create f.make_open_read ("~/jj_source/jj_vitp/xy_land_files/" + a_name + ".txt")
--			create f.make_open_read ("./xy_land_files/asia.txt")
			create Result
			from f.start
			until f.exhausted or f.end_of_file
			loop
				f.read_real
				x_loc := f.last_real
				f.forth
				f.read_real
				y_loc := f.last_real
				Result.extend_point (create {EV_COORDINATE}.make_precise (x_loc, y_loc))
				f.forth
			end
		end

	asia_imp: EV_MODEL_POLYGON
			-- The brown land at top left of board
		do
--			Result := polygon_from_file ("asia")
				-- The first few points and the last point were modified or commented
				-- out so that the land would not go too far outside the boarde.
			create Result
				-- Clockwise from top-left corner
			Result.extend_point (create {EV_COORDINATE}.make_precise (25, 32))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1442.25, -262))
				-- Points generated by Grabber application
--			Result.extend_point (create {EV_COORDINATE}.make_precise (0, 0))
--			Result.extend_point (create {EV_COORDINATE}.make_precise (1442.25, -307))
--			Result.extend_point (create {EV_COORDINATE}.make_precise (1441.2499999999993, -296))
--			Result.extend_point (create {EV_COORDINATE}.make_precise (1443.2499999999993, -270))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1443.2499999999993, -257))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1448.25, -255))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1441.2499999999993, -249))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1444.25, -236))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1439.2499999999993, -228.00000000000003))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1440.25, -215))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1436.2499999999993, -211.00000000000003))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1437.2499999999993, -202))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1427.2499999999993, -191.00000000000006))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1419.2499999999993, -183))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1415.25, -177.00000000000006))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1412.3611111111104, -169.11111111111117))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1411.25, -162))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1402.25, -157.00000000000006))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1398.2499999999993, -147))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1393.25, -136.00000000000006))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1388.3611111111104, -126.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1386.25, -123))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1380.2499999999993, -110))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1371.2499999999993, -104))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1364.2499999999993, -93.000000000000085))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1358.2499999999993, -90))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1349.25, -77))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1346.5833333333328, -74.000000000000085))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1345.6944444444443, -66))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1338.2499999999995, -67.000000000000114))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1334.25, -55.000000000000114))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1327.2499999999995, -42.000000000000114))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1318.25, -34.000000000000114))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1299.2499999999995, -23))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1294.5833333333328, -17.111111111111256))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1292.3611111111106, -18.000000000000114))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1290.1388888888882, -16.222222222222342))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1286.1388888888882, -16.222222222222342))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1282.1388888888882, -14.444444444444571))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1274.2499999999995, -13.000000000000114))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1271.9166666666661, -16.666666666666799))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1269.25, -13.555555555555657))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1266.1388888888882, -18.000000000000114))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1263.4722222222222, -15.333333333333343))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1259.9166666666661, -19.333333333333456))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1257.2499999999995, -17.000000000000114))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1257.2499999999995, -27))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1254.5833333333328, -26.888888888888914))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1251.9166666666661, -26.000000000000114))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1247.2499999999995, -19.000000000000171))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1243.9166666666661, -18.888888888888999))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1247.0277777777776, -24.222222222222342))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1249.2499999999995, -30))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1243.2499999999995, -29.000000000000114))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1241.6944444444439, -23.777777777777914))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1236.805555555555, -18.444444444444571))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1232.25, -10))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1217.25, -11))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1223.2499999999995, -7.0000000000001137))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1221.2499999999995, 2))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1218.5833333333328, -0.22222222222234222))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1214.25, 2))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1211.0277777777774, 4.222222222222058))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1207.4722222222222, 8.222222222222058))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1204.805555555555, 8.6666666666665151))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1202.5833333333333, 15.333333333333201))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1197.2499999999995, 18.999999999999886))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1197.2499999999995, 27))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1199.9166666666661, 30.444444444444343))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1197.6944444444439, 34.888888888888687))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1199.0277777777776, 42.44444444444423))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1198.1388888888882, 46.44444444444423))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1195.4722222222217, 45.111111111111086))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1185.2499999999995, 50))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1184.2499999999995, 56.999999999999829))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1181.6944444444443, 56.222222222222058))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1177.6944444444443, 59.777777777777601))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1173.25, 59))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1174.25, 64.999999999999829))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1168.3611111111106, 67.333333333333144))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1163.0277777777774, 68.666666666666515))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1157.2499999999995, 67))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1152.3611111111106, 74.44444444444423))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1147.2499999999995, 77))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1148.805555555555, 82.4444444444444))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1147.0277777777774, 87.777777777777601))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1144.805555555555, 87.777777777777601))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1145.6944444444439, 93.555555555555316))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1153.2499999999993, 98))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1167.2499999999995, 110.99999999999983))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1173.25, 126.99999999999977))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1179.4722222222222, 136.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1184.805555555555, 136.222222222222))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1190.1388888888882, 141.11111111111092))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1189.6944444444443, 146.88888888888869))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1189.2499999999995, 152.222222222222))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1191.2499999999995, 156.99999999999977))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1191.2499999999995, 171.99999999999966))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1188.25, 184.99999999999983))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1195.2499999999995, 183.99999999999966))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1193.2499999999995, 198))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1184.2499999999995, 208.99999999999977))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1178.25, 212.99999999999977))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1174.1388888888882, 210.88888888888869))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1172.3611111111106, 208.222222222222))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1172.3611111111106, 212.222222222222))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1164.2499999999995, 213.99999999999977))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1162.1388888888882, 216.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1159.4722222222217, 213.99999999999977))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1157.2499999999995, 213.99999999999977))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1161.25, 220.6666666666664))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1156.3611111111106, 220.222222222222))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1154.5833333333328, 215.77777777777749))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1149.6944444444439, 216.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1152.805555555555, 217.55555555555532))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1154.1388888888882, 222.88888888888869))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1149.2499999999995, 222.44444444444417))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1148.3611111111106, 219.33333333333309))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1145.2499999999995, 218.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1147.0277777777774, 223.33333333333309))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1139.9166666666661, 229.55555555555532))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1140.805555555555, 225.55555555555532))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1143.9166666666665, 221.55555555555532))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1136.805555555555, 222.88888888888869))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1135.0277777777774, 228.222222222222))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1131.9166666666665, 228.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1130.5833333333328, 225.11111111111086))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1128.3611111111106, 229.55555555555532))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1128.2499999999995, 232.99999999999977))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1124.3611111111106, 233.11111111111086))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1124.805555555555, 226.4444444444444))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1121.25, 226.4444444444444))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1120.805555555555, 230.44444444444417))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1116.805555555555, 231.77777777777749))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1114.2499999999993, 228.99999999999977))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1117.6944444444439, 226.88888888888869))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1119.4722222222217, 221.11111111111086))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1121.6944444444443, 222))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1124.805555555555, 222.88888888888869))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1125.6944444444439, 217.55555555555532))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1122.2499999999995, 216.99999999999977))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1120.805555555555, 213.11111111111086))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1122.5833333333333, 211.33333333333309))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1120.2499999999995, 204.99999999999966))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1123.9166666666661, 195.77777777777749))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1128.2499999999995, 191.99999999999977))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1131.4722222222217, 188.222222222222))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1126.5833333333328, 189.11111111111086))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1128.2499999999995, 185.99999999999977))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1124.3611111111106, 181.99999999999983))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1124.3611111111106, 168.222222222222))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1119.4722222222217, 166.4444444444444))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1115.2499999999995, 163.99999999999983))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1119.0277777777774, 159.33333333333314))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1120.805555555555, 161.55555555555532))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1121.6944444444443, 157.55555555555532))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1123.9166666666661, 158.88888888888869))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1124.3611111111106, 156.222222222222))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1128.2499999999995, 156.99999999999977))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1132.805555555555, 161.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1131.4722222222217, 156.222222222222))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1131.4722222222217, 153.11111111111092))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1127.9166666666661, 151.7777777777776))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1132.3611111111106, 148.222222222222))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1127.0277777777776, 145.99999999999983))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1127.25, 140))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1119.25, 134))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1116.3611111111109, 136.222222222222))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1114.5833333333328, 133.11111111111092))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1110.2499999999995, 132.99999999999977))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1108.3611111111106, 127.7777777777776))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1105.6944444444439, 129.55555555555532))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1105.6944444444439, 132.222222222222))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1104.2499999999995, 138.99999999999977))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1100.805555555555, 136.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1097.6944444444439, 137.55555555555532))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1100.805555555555, 131.77777777777749))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1095.4722222222222, 132.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1089.6944444444439, 130.88888888888869))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1094.5833333333333, 127.33333333333314))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1095.9166666666661, 125.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1083.9166666666661, 125.55555555555532))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1088.2499999999995, 117))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1095.4722222222222, 98))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1099.9166666666661, 91.777777777777601))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1098.5833333333328, 86.444444444444173))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1101.6944444444439, 81.555555555555316))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1097.25, 83.777777777777601))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1096.2499999999993, 81))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1082.25, 78))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1079.4722222222217, 74.888888888888687))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1075.9166666666661, 75.333333333333314))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1074.5833333333328, 70.44444444444423))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1072.3611111111106, 76.222222222222001))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1051.2499999999995, 77))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1030.2499999999995, 89))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1024.805555555555, 93.555555555555316))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1018.583333333333, 99.777777777777601))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1015.0277777777774, 104.222222222222))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1009.2499999999997, 103.77777777777749))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1004.2499999999997, 108))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1003.2499999999995, 99.999999999999829))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1012.2499999999995, 95.999999999999829))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1014.2499999999997, 87.999999999999829))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1004.2499999999997, 87.999999999999829))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1009.694444444444, 84.222222222222001))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1005.694444444444, 82.888888888888687))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1009.2499999999995, 78.999999999999829))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1010.2499999999997, 72.999999999999829))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1016.805555555555, 72.222222222222001))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1020.2499999999997, 63.999999999999829))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1026.25, 58))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1027.0277777777774, 53.555555555555543))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1021.2499999999993, 45.999999999999829))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1002.2499999999997, 42.999999999999829))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1000.2499999999995, 50))
			Result.extend_point (create {EV_COORDINATE}.make_precise (994.13888888888846, 50.44444444444423))
			Result.extend_point (create {EV_COORDINATE}.make_precise (991.24999999999955, 60))
			Result.extend_point (create {EV_COORDINATE}.make_precise (988.24999999999932, 64.999999999999829))
			Result.extend_point (create {EV_COORDINATE}.make_precise (966.25, 72))
			Result.extend_point (create {EV_COORDINATE}.make_precise (960.24999999999966, 83.999999999999829))
			Result.extend_point (create {EV_COORDINATE}.make_precise (957.25, 94))
			Result.extend_point (create {EV_COORDINATE}.make_precise (947.02777777777737, 94))
			Result.extend_point (create {EV_COORDINATE}.make_precise (939.25, 98))
			Result.extend_point (create {EV_COORDINATE}.make_precise (933.24999999999966, 92.999999999999829))
			Result.extend_point (create {EV_COORDINATE}.make_precise (924.24999999999966, 99))
			Result.extend_point (create {EV_COORDINATE}.make_precise (922.13888888888846, 107.7777777777776))
			Result.extend_point (create {EV_COORDINATE}.make_precise (928.24999999999955, 120.99999999999977))
			Result.extend_point (create {EV_COORDINATE}.make_precise (942.24999999999966, 127.99999999999983))
			Result.extend_point (create {EV_COORDINATE}.make_precise (947.25, 125))
			Result.extend_point (create {EV_COORDINATE}.make_precise (953.25, 127.99999999999983))
			Result.extend_point (create {EV_COORDINATE}.make_precise (958.24999999999955, 136.99999999999983))
			Result.extend_point (create {EV_COORDINATE}.make_precise (954.25, 141.99999999999966))
			Result.extend_point (create {EV_COORDINATE}.make_precise (956.25, 150.99999999999977))
			Result.extend_point (create {EV_COORDINATE}.make_precise (965.25, 154.99999999999983))
			Result.extend_point (create {EV_COORDINATE}.make_precise (973.24999999999955, 149.99999999999983))
			Result.extend_point (create {EV_COORDINATE}.make_precise (981.25, 141.99999999999966))
			Result.extend_point (create {EV_COORDINATE}.make_precise (984.36111111111063, 137.55555555555532))
			Result.extend_point (create {EV_COORDINATE}.make_precise (996.24999999999966, 134))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1005.2499999999997, 140))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1010.1388888888888, 143.77777777777749))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1022.2499999999997, 143))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1036.2499999999995, 147))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1035.4722222222217, 152.222222222222))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1032.3611111111106, 153.55555555555532))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1034.2499999999995, 159))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1029.6944444444439, 161.55555555555532))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1021.2499999999993, 159.99999999999977))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1000.8055555555552, 168.222222222222))
			Result.extend_point (create {EV_COORDINATE}.make_precise (998.1388888888888, 174.44444444444423))
			Result.extend_point (create {EV_COORDINATE}.make_precise (995.02777777777737, 172.66666666666652))
			Result.extend_point (create {EV_COORDINATE}.make_precise (991.24999999999955, 180.99999999999977))
			Result.extend_point (create {EV_COORDINATE}.make_precise (984.36111111111063, 183.33333333333314))
			Result.extend_point (create {EV_COORDINATE}.make_precise (983.91666666666629, 179.33333333333331))
			Result.extend_point (create {EV_COORDINATE}.make_precise (978.58333333333326, 180.222222222222))
			Result.extend_point (create {EV_COORDINATE}.make_precise (982.13888888888823, 185.99999999999977))
			Result.extend_point (create {EV_COORDINATE}.make_precise (977.24999999999966, 188.6666666666664))
			Result.extend_point (create {EV_COORDINATE}.make_precise (974.25, 192.99999999999977))
			Result.extend_point (create {EV_COORDINATE}.make_precise (972.36111111111063, 197.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (968.36111111111063, 197.55555555555532))
			Result.extend_point (create {EV_COORDINATE}.make_precise (966.58333333333303, 203.77777777777749))
			Result.extend_point (create {EV_COORDINATE}.make_precise (961.24999999999932, 212.99999999999977))
			Result.extend_point (create {EV_COORDINATE}.make_precise (959.47222222222183, 216.6666666666664))
			Result.extend_point (create {EV_COORDINATE}.make_precise (959.02777777777737, 220.222222222222))
			Result.extend_point (create {EV_COORDINATE}.make_precise (962.58333333333326, 220.6666666666664))
			Result.extend_point (create {EV_COORDINATE}.make_precise (965.25, 225))
			Result.extend_point (create {EV_COORDINATE}.make_precise (973.694444444444, 228.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (983.25, 235.99999999999977))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1001.25, 280))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1008.2499999999997, 283.99999999999977))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1010.2499999999997, 295))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1016.25, 293.99999999999977))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1022.2499999999997, 307.99999999999977))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1016.25, 314))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1022.2499999999997, 324.99999999999977))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1008.2499999999997, 326.99999999999977))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1000.2499999999995, 336))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1006.2499999999993, 337.99999999999966))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1017.25, 346.99999999999966))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1024.3611111111106, 344.66666666666629))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1030.583333333333, 348.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1021.694444444444, 348.22222222222183))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1023.9166666666666, 351.33333333333303))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1027.4722222222222, 355.33333333333303))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1022.1388888888888, 354.88888888888846))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1017.25, 359))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1009.2499999999997, 361.11111111111074))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1021.2499999999997, 359.33333333333303))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1021.2499999999997, 365.99999999999966))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1021.694444444444, 373.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1016.805555555555, 369.55555555555509))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1013.25, 372.99999999999966))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1015.0277777777774, 378))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1014.1388888888883, 381.99999999999966))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1010.583333333333, 382.44444444444412))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1013.25, 388.99999999999966))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1014.5833333333333, 394))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1010.583333333333, 392.22222222222183))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1007.0277777777774, 396.66666666666629))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1003.4722222222218, 398.44444444444412))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1003.9166666666663, 392.66666666666629))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1000.2499999999995, 400.99999999999966))
			Result.extend_point (create {EV_COORDINATE}.make_precise (996.36111111111063, 402.44444444444412))
			Result.extend_point (create {EV_COORDINATE}.make_precise (992.8055555555552, 409.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (991.24999999999955, 415.99999999999966))
			Result.extend_point (create {EV_COORDINATE}.make_precise (980.25, 427.99999999999966))
			Result.extend_point (create {EV_COORDINATE}.make_precise (978.58333333333326, 435.33333333333303))
			Result.extend_point (create {EV_COORDINATE}.make_precise (974.1388888888888, 437.11111111111063))
			Result.extend_point (create {EV_COORDINATE}.make_precise (976.36111111111063, 432.66666666666629))
			Result.extend_point (create {EV_COORDINATE}.make_precise (971.91666666666629, 433.11111111111063))
			Result.extend_point (create {EV_COORDINATE}.make_precise (968.36111111111063, 432.66666666666629))
			Result.extend_point (create {EV_COORDINATE}.make_precise (968.8055555555552, 436.22222222222183))
			Result.extend_point (create {EV_COORDINATE}.make_precise (972.36111111111063, 439.77777777777737))
			Result.extend_point (create {EV_COORDINATE}.make_precise (974.1388888888888, 443.33333333333303))
			Result.extend_point (create {EV_COORDINATE}.make_precise (969.24999999999966, 445.5555555555552))
			Result.extend_point (create {EV_COORDINATE}.make_precise (967.47222222222217, 451.33333333333303))
			Result.extend_point (create {EV_COORDINATE}.make_precise (969.694444444444, 452.66666666666629))
			Result.extend_point (create {EV_COORDINATE}.make_precise (967.91666666666629, 456.22222222222183))
			Result.extend_point (create {EV_COORDINATE}.make_precise (967.91666666666629, 459.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (964.80555555555497, 460.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (971.02777777777737, 461.11111111111063))
			Result.extend_point (create {EV_COORDINATE}.make_precise (972.8055555555552, 464.22222222222183))
			Result.extend_point (create {EV_COORDINATE}.make_precise (968.8055555555552, 467.77777777777737))
			Result.extend_point (create {EV_COORDINATE}.make_precise (965.25, 468.66666666666629))
			Result.extend_point (create {EV_COORDINATE}.make_precise (963.02777777777737, 464.66666666666629))
			Result.extend_point (create {EV_COORDINATE}.make_precise (957.25, 466))
			Result.extend_point (create {EV_COORDINATE}.make_precise (960.8055555555552, 470.88888888888846))
			Result.extend_point (create {EV_COORDINATE}.make_precise (955.47222222222217, 471.77777777777737))
			Result.extend_point (create {EV_COORDINATE}.make_precise (953.25, 477))
			Result.extend_point (create {EV_COORDINATE}.make_precise (950.58333333333326, 481.11111111111063))
			Result.extend_point (create {EV_COORDINATE}.make_precise (944.8055555555552, 481.11111111111063))
			Result.extend_point (create {EV_COORDINATE}.make_precise (948.36111111111063, 483.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (944.36111111111063, 488.66666666666629))
			Result.extend_point (create {EV_COORDINATE}.make_precise (941.694444444444, 486.444444444444))
			Result.extend_point (create {EV_COORDINATE}.make_precise (942.13888888888835, 491.77777777777737))
			Result.extend_point (create {EV_COORDINATE}.make_precise (936.8055555555552, 490.444444444444))
			Result.extend_point (create {EV_COORDINATE}.make_precise (935.47222222222183, 486.88888888888846))
			Result.extend_point (create {EV_COORDINATE}.make_precise (930.58333333333303, 490.444444444444))
			Result.extend_point (create {EV_COORDINATE}.make_precise (934.13888888888846, 494.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (930.13888888888835, 497.11111111111063))
			Result.extend_point (create {EV_COORDINATE}.make_precise (928.36111111111063, 502.88888888888846))
			Result.extend_point (create {EV_COORDINATE}.make_precise (924.8055555555552, 500.66666666666629))
			Result.extend_point (create {EV_COORDINATE}.make_precise (923.02777777777737, 505.99999999999966))
			Result.extend_point (create {EV_COORDINATE}.make_precise (919.91666666666629, 505.11111111111063))
			Result.extend_point (create {EV_COORDINATE}.make_precise (917.694444444444, 511.77777777777737))
			Result.extend_point (create {EV_COORDINATE}.make_precise (915.02777777777737, 509.5555555555552))
			Result.extend_point (create {EV_COORDINATE}.make_precise (908.36111111111063, 513.11111111111063))
			Result.extend_point (create {EV_COORDINATE}.make_precise (903.02777777777737, 518.444444444444))
			Result.extend_point (create {EV_COORDINATE}.make_precise (898.58333333333326, 523.77777777777737))
			Result.extend_point (create {EV_COORDINATE}.make_precise (896.36111111111063, 527.77777777777737))
			Result.extend_point (create {EV_COORDINATE}.make_precise (891.91666666666663, 527.77777777777737))
			Result.extend_point (create {EV_COORDINATE}.make_precise (879.47222222222217, 531.77777777777737))
			Result.extend_point (create {EV_COORDINATE}.make_precise (874.25, 529.99999999999955))
			Result.extend_point (create {EV_COORDINATE}.make_precise (875.91666666666629, 535.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (869.694444444444, 534))
			Result.extend_point (create {EV_COORDINATE}.make_precise (867.02777777777737, 531.33333333333303))
			Result.extend_point (create {EV_COORDINATE}.make_precise (862.13888888888846, 534))
			Result.extend_point (create {EV_COORDINATE}.make_precise (859.02777777777737, 538))
			Result.extend_point (create {EV_COORDINATE}.make_precise (856.36111111111063, 532.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (853.694444444444, 533.11111111111063))
			Result.extend_point (create {EV_COORDINATE}.make_precise (852.24999999999966, 537))
			Result.extend_point (create {EV_COORDINATE}.make_precise (846.13888888888846, 537.11111111111063))
			Result.extend_point (create {EV_COORDINATE}.make_precise (847.47222222222217, 542.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (844.8055555555552, 546.444444444444))
			Result.extend_point (create {EV_COORDINATE}.make_precise (840.24999999999966, 547))
			Result.extend_point (create {EV_COORDINATE}.make_precise (838.58333333333303, 541.99999999999966))
			Result.extend_point (create {EV_COORDINATE}.make_precise (835.02777777777737, 537.11111111111063))
			Result.extend_point (create {EV_COORDINATE}.make_precise (832.24999999999966, 532))
			Result.extend_point (create {EV_COORDINATE}.make_precise (831.91666666666663, 543.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (828.25, 550.99999999999955))
			Result.extend_point (create {EV_COORDINATE}.make_precise (823.47222222222217, 550))
			Result.extend_point (create {EV_COORDINATE}.make_precise (823.02777777777737, 553.99999999999966))
			Result.extend_point (create {EV_COORDINATE}.make_precise (819.47222222222183, 546.88888888888846))
			Result.extend_point (create {EV_COORDINATE}.make_precise (817.69444444444412, 551.33333333333303))
			Result.extend_point (create {EV_COORDINATE}.make_precise (815.02777777777737, 554.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (812.36111111111074, 551.33333333333303))
			Result.extend_point (create {EV_COORDINATE}.make_precise (808.8055555555552, 557.11111111111063))
			Result.extend_point (create {EV_COORDINATE}.make_precise (803.91666666666629, 555.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (794.58333333333303, 556.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (795.02777777777737, 559.77777777777737))
			Result.extend_point (create {EV_COORDINATE}.make_precise (789.69444444444412, 562.444444444444))
			Result.extend_point (create {EV_COORDINATE}.make_precise (788.36111111111109, 556.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (787.47222222222183, 562.88888888888846))
			Result.extend_point (create {EV_COORDINATE}.make_precise (778.58333333333303, 564.66666666666629))
			Result.extend_point (create {EV_COORDINATE}.make_precise (765.25, 565.99999999999955))
			Result.extend_point (create {EV_COORDINATE}.make_precise (762.13888888888846, 573.5555555555552))
			Result.extend_point (create {EV_COORDINATE}.make_precise (763.91666666666629, 578.444444444444))
			Result.extend_point (create {EV_COORDINATE}.make_precise (756.8055555555552, 575.33333333333303))
			Result.extend_point (create {EV_COORDINATE}.make_precise (759.02777777777737, 571.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (754.58333333333303, 574.444444444444))
			Result.extend_point (create {EV_COORDINATE}.make_precise (753.24999999999966, 578.88888888888846))
			Result.extend_point (create {EV_COORDINATE}.make_precise (757.25, 579.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (757.25, 581.5555555555552))
			Result.extend_point (create {EV_COORDINATE}.make_precise (758.58333333333303, 584.66666666666629))
			Result.extend_point (create {EV_COORDINATE}.make_precise (761.24999999999966, 586.99999999999955))
			Result.extend_point (create {EV_COORDINATE}.make_precise (756.25, 594))
			Result.extend_point (create {EV_COORDINATE}.make_precise (746.24999999999966, 592.99999999999955))
			Result.extend_point (create {EV_COORDINATE}.make_precise (746.13888888888846, 587.77777777777737))
			Result.extend_point (create {EV_COORDINATE}.make_precise (740.25, 583))
			Result.extend_point (create {EV_COORDINATE}.make_precise (743.02777777777749, 580.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (740.25, 574))
			Result.extend_point (create {EV_COORDINATE}.make_precise (743.9166666666664, 568.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (746.13888888888846, 564.66666666666629))
			Result.extend_point (create {EV_COORDINATE}.make_precise (741.25, 564))
			Result.extend_point (create {EV_COORDINATE}.make_precise (728.36111111111109, 565.5555555555552))
			Result.extend_point (create {EV_COORDINATE}.make_precise (729.25, 561.11111111111063))
			Result.extend_point (create {EV_COORDINATE}.make_precise (718.24999999999977, 559.99999999999955))
			Result.extend_point (create {EV_COORDINATE}.make_precise (716.80555555555532, 553.5555555555552))
			Result.extend_point (create {EV_COORDINATE}.make_precise (715.9166666666664, 561.11111111111063))
			Result.extend_point (create {EV_COORDINATE}.make_precise (697.24999999999977, 564))
			Result.extend_point (create {EV_COORDINATE}.make_precise (695.9166666666664, 568.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (690.13888888888869, 569.11111111111063))
			Result.extend_point (create {EV_COORDINATE}.make_precise (694.58333333333303, 570.88888888888835))
			Result.extend_point (create {EV_COORDINATE}.make_precise (693.24999999999977, 574))
			Result.extend_point (create {EV_COORDINATE}.make_precise (683.02777777777749, 577.11111111111063))
			Result.extend_point (create {EV_COORDINATE}.make_precise (678.13888888888869, 579.77777777777737))
			Result.extend_point (create {EV_COORDINATE}.make_precise (675.02777777777749, 583.33333333333303))
			Result.extend_point (create {EV_COORDINATE}.make_precise (675.25, 592))
			Result.extend_point (create {EV_COORDINATE}.make_precise (660.25, 598.99999999999932))
			Result.extend_point (create {EV_COORDINATE}.make_precise (653.24999999999977, 608.66666666666629))
			Result.extend_point (create {EV_COORDINATE}.make_precise (650.58333333333303, 624.66666666666629))
			Result.extend_point (create {EV_COORDINATE}.make_precise (655.47222222222217, 635.77777777777737))
			Result.extend_point (create {EV_COORDINATE}.make_precise (666.24999999999977, 643.99999999999955))
			Result.extend_point (create {EV_COORDINATE}.make_precise (668.24999999999977, 655.99999999999955))
			Result.extend_point (create {EV_COORDINATE}.make_precise (682.25, 670.99999999999955))
			Result.extend_point (create {EV_COORDINATE}.make_precise (687.25, 678.99999999999955))
			Result.extend_point (create {EV_COORDINATE}.make_precise (704.25, 691.99999999999932))
			Result.extend_point (create {EV_COORDINATE}.make_precise (714.13888888888846, 704.22222222222172))
			Result.extend_point (create {EV_COORDINATE}.make_precise (730.25, 741))
			Result.extend_point (create {EV_COORDINATE}.make_precise (729.25, 793.55555555555497))
			Result.extend_point (create {EV_COORDINATE}.make_precise (620.80555555555543, 818.59259259259238))
			Result.extend_point (create {EV_COORDINATE}.make_precise (584.06481481481478, 788.07407407407391))
			Result.extend_point (create {EV_COORDINATE}.make_precise (576.36111111111109, 786.29629629629608))
			Result.extend_point (create {EV_COORDINATE}.make_precise (576.65740740740739, 790.74074074074042))
			Result.extend_point (create {EV_COORDINATE}.make_precise (573.99074074074065, 791.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (574.25, 784.99999999999955))
			Result.extend_point (create {EV_COORDINATE}.make_precise (566.58333333333314, 777.99999999999955))
			Result.extend_point (create {EV_COORDINATE}.make_precise (559.25, 774.99999999999955))
			Result.extend_point (create {EV_COORDINATE}.make_precise (548.36111111111086, 774))
			Result.extend_point (create {EV_COORDINATE}.make_precise (540.24999999999977, 776))
			Result.extend_point (create {EV_COORDINATE}.make_precise (543.0277777777776, 756.22222222222172))
			Result.extend_point (create {EV_COORDINATE}.make_precise (536.80555555555532, 754.44444444444434))
			Result.extend_point (create {EV_COORDINATE}.make_precise (527.91666666666663, 754.44444444444434))
			Result.extend_point (create {EV_COORDINATE}.make_precise (521.25, 758.99999999999955))
			Result.extend_point (create {EV_COORDINATE}.make_precise (523.02777777777749, 766))
			Result.extend_point (create {EV_COORDINATE}.make_precise (520.80555555555532, 774))
			Result.extend_point (create {EV_COORDINATE}.make_precise (519.91666666666663, 784.66666666666606))
			Result.extend_point (create {EV_COORDINATE}.make_precise (518.13888888888869, 790.88888888888823))
			Result.extend_point (create {EV_COORDINATE}.make_precise (515.47222222222194, 795.77777777777737))
			Result.extend_point (create {EV_COORDINATE}.make_precise (511.472222222222, 804.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (510.58333333333309, 813.55555555555475))
			Result.extend_point (create {EV_COORDINATE}.make_precise (509.24999999999983, 817.55555555555475))
			Result.extend_point (create {EV_COORDINATE}.make_precise (504.80555555555532, 822.88888888888823))
			Result.extend_point (create {EV_COORDINATE}.make_precise (502.13888888888869, 839.33333333333235))
			Result.extend_point (create {EV_COORDINATE}.make_precise (502.58333333333331, 845.99999999999955))
			Result.extend_point (create {EV_COORDINATE}.make_precise (506.13888888888869, 849.55555555555497))
			Result.extend_point (create {EV_COORDINATE}.make_precise (504.36111111111092, 851.7777777777776))
			Result.extend_point (create {EV_COORDINATE}.make_precise (506.58333333333314, 854.88888888888823))
			Result.extend_point (create {EV_COORDINATE}.make_precise (511.472222222222, 853.11111111111063))
			Result.extend_point (create {EV_COORDINATE}.make_precise (515.47222222222194, 851.7777777777776))
			Result.extend_point (create {EV_COORDINATE}.make_precise (519.02777777777749, 853.55555555555497))
			Result.extend_point (create {EV_COORDINATE}.make_precise (520.36111111111109, 862))
			Result.extend_point (create {EV_COORDINATE}.make_precise (521.25, 868.22222222222172))
			Result.extend_point (create {EV_COORDINATE}.make_precise (524.80555555555532, 873.55555555555475))
			Result.extend_point (create {EV_COORDINATE}.make_precise (527.02777777777749, 872.22222222222172))
			Result.extend_point (create {EV_COORDINATE}.make_precise (527.91666666666663, 878))
			Result.extend_point (create {EV_COORDINATE}.make_precise (531.02777777777749, 890.44444444444434))
			Result.extend_point (create {EV_COORDINATE}.make_precise (534.58333333333314, 900.22222222222172))
			Result.extend_point (create {EV_COORDINATE}.make_precise (543.91666666666663, 907.77777777777737))
			Result.extend_point (create {EV_COORDINATE}.make_precise (551.02777777777749, 908.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (556.36111111111109, 907.77777777777737))
			Result.extend_point (create {EV_COORDINATE}.make_precise (561.24999999999977, 916.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (570.13888888888869, 922.88888888888823))
			Result.extend_point (create {EV_COORDINATE}.make_precise (564.80555555555532, 930.44444444444389))
			Result.extend_point (create {EV_COORDINATE}.make_precise (563.02777777777749, 934.88888888888823))
			Result.extend_point (create {EV_COORDINATE}.make_precise (557.24999999999977, 930.44444444444389))
			Result.extend_point (create {EV_COORDINATE}.make_precise (551.91666666666652, 931.77777777777692))
			Result.extend_point (create {EV_COORDINATE}.make_precise (547.0277777777776, 928.66666666666606))
			Result.extend_point (create {EV_COORDINATE}.make_precise (546.58333333333303, 923.7777777777776))
			Result.extend_point (create {EV_COORDINATE}.make_precise (542.13888888888869, 922.44444444444366))
			Result.extend_point (create {EV_COORDINATE}.make_precise (538.13888888888869, 916.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (532.80555555555532, 916.66666666666606))
			Result.extend_point (create {EV_COORDINATE}.make_precise (527.02777777777749, 911.77777777777737))
			Result.extend_point (create {EV_COORDINATE}.make_precise (524.36111111111086, 918.44444444444434))
			Result.extend_point (create {EV_COORDINATE}.make_precise (519.91666666666663, 911.77777777777737))
			Result.extend_point (create {EV_COORDINATE}.make_precise (515.02777777777749, 909.11111111111063))
			Result.extend_point (create {EV_COORDINATE}.make_precise (514.58333333333326, 904.66666666666606))
			Result.extend_point (create {EV_COORDINATE}.make_precise (510.58333333333309, 898))
			Result.extend_point (create {EV_COORDINATE}.make_precise (507.91666666666652, 899.33333333333258))
			Result.extend_point (create {EV_COORDINATE}.make_precise (505.6944444444444, 890.44444444444434))
			Result.extend_point (create {EV_COORDINATE}.make_precise (506.13888888888869, 886.44444444444434))
			Result.extend_point (create {EV_COORDINATE}.make_precise (503.0277777777776, 890.44444444444434))
			Result.extend_point (create {EV_COORDINATE}.make_precise (500.80555555555532, 894.88888888888823))
			Result.extend_point (create {EV_COORDINATE}.make_precise (499.472222222222, 885.55555555555475))
			Result.extend_point (create {EV_COORDINATE}.make_precise (497.25, 882.44444444444434))
			Result.extend_point (create {EV_COORDINATE}.make_precise (492.80555555555532, 881.55555555555475))
			Result.extend_point (create {EV_COORDINATE}.make_precise (489.6944444444444, 875.77777777777737))
			Result.extend_point (create {EV_COORDINATE}.make_precise (491.02777777777749, 869.55555555555475))
			Result.extend_point (create {EV_COORDINATE}.make_precise (486.13888888888869, 875.77777777777737))
			Result.extend_point (create {EV_COORDINATE}.make_precise (486.58333333333303, 879.7777777777776))
			Result.extend_point (create {EV_COORDINATE}.make_precise (486.58333333333303, 884.22222222222172))
			Result.extend_point (create {EV_COORDINATE}.make_precise (483.91666666666652, 886.88888888888823))
			Result.extend_point (create {EV_COORDINATE}.make_precise (482.13888888888869, 879.7777777777776))
			Result.extend_point (create {EV_COORDINATE}.make_precise (480.80555555555532, 869.11111111111063))
			Result.extend_point (create {EV_COORDINATE}.make_precise (481.24999999999983, 856.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (484.80555555555532, 851.7777777777776))
			Result.extend_point (create {EV_COORDINATE}.make_precise (488.36111111111109, 837.55555555555497))
			Result.extend_point (create {EV_COORDINATE}.make_precise (487.472222222222, 831.3333333333328))
			Result.extend_point (create {EV_COORDINATE}.make_precise (487.472222222222, 827.33333333333258))
			Result.extend_point (create {EV_COORDINATE}.make_precise (486.13888888888869, 820.22222222222172))
			Result.extend_point (create {EV_COORDINATE}.make_precise (489.6944444444444, 816.22222222222172))
			Result.extend_point (create {EV_COORDINATE}.make_precise (491.91666666666663, 815.33333333333235))
			Result.extend_point (create {EV_COORDINATE}.make_precise (491.02777777777749, 809.55555555555475))
			Result.extend_point (create {EV_COORDINATE}.make_precise (492.80555555555532, 807.77777777777737))
			Result.extend_point (create {EV_COORDINATE}.make_precise (492.80555555555532, 802.88888888888823))
			Result.extend_point (create {EV_COORDINATE}.make_precise (492.36111111111109, 796.66666666666606))
			Result.extend_point (create {EV_COORDINATE}.make_precise (489.24999999999983, 796.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (489.24999999999983, 794))
			Result.extend_point (create {EV_COORDINATE}.make_precise (487.0277777777776, 794))
			Result.extend_point (create {EV_COORDINATE}.make_precise (485.69444444444423, 788.66666666666606))
			Result.extend_point (create {EV_COORDINATE}.make_precise (487.91666666666652, 790.44444444444389))
			Result.extend_point (create {EV_COORDINATE}.make_precise (491.472222222222, 790.44444444444389))
			Result.extend_point (create {EV_COORDINATE}.make_precise (488.36111111111109, 785.11111111111063))
			Result.extend_point (create {EV_COORDINATE}.make_precise (487.472222222222, 781.99999999999955))
			Result.extend_point (create {EV_COORDINATE}.make_precise (483.472222222222, 782.88888888888823))
			Result.extend_point (create {EV_COORDINATE}.make_precise (483.02777777777749, 778.44444444444434))
			Result.extend_point (create {EV_COORDINATE}.make_precise (483.472222222222, 774))
			Result.extend_point (create {EV_COORDINATE}.make_precise (485.69444444444423, 776.66666666666606))
			Result.extend_point (create {EV_COORDINATE}.make_precise (488.36111111111109, 778.88888888888823))
			Result.extend_point (create {EV_COORDINATE}.make_precise (490.13888888888869, 775.77777777777737))
			Result.extend_point (create {EV_COORDINATE}.make_precise (491.02777777777749, 772.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (489.24999999999983, 762.88888888888823))
			Result.extend_point (create {EV_COORDINATE}.make_precise (485.25, 755.33333333333258))
			Result.extend_point (create {EV_COORDINATE}.make_precise (482.13888888888869, 750.444444444444))
			Result.extend_point (create {EV_COORDINATE}.make_precise (480.36111111111109, 754.88888888888823))
			Result.extend_point (create {EV_COORDINATE}.make_precise (478.13888888888869, 750.444444444444))
			Result.extend_point (create {EV_COORDINATE}.make_precise (478.58333333333331, 742.88888888888835))
			Result.extend_point (create {EV_COORDINATE}.make_precise (477.69444444444423, 738.444444444444))
			Result.extend_point (create {EV_COORDINATE}.make_precise (475.47222222222206, 733.55555555555497))
			Result.extend_point (create {EV_COORDINATE}.make_precise (472.80555555555554, 725.11111111111063))
			Result.extend_point (create {EV_COORDINATE}.make_precise (470.58333333333314, 713.55555555555497))
			Result.extend_point (create {EV_COORDINATE}.make_precise (469.25, 706.88888888888835))
			Result.extend_point (create {EV_COORDINATE}.make_precise (469.25, 700.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (467.0277777777776, 697.55555555555497))
			Result.extend_point (create {EV_COORDINATE}.make_precise (465.25, 690.88888888888835))
			Result.extend_point (create {EV_COORDINATE}.make_precise (461.25, 684.22222222222172))
			Result.extend_point (create {EV_COORDINATE}.make_precise (459.0277777777776, 680.22222222222172))
			Result.extend_point (create {EV_COORDINATE}.make_precise (456.36111111111109, 672.66666666666606))
			Result.extend_point (create {EV_COORDINATE}.make_precise (456.80555555555537, 669.99999999999955))
			Result.extend_point (create {EV_COORDINATE}.make_precise (453.69444444444423, 672.66666666666606))
			Result.extend_point (create {EV_COORDINATE}.make_precise (450.58333333333309, 671.3333333333328))
			Result.extend_point (create {EV_COORDINATE}.make_precise (450.58333333333309, 673.99999999999955))
			Result.extend_point (create {EV_COORDINATE}.make_precise (448.36111111111109, 674.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (448.36111111111109, 678.88888888888835))
			Result.extend_point (create {EV_COORDINATE}.make_precise (444.36111111111109, 682.88888888888835))
			Result.extend_point (create {EV_COORDINATE}.make_precise (439.91666666666652, 684.22222222222172))
			Result.extend_point (create {EV_COORDINATE}.make_precise (436.36111111111092, 678.444444444444))
			Result.extend_point (create {EV_COORDINATE}.make_precise (439.02777777777766, 685.99999999999955))
			Result.extend_point (create {EV_COORDINATE}.make_precise (432.80555555555554, 687.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (431.91666666666652, 690.444444444444))
			Result.extend_point (create {EV_COORDINATE}.make_precise (426.13888888888869, 691.77777777777737))
			Result.extend_point (create {EV_COORDINATE}.make_precise (424.80555555555554, 694.44444444444355))
			Result.extend_point (create {EV_COORDINATE}.make_precise (419.91666666666652, 700.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (416.36111111111097, 701.55555555555497))
			Result.extend_point (create {EV_COORDINATE}.make_precise (412.80555555555543, 701.55555555555497))
			Result.extend_point (create {EV_COORDINATE}.make_precise (410.58333333333331, 698.444444444444))
			Result.extend_point (create {EV_COORDINATE}.make_precise (411.02777777777766, 692.66666666666606))
			Result.extend_point (create {EV_COORDINATE}.make_precise (408.36111111111097, 701.55555555555497))
			Result.extend_point (create {EV_COORDINATE}.make_precise (404.36111111111097, 702))
			Result.extend_point (create {EV_COORDINATE}.make_precise (400.36111111111109, 700.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (397.6944444444444, 696.66666666666606))
			Result.extend_point (create {EV_COORDINATE}.make_precise (395.02777777777766, 698.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (393.69444444444434, 696.66666666666606))
			Result.extend_point (create {EV_COORDINATE}.make_precise (399.91666666666652, 690.444444444444))
			Result.extend_point (create {EV_COORDINATE}.make_precise (400.36111111111109, 683.7777777777776))
			Result.extend_point (create {EV_COORDINATE}.make_precise (398.13888888888869, 688.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (390.13888888888874, 697.99999999999955))
			Result.extend_point (create {EV_COORDINATE}.make_precise (389.69444444444434, 690.444444444444))
			Result.extend_point (create {EV_COORDINATE}.make_precise (393.69444444444434, 678.88888888888835))
			Result.extend_point (create {EV_COORDINATE}.make_precise (396.80555555555554, 662.44444444444434))
			Result.extend_point (create {EV_COORDINATE}.make_precise (394.58333333333331, 644.22222222222172))
			Result.extend_point (create {EV_COORDINATE}.make_precise (387.02777777777766, 629.55555555555497))
			Result.extend_point (create {EV_COORDINATE}.make_precise (386.13888888888874, 620.66666666666606))
			Result.extend_point (create {EV_COORDINATE}.make_precise (383.91666666666652, 622.44444444444366))
			Result.extend_point (create {EV_COORDINATE}.make_precise (383.47222222222206, 627.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (379.02777777777771, 625.55555555555486))
			Result.extend_point (create {EV_COORDINATE}.make_precise (375.91666666666652, 620.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (373.24999999999989, 614.444444444444))
			Result.extend_point (create {EV_COORDINATE}.make_precise (374.58333333333331, 613.11111111111063))
			Result.extend_point (create {EV_COORDINATE}.make_precise (378.13888888888874, 615.33333333333303))
			Result.extend_point (create {EV_COORDINATE}.make_precise (380.80555555555543, 618.444444444444))
			Result.extend_point (create {EV_COORDINATE}.make_precise (381.24999999999989, 615.33333333333303))
			Result.extend_point (create {EV_COORDINATE}.make_precise (377.69444444444434, 610.44444444444366))
			Result.extend_point (create {EV_COORDINATE}.make_precise (378.58333333333314, 604.22222222222183))
			Result.extend_point (create {EV_COORDINATE}.make_precise (373.24999999999989, 601.55555555555486))
			Result.extend_point (create {EV_COORDINATE}.make_precise (375.47222222222206, 606))
			Result.extend_point (create {EV_COORDINATE}.make_precise (371.91666666666652, 606))
			Result.extend_point (create {EV_COORDINATE}.make_precise (369.25, 599.77777777777737))
			Result.extend_point (create {EV_COORDINATE}.make_precise (365.69444444444434, 600.66666666666617))
			Result.extend_point (create {EV_COORDINATE}.make_precise (360.80555555555543, 597.99999999999966))
			Result.extend_point (create {EV_COORDINATE}.make_precise (362.58333333333326, 593.11111111111063))
			Result.extend_point (create {EV_COORDINATE}.make_precise (359.47222222222206, 597.11111111111063))
			Result.extend_point (create {EV_COORDINATE}.make_precise (356.80555555555543, 595.77777777777737))
			Result.extend_point (create {EV_COORDINATE}.make_precise (356.80555555555543, 586.44444444444366))
			Result.extend_point (create {EV_COORDINATE}.make_precise (355.02777777777766, 594))
			Result.extend_point (create {EV_COORDINATE}.make_precise (351.47222222222211, 586.88888888888846))
			Result.extend_point (create {EV_COORDINATE}.make_precise (345.69444444444434, 579.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (338.13888888888874, 569.11111111111063))
			Result.extend_point (create {EV_COORDINATE}.make_precise (335.91666666666657, 554.444444444444))
			Result.extend_point (create {EV_COORDINATE}.make_precise (337.24999999999989, 552.22222222222183))
			Result.extend_point (create {EV_COORDINATE}.make_precise (333.24999999999989, 542.444444444444))
			Result.extend_point (create {EV_COORDINATE}.make_precise (331.47222222222217, 536.22222222222183))
			Result.extend_point (create {EV_COORDINATE}.make_precise (326.58333333333326, 533.11111111111063))
			Result.extend_point (create {EV_COORDINATE}.make_precise (327.02777777777766, 536.66666666666606))
			Result.extend_point (create {EV_COORDINATE}.make_precise (329.69444444444434, 540.22222222222183))
			Result.extend_point (create {EV_COORDINATE}.make_precise (328.36111111111097, 542.444444444444))
			Result.extend_point (create {EV_COORDINATE}.make_precise (325.24999999999989, 538.44444444444366))
			Result.extend_point (create {EV_COORDINATE}.make_precise (322.13888888888874, 539.77777777777737))
			Result.extend_point (create {EV_COORDINATE}.make_precise (320.36111111111097, 542.444444444444))
			Result.extend_point (create {EV_COORDINATE}.make_precise (320.80555555555543, 546))
			Result.extend_point (create {EV_COORDINATE}.make_precise (316.36111111111097, 550))
			Result.extend_point (create {EV_COORDINATE}.make_precise (316.36111111111097, 543.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (315.91666666666657, 535.77777777777737))
			Result.extend_point (create {EV_COORDINATE}.make_precise (309.24999999999989, 525.11111111111063))
			Result.extend_point (create {EV_COORDINATE}.make_precise (307.47222222222211, 516.22222222222183))
			Result.extend_point (create {EV_COORDINATE}.make_precise (306.1388888888888, 517.99999999999955))
			Result.extend_point (create {EV_COORDINATE}.make_precise (307.02777777777777, 526.44444444444366))
			Result.extend_point (create {EV_COORDINATE}.make_precise (310.13888888888874, 528.22222222222149))
			Result.extend_point (create {EV_COORDINATE}.make_precise (311.02777777777766, 532.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (313.24999999999989, 538.88888888888846))
			Result.extend_point (create {EV_COORDINATE}.make_precise (312.80555555555554, 545.11111111111063))
			Result.extend_point (create {EV_COORDINATE}.make_precise (309.69444444444434, 550.44444444444366))
			Result.extend_point (create {EV_COORDINATE}.make_precise (304.36111111111103, 554.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (297.25, 555.77777777777737))
			Result.extend_point (create {EV_COORDINATE}.make_precise (294.1388888888888, 552.66666666666617))
			Result.extend_point (create {EV_COORDINATE}.make_precise (291.02777777777777, 549.5555555555552))
			Result.extend_point (create {EV_COORDINATE}.make_precise (290.58333333333326, 555.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (283.91666666666663, 558.444444444444))
			Result.extend_point (create {EV_COORDINATE}.make_precise (278.58333333333326, 557.11111111111063))
			Result.extend_point (create {EV_COORDINATE}.make_precise (278.58333333333326, 559.77777777777737))
			Result.extend_point (create {EV_COORDINATE}.make_precise (273.25, 559.77777777777737))
			Result.extend_point (create {EV_COORDINATE}.make_precise (270.1388888888888, 557.11111111111063))
			Result.extend_point (create {EV_COORDINATE}.make_precise (269.24999999999994, 561.11111111111063))
			Result.extend_point (create {EV_COORDINATE}.make_precise (266.1388888888888, 561.99999999999966))
			Result.extend_point (create {EV_COORDINATE}.make_precise (264.80555555555549, 555.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (263.02777777777771, 563.33333333333303))
			Result.extend_point (create {EV_COORDINATE}.make_precise (259.47222222222217, 562.44444444444366))
			Result.extend_point (create {EV_COORDINATE}.make_precise (260.80555555555543, 556.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (257.69444444444434, 561.99999999999966))
			Result.extend_point (create {EV_COORDINATE}.make_precise (255.02777777777771, 561.99999999999966))
			Result.extend_point (create {EV_COORDINATE}.make_precise (254.58333333333326, 557.11111111111063))
			Result.extend_point (create {EV_COORDINATE}.make_precise (251.02777777777777, 560.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (248.80555555555546, 559.77777777777737))
			Result.extend_point (create {EV_COORDINATE}.make_precise (251.02777777777777, 553.11111111111063))
			Result.extend_point (create {EV_COORDINATE}.make_precise (254.58333333333326, 547.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (252.36111111111103, 546.88888888888835))
			Result.extend_point (create {EV_COORDINATE}.make_precise (247.91666666666663, 553.99999999999932))
			Result.extend_point (create {EV_COORDINATE}.make_precise (244.80555555555549, 559.33333333333303))
			Result.extend_point (create {EV_COORDINATE}.make_precise (236.80555555555546, 560.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (231.47222222222217, 561.99999999999966))
			Result.extend_point (create {EV_COORDINATE}.make_precise (224.36111111111106, 565.99999999999955))
			Result.extend_point (create {EV_COORDINATE}.make_precise (222.58333333333331, 573.5555555555552))
			Result.extend_point (create {EV_COORDINATE}.make_precise (223.47222222222217, 581.11111111111063))
			Result.extend_point (create {EV_COORDINATE}.make_precise (227.47222222222217, 581.55555555555497))
			Result.extend_point (create {EV_COORDINATE}.make_precise (223.02777777777777, 585.5555555555552))
			Result.extend_point (create {EV_COORDINATE}.make_precise (220.80555555555551, 589.99999999999955))
			Result.extend_point (create {EV_COORDINATE}.make_precise (225.24999999999994, 587.77777777777737))
			Result.extend_point (create {EV_COORDINATE}.make_precise (219.9166666666666, 592.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (214.13888888888889, 598.88888888888846))
			Result.extend_point (create {EV_COORDINATE}.make_precise (205.6944444444444, 603.33333333333303))
			Result.extend_point (create {EV_COORDINATE}.make_precise (190.13888888888886, 609.55555555555497))
			Result.extend_point (create {EV_COORDINATE}.make_precise (175.02777777777777, 621.99999999999966))
				-- Modified from grabber points to stay within boarder
--			Result.extend_point (create {EV_COORDINATE}.make_precise (157.25, 643.3333333333328))
--			Result.extend_point (create {EV_COORDINATE}.make_precise (146.58333333333331, 652.22222222222172))
--			Result.extend_point (create {EV_COORDINATE}.make_precise (137.69444444444446, 658.44444444444366))
				-- new modified point (at bottom left of Asia
			Result.extend_point (create {EV_COORDINATE}.make_precise (162, 650))
		end

	hainan_imp: EV_MODEL_POLYGON
			-- Make the polygon
		do
			create Result
				-- Points generated by Grabber application
			Result.extend_point (create {EV_COORDINATE}.make_precise (763.02777777777737, 601.11111111111063))
			Result.extend_point (create {EV_COORDINATE}.make_precise (760.8055555555552, 598.88888888888846))
			Result.extend_point (create {EV_COORDINATE}.make_precise (764.8055555555552, 596.66666666666606))
			Result.extend_point (create {EV_COORDINATE}.make_precise (767.47222222222217, 599.77777777777737))
			Result.extend_point (create {EV_COORDINATE}.make_precise (770.5833333333328, 599.77777777777737))
			Result.extend_point (create {EV_COORDINATE}.make_precise (771.47222222222217, 608.66666666666606))
			Result.extend_point (create {EV_COORDINATE}.make_precise (765.25, 615.33333333333303))
			Result.extend_point (create {EV_COORDINATE}.make_precise (763.91666666666617, 618.88888888888835))
			Result.extend_point (create {EV_COORDINATE}.make_precise (763.02777777777737, 625.11111111111063))
			Result.extend_point (create {EV_COORDINATE}.make_precise (759.91666666666663, 628.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (761.69444444444412, 630.444444444444))
			Result.extend_point (create {EV_COORDINATE}.make_precise (759.02777777777737, 631.77777777777737))
			Result.extend_point (create {EV_COORDINATE}.make_precise (756.36111111111074, 631.77777777777737))
			Result.extend_point (create {EV_COORDINATE}.make_precise (751.02777777777737, 634.88888888888823))
			Result.extend_point (create {EV_COORDINATE}.make_precise (751.47222222222217, 638.444444444444))
			Result.extend_point (create {EV_COORDINATE}.make_precise (749.25, 639.77777777777737))
			Result.extend_point (create {EV_COORDINATE}.make_precise (746.58333333333303, 637.99999999999932))
			Result.extend_point (create {EV_COORDINATE}.make_precise (742.58333333333303, 640.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (743.9166666666664, 642.444444444444))
			Result.extend_point (create {EV_COORDINATE}.make_precise (738.13888888888846, 643.77777777777737))
			Result.extend_point (create {EV_COORDINATE}.make_precise (735.9166666666664, 641.99999999999955))
			Result.extend_point (create {EV_COORDINATE}.make_precise (731.02777777777737, 641.99999999999955))
			Result.extend_point (create {EV_COORDINATE}.make_precise (724.80555555555532, 639.33333333333303))
			Result.extend_point (create {EV_COORDINATE}.make_precise (721.69444444444412, 637.11111111111063))
			Result.extend_point (create {EV_COORDINATE}.make_precise (719.02777777777715, 636.66666666666617))
			Result.extend_point (create {EV_COORDINATE}.make_precise (718.58333333333303, 631.77777777777737))
			Result.extend_point (create {EV_COORDINATE}.make_precise (717.69444444444412, 627.77777777777737))
			Result.extend_point (create {EV_COORDINATE}.make_precise (718.13888888888869, 620.66666666666606))
			Result.extend_point (create {EV_COORDINATE}.make_precise (718.13888888888869, 616.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (724.36111111111086, 611.77777777777737))
			Result.extend_point (create {EV_COORDINATE}.make_precise (729.69444444444412, 607.77777777777737))
			Result.extend_point (create {EV_COORDINATE}.make_precise (729.25, 605.11111111111063))
			Result.extend_point (create {EV_COORDINATE}.make_precise (732.80555555555532, 603.77777777777737))
			Result.extend_point (create {EV_COORDINATE}.make_precise (737.24999999999977, 604.22222222222183))
			Result.extend_point (create {EV_COORDINATE}.make_precise (738.13888888888846, 600.22222222222149))
			Result.extend_point (create {EV_COORDINATE}.make_precise (741.25, 600.22222222222149))
			Result.extend_point (create {EV_COORDINATE}.make_precise (744.8055555555552, 600.66666666666617))
			Result.extend_point (create {EV_COORDINATE}.make_precise (749.69444444444412, 600.66666666666617))
			Result.extend_point (create {EV_COORDINATE}.make_precise (753.24999999999966, 598.88888888888846))
			Result.extend_point (create {EV_COORDINATE}.make_precise (757.25, 597.5555555555552))
		end

	taiwan_imp: EV_MODEL_POLYGON
			-- Make the polygon
		do
			create Result
				-- Points generated by Grabber application
			Result.extend_point (create {EV_COORDINATE}.make_precise (1009.2499999999995, 473.99999999999966))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1009.694444444444, 469.99999999999966))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1012.8055555555549, 469.11111111111063))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1015.0277777777774, 472.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1019.0277777777774, 473.99999999999966))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1023.0277777777774, 477.11111111111063))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1020.3611111111106, 478.88888888888846))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1017.6944444444437, 483.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1019.4722222222218, 488.22222222222183))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1019.4722222222218, 494.444444444444))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1014.1388888888883, 499.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1013.25, 501.55555555555497))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1012.8055555555549, 512.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1009.694444444444, 520.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1007.4722222222215, 527.33333333333303))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1000.805555555555, 533.55555555555497))
			Result.extend_point (create {EV_COORDINATE}.make_precise (998.1388888888888, 539.77777777777737))
			Result.extend_point (create {EV_COORDINATE}.make_precise (997.694444444444, 544.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (997.694444444444, 550.44444444444366))
			Result.extend_point (create {EV_COORDINATE}.make_precise (995.47222222222149, 553.11111111111063))
			Result.extend_point (create {EV_COORDINATE}.make_precise (993.25, 553.11111111111063))
			Result.extend_point (create {EV_COORDINATE}.make_precise (992.36111111111063, 550))
			Result.extend_point (create {EV_COORDINATE}.make_precise (992.36111111111063, 547.33333333333326))
			Result.extend_point (create {EV_COORDINATE}.make_precise (989.694444444444, 542.444444444444))
			Result.extend_point (create {EV_COORDINATE}.make_precise (987.02777777777737, 540.22222222222183))
			Result.extend_point (create {EV_COORDINATE}.make_precise (983.02777777777737, 538.88888888888846))
			Result.extend_point (create {EV_COORDINATE}.make_precise (980.8055555555552, 528.66666666666617))
			Result.extend_point (create {EV_COORDINATE}.make_precise (978.13888888888823, 524.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (979.47222222222183, 518.444444444444))
			Result.extend_point (create {EV_COORDINATE}.make_precise (980.36111111111063, 506.444444444444))
			Result.extend_point (create {EV_COORDINATE}.make_precise (983.02777777777737, 505.99999999999955))
			Result.extend_point (create {EV_COORDINATE}.make_precise (985.694444444444, 498))
			Result.extend_point (create {EV_COORDINATE}.make_precise (990.58333333333303, 491.77777777777737))
			Result.extend_point (create {EV_COORDINATE}.make_precise (991.91666666666606, 487.33333333333303))
			Result.extend_point (create {EV_COORDINATE}.make_precise (994.58333333333269, 484.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (998.1388888888888, 478.444444444444))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1003.0277777777774, 474.88888888888835))
		end

feature {NONE} -- Implmenetation (Kamchatka polygons)

	kamchatsky_imp: EV_MODEL_POLYGON
			-- Make the polygon
		do
			create Result
				-- Points modified after grabber to fit in boarder
--			Result.extend_point (create {EV_COORDINATE}.make_precise (-150, -200))
				-- Points generated by Grabber application
--			Result.extend_point (create {EV_COORDINATE}.make_precise (0, 0))
--			Result.extend_point (create {EV_COORDINATE}.make_precise (-6.6666666666667425, -48))
--			Result.extend_point (create {EV_COORDINATE}.make_precise (-13.333333333333712, -83.333333333333329))
--			Result.extend_point (create {EV_COORDINATE}.make_precise (355.33333333333326, -132))
				-- modified point
			Result.extend_point (create {EV_COORDINATE}.make_precise (-10, 20))
--			Result.extend_point (create {EV_COORDINATE}.make_precise (355.33333333333326, -10))

--			Result.extend_point (create {EV_COORDINATE}.make_precise (353.33333333333326, -120))
--			Result.extend_point (create {EV_COORDINATE}.make_precise (348, -106.66666666666666))
--			Result.extend_point (create {EV_COORDINATE}.make_precise (343.33333333333326, -93.333333333333329))
--			Result.extend_point (create {EV_COORDINATE}.make_precise (342.66666666666652, -74.666666666666657))
--			Result.extend_point (create {EV_COORDINATE}.make_precise (345.33333333333326, -65.333333333333329))
--			Result.extend_point (create {EV_COORDINATE}.make_precise (348.66666666666652, -68))
--			Result.extend_point (create {EV_COORDINATE}.make_precise (347.33333333333326, -59.333333333333329))
			Result.extend_point (create {EV_COORDINATE}.make_precise (353.33333333333326, -52))
			Result.extend_point (create {EV_COORDINATE}.make_precise (352.66666666666652, -34.666666666666657))
			Result.extend_point (create {EV_COORDINATE}.make_precise (346.66666666666652, -36.666666666666657))
			Result.extend_point (create {EV_COORDINATE}.make_precise (342, -40))
			Result.extend_point (create {EV_COORDINATE}.make_precise (342.66666666666652, -34))
			Result.extend_point (create {EV_COORDINATE}.make_precise (342.66666666666652, -24))
			Result.extend_point (create {EV_COORDINATE}.make_precise (344.66666666666652, -22))
			Result.extend_point (create {EV_COORDINATE}.make_precise (349.33333333333326, -22.666666666666657))
			Result.extend_point (create {EV_COORDINATE}.make_precise (350, -18.666666666666657))
			Result.extend_point (create {EV_COORDINATE}.make_precise (346.66666666666652, -12))
			Result.extend_point (create {EV_COORDINATE}.make_precise (354, -14))
			Result.extend_point (create {EV_COORDINATE}.make_precise (352.66666666666652, -8.6666666666666572))
			Result.extend_point (create {EV_COORDINATE}.make_precise (348, -2.6666666666666572))
			Result.extend_point (create {EV_COORDINATE}.make_precise (351.33333333333326, 4))
			Result.extend_point (create {EV_COORDINATE}.make_precise (353.33333333333326, -0.66666666666665719))
			Result.extend_point (create {EV_COORDINATE}.make_precise (358, -2.6666666666666572))
			Result.extend_point (create {EV_COORDINATE}.make_precise (356.66666666666652, 4))
			Result.extend_point (create {EV_COORDINATE}.make_precise (361.33333333333326, 4))
			Result.extend_point (create {EV_COORDINATE}.make_precise (360.66666666666652, 10.666666666666657))
			Result.extend_point (create {EV_COORDINATE}.make_precise (361.33333333333326, 16.666666666666657))
			Result.extend_point (create {EV_COORDINATE}.make_precise (358.66666666666652, 23.333333333333343))
			Result.extend_point (create {EV_COORDINATE}.make_precise (350.66666666666652, 18))
			Result.extend_point (create {EV_COORDINATE}.make_precise (333.33333333333326, 7.3333333333333428))
			Result.extend_point (create {EV_COORDINATE}.make_precise (336.66666666666652, 0.66666666666665719))
			Result.extend_point (create {EV_COORDINATE}.make_precise (341.33333333333326, -4))
			Result.extend_point (create {EV_COORDINATE}.make_precise (338, -4))
			Result.extend_point (create {EV_COORDINATE}.make_precise (330.66666666666652, 4))
			Result.extend_point (create {EV_COORDINATE}.make_precise (326, 1.3333333333333428))
			Result.extend_point (create {EV_COORDINATE}.make_precise (323.33333333333326, -1.3333333333333428))
			Result.extend_point (create {EV_COORDINATE}.make_precise (315.33333333333326, 0.66666666666665719))
			Result.extend_point (create {EV_COORDINATE}.make_precise (308.66666666666652, 4))
			Result.extend_point (create {EV_COORDINATE}.make_precise (301.33333333333326, 14))
			Result.extend_point (create {EV_COORDINATE}.make_precise (297.33333333333326, 12))
			Result.extend_point (create {EV_COORDINATE}.make_precise (290.66666666666652, 12))
			Result.extend_point (create {EV_COORDINATE}.make_precise (278, 18))
			Result.extend_point (create {EV_COORDINATE}.make_precise (263.33333333333326, 28))
			Result.extend_point (create {EV_COORDINATE}.make_precise (255.33333333333326, 34.666666666666657))
			Result.extend_point (create {EV_COORDINATE}.make_precise (244.66666666666652, 47.333333333333343))
			Result.extend_point (create {EV_COORDINATE}.make_precise (241.33333333333326, 44.666666666666657))
			Result.extend_point (create {EV_COORDINATE}.make_precise (244, 50.666666666666657))
			Result.extend_point (create {EV_COORDINATE}.make_precise (239.33333333333326, 53.333333333333343))
			Result.extend_point (create {EV_COORDINATE}.make_precise (237.33333333333326, 46.666666666666657))
			Result.extend_point (create {EV_COORDINATE}.make_precise (234.66666666666652, 45.333333333333343))
			Result.extend_point (create {EV_COORDINATE}.make_precise (234.66666666666652, 40))
			Result.extend_point (create {EV_COORDINATE}.make_precise (232.66666666666652, 31.333333333333343))
			Result.extend_point (create {EV_COORDINATE}.make_precise (228.66666666666652, 29.333333333333343))
			Result.extend_point (create {EV_COORDINATE}.make_precise (224.66666666666652, 28.666666666666657))
			Result.extend_point (create {EV_COORDINATE}.make_precise (222.66666666666652, 25.333333333333343))
			Result.extend_point (create {EV_COORDINATE}.make_precise (222.66666666666652, 30))
			Result.extend_point (create {EV_COORDINATE}.make_precise (212.66666666666652, 34.666666666666657))
			Result.extend_point (create {EV_COORDINATE}.make_precise (213.33333333333326, 38.666666666666657))
			Result.extend_point (create {EV_COORDINATE}.make_precise (217.33333333333326, 40))
			Result.extend_point (create {EV_COORDINATE}.make_precise (216.66666666666652, 43.333333333333343))
			Result.extend_point (create {EV_COORDINATE}.make_precise (213.33333333333326, 44.666666666666657))
			Result.extend_point (create {EV_COORDINATE}.make_precise (214.66666666666652, 50.666666666666657))
			Result.extend_point (create {EV_COORDINATE}.make_precise (222, 52.666666666666657))
			Result.extend_point (create {EV_COORDINATE}.make_precise (222, 49.333333333333343))
			Result.extend_point (create {EV_COORDINATE}.make_precise (226.66666666666652, 49.333333333333343))
			Result.extend_point (create {EV_COORDINATE}.make_precise (231.33333333333326, 49.333333333333343))
			Result.extend_point (create {EV_COORDINATE}.make_precise (230.66666666666652, 56.666666666666657))
			Result.extend_point (create {EV_COORDINATE}.make_precise (233.33333333333326, 60))
			Result.extend_point (create {EV_COORDINATE}.make_precise (227.33333333333326, 63.333333333333343))
			Result.extend_point (create {EV_COORDINATE}.make_precise (226.66666666666652, 70.666666666666657))
			Result.extend_point (create {EV_COORDINATE}.make_precise (222.66666666666652, 68.666666666666657))
			Result.extend_point (create {EV_COORDINATE}.make_precise (219.33333333333326, 72))
			Result.extend_point (create {EV_COORDINATE}.make_precise (219.33333333333326, 76))
			Result.extend_point (create {EV_COORDINATE}.make_precise (224.66666666666652, 76.666666666666657))
			Result.extend_point (create {EV_COORDINATE}.make_precise (228, 81.333333333333343))
			Result.extend_point (create {EV_COORDINATE}.make_precise (228, 88.666666666666657))
			Result.extend_point (create {EV_COORDINATE}.make_precise (225.33333333333326, 92.666666666666657))
			Result.extend_point (create {EV_COORDINATE}.make_precise (219.33333333333326, 94.666666666666657))
			Result.extend_point (create {EV_COORDINATE}.make_precise (218, 91.333333333333343))
			Result.extend_point (create {EV_COORDINATE}.make_precise (211.33333333333326, 88.666666666666657))
			Result.extend_point (create {EV_COORDINATE}.make_precise (214, 94.666666666666657))
			Result.extend_point (create {EV_COORDINATE}.make_precise (217.33333333333326, 101.99999999999991))
			Result.extend_point (create {EV_COORDINATE}.make_precise (220.66666666666652, 101.33333333333334))
			Result.extend_point (create {EV_COORDINATE}.make_precise (223.33333333333326, 108.66666666666666))
			Result.extend_point (create {EV_COORDINATE}.make_precise (219.33333333333326, 111.33333333333334))
			Result.extend_point (create {EV_COORDINATE}.make_precise (222, 115.99999999999991))
			Result.extend_point (create {EV_COORDINATE}.make_precise (220.66666666666652, 118.66666666666666))
			Result.extend_point (create {EV_COORDINATE}.make_precise (216.66666666666652, 118.66666666666666))
			Result.extend_point (create {EV_COORDINATE}.make_precise (216.66666666666652, 123.33333333333334))
			Result.extend_point (create {EV_COORDINATE}.make_precise (212.66666666666652, 127.33333333333334))
			Result.extend_point (create {EV_COORDINATE}.make_precise (221.33333333333326, 122.66666666666666))
			Result.extend_point (create {EV_COORDINATE}.make_precise (225.33333333333326, 130.66666666666666))
			Result.extend_point (create {EV_COORDINATE}.make_precise (220, 134.66666666666666))
			Result.extend_point (create {EV_COORDINATE}.make_precise (220, 137.99999999999991))
			Result.extend_point (create {EV_COORDINATE}.make_precise (225.33333333333326, 135.99999999999991))
			Result.extend_point (create {EV_COORDINATE}.make_precise (226, 142.66666666666666))
			Result.extend_point (create {EV_COORDINATE}.make_precise (219.33333333333326, 146.66666666666666))
			Result.extend_point (create {EV_COORDINATE}.make_precise (214.66666666666652, 145.33333333333334))
			Result.extend_point (create {EV_COORDINATE}.make_precise (214.66666666666652, 149.99999999999991))
			Result.extend_point (create {EV_COORDINATE}.make_precise (210.66666666666652, 155.33333333333334))
			Result.extend_point (create {EV_COORDINATE}.make_precise (212, 159.99999999999991))
			Result.extend_point (create {EV_COORDINATE}.make_precise (208.66666666666652, 167.99999999999991))
			Result.extend_point (create {EV_COORDINATE}.make_precise (205.33333333333326, 163.99999999999991))
			Result.extend_point (create {EV_COORDINATE}.make_precise (201.33333333333326, 169.33333333333334))
			Result.extend_point (create {EV_COORDINATE}.make_precise (204, 176.66666666666666))
			Result.extend_point (create {EV_COORDINATE}.make_precise (200, 181.33333333333334))
			Result.extend_point (create {EV_COORDINATE}.make_precise (201.33333333333326, 191.33333333333334))
			Result.extend_point (create {EV_COORDINATE}.make_precise (194, 197.99999999999997))
			Result.extend_point (create {EV_COORDINATE}.make_precise (189.33333333333326, 205.99999999999997))
			Result.extend_point (create {EV_COORDINATE}.make_precise (184, 213.99999999999997))
			Result.extend_point (create {EV_COORDINATE}.make_precise (178, 215.99999999999997))
			Result.extend_point (create {EV_COORDINATE}.make_precise (173.33333333333326, 225.33333333333334))
			Result.extend_point (create {EV_COORDINATE}.make_precise (168.66666666666652, 235.33333333333334))
			Result.extend_point (create {EV_COORDINATE}.make_precise (166.66666666666652, 240.66666666666666))
			Result.extend_point (create {EV_COORDINATE}.make_precise (162.66666666666652, 240.66666666666666))
			Result.extend_point (create {EV_COORDINATE}.make_precise (159.33333333333326, 245.99999999999997))
			Result.extend_point (create {EV_COORDINATE}.make_precise (156, 245.33333333333334))
			Result.extend_point (create {EV_COORDINATE}.make_precise (154.66666666666652, 250.66666666666666))
			Result.extend_point (create {EV_COORDINATE}.make_precise (146, 251.33333333333334))
			Result.extend_point (create {EV_COORDINATE}.make_precise (143.33333333333326, 253.99999999999997))
			Result.extend_point (create {EV_COORDINATE}.make_precise (139.33333333333326, 253.33333333333334))
			Result.extend_point (create {EV_COORDINATE}.make_precise (137.33333333333326, 255.99999999999997))
			Result.extend_point (create {EV_COORDINATE}.make_precise (132.66666666666652, 262.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (129.33333333333326, 268))
			Result.extend_point (create {EV_COORDINATE}.make_precise (126.66666666666652, 276))
			Result.extend_point (create {EV_COORDINATE}.make_precise (127.33333333333326, 281.33333333333337))
			Result.extend_point (create {EV_COORDINATE}.make_precise (118.66666666666652, 281.33333333333337))
			Result.extend_point (create {EV_COORDINATE}.make_precise (114, 287.33333333333337))
			Result.extend_point (create {EV_COORDINATE}.make_precise (104.66666666666652, 302.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (100, 303.33333333333337))
			Result.extend_point (create {EV_COORDINATE}.make_precise (92, 308.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (90.666666666666515, 314))
			Result.extend_point (create {EV_COORDINATE}.make_precise (79.333333333333258, 324.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (74.666666666666515, 328))
			Result.extend_point (create {EV_COORDINATE}.make_precise (69.333333333333258, 331.33333333333337))
			Result.extend_point (create {EV_COORDINATE}.make_precise (62, 342.66666666666652))
			Result.extend_point (create {EV_COORDINATE}.make_precise (53.333333333333258, 350.66666666666652))
			Result.extend_point (create {EV_COORDINATE}.make_precise (51.333333333333258, 348))
			Result.extend_point (create {EV_COORDINATE}.make_precise (60.666666666666515, 336))
			Result.extend_point (create {EV_COORDINATE}.make_precise (61.333333333333258, 323.33333333333337))
			Result.extend_point (create {EV_COORDINATE}.make_precise (60.666666666666515, 319.33333333333337))
			Result.extend_point (create {EV_COORDINATE}.make_precise (57.333333333333258, 320.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (58, 309.33333333333337))
			Result.extend_point (create {EV_COORDINATE}.make_precise (56.666666666666515, 302.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (51.333333333333258, 295.33333333333337))
			Result.extend_point (create {EV_COORDINATE}.make_precise (46, 295.33333333333337))
			Result.extend_point (create {EV_COORDINATE}.make_precise (43.333333333333258, 291.33333333333337))
			Result.extend_point (create {EV_COORDINATE}.make_precise (41.333333333333258, 284.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (39.333333333333258, 271.33333333333337))
			Result.extend_point (create {EV_COORDINATE}.make_precise (36, 252.66666666666666))
			Result.extend_point (create {EV_COORDINATE}.make_precise (37.333333333333258, 235.99999999999997))
			Result.extend_point (create {EV_COORDINATE}.make_precise (36.666666666666515, 221.33333333333334))
			Result.extend_point (create {EV_COORDINATE}.make_precise (34.666666666666515, 194.66666666666666))
			Result.extend_point (create {EV_COORDINATE}.make_precise (36, 171.33333333333334))
			Result.extend_point (create {EV_COORDINATE}.make_precise (31.333333333333258, 148.66666666666666))
			Result.extend_point (create {EV_COORDINATE}.make_precise (26, 123.33333333333334))
			Result.extend_point (create {EV_COORDINATE}.make_precise (16.666666666666288, 100.66666666666666))
			Result.extend_point (create {EV_COORDINATE}.make_precise (13.333333333333258, 89.333333333333343))
			Result.extend_point (create {EV_COORDINATE}.make_precise (6.6666666666662877, 70.666666666666657))
			Result.extend_point (create {EV_COORDINATE}.make_precise (2.6666666666662877, 38.666666666666657))
		end

	shumshu_imp: EV_MODEL_POLYGON
			-- Make the polygon
		do
			create Result
				-- Points generated by Grabber application
			Result.extend_point (create {EV_COORDINATE}.make_precise (37.333333333333258, 350.66666666666652))
			Result.extend_point (create {EV_COORDINATE}.make_precise (40, 365.33333333333337))
			Result.extend_point (create {EV_COORDINATE}.make_precise (34, 376))
			Result.extend_point (create {EV_COORDINATE}.make_precise (30.666666666666515, 378))
			Result.extend_point (create {EV_COORDINATE}.make_precise (30.666666666666515, 384))
			Result.extend_point (create {EV_COORDINATE}.make_precise (22.666666666666515, 384.66666666666652))
			Result.extend_point (create {EV_COORDINATE}.make_precise (18.666666666666288, 384.66666666666652))
			Result.extend_point (create {EV_COORDINATE}.make_precise (13.333333333333258, 379.33333333333337))
			Result.extend_point (create {EV_COORDINATE}.make_precise (8.6666666666662877, 378))
			Result.extend_point (create {EV_COORDINATE}.make_precise (8, 373.33333333333337))
			Result.extend_point (create {EV_COORDINATE}.make_precise (10, 364))
			Result.extend_point (create {EV_COORDINATE}.make_precise (14, 363.33333333333337))
			Result.extend_point (create {EV_COORDINATE}.make_precise (24.666666666666515, 353.33333333333337))
		end

	paramushir_imp: EV_MODEL_POLYGON
			-- Make the polygon
		do
			create Result
				-- Points generated by Grabber application
			Result.extend_point (create {EV_COORDINATE}.make_precise (-4.6666666666667425, 364.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (2, 366.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (5.1111111111108585, 366))
			Result.extend_point (create {EV_COORDINATE}.make_precise (6, 370.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (4.2222222222221717, 377.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (4.6666666666662877, 383.33333333333337))
			Result.extend_point (create {EV_COORDINATE}.make_precise (6.8888888888886868, 386.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (7.7777777777776009, 391.33333333333337))
			Result.extend_point (create {EV_COORDINATE}.make_precise (5.5555555555552019, 392.66666666666652))
			Result.extend_point (create {EV_COORDINATE}.make_precise (7.7777777777776009, 401.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (5.1111111111108585, 405.11111111111097))
			Result.extend_point (create {EV_COORDINATE}.make_precise (1.5555555555552019, 404.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-2.8888888888891415, 406.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-6.4444444444447981, 412.66666666666652))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-4.6666666666667425, 417.11111111111097))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-6.8888888888891415, 419.33333333333337))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-9.5555555555556566, 422))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-10, 426.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-13.111111111111313, 430))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-14.888888888889142, 434.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-18, 440.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-22, 440.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-28.222222222222399, 449.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-31.777777777777828, 447.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-43.333333333333712, 449.11111111111097))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-47.333333333333712, 453.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-49.555555555555657, 453.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-54.444444444444798, 457.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-57.555555555555657, 465.11111111111097))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-62.444444444444798, 475.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-63.333333333333712, 470.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-66.888888888889142, 466.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-71.777777777777828, 466.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-78, 467.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-80.222222222222399, 462.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-77.555555555555657, 461.11111111111097))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-74.888888888889142, 454.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-74.888888888889142, 447.33333333333337))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-75.333333333333712, 442.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-78, 442))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-79.777777777777828, 437.11111111111097))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-78.888888888889142, 431.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-76.666666666666742, 430.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-72.666666666666742, 430.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-68.666666666666742, 433.11111111111097))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-66, 433.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-63.333333333333712, 429.11111111111097))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-59.777777777777828, 422.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-53.111111111111313, 423.33333333333337))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-48.666666666666742, 422))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-46.444444444444798, 419.33333333333337))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-42.888888888889142, 421.11111111111097))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-36.222222222222399, 418))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-30, 406))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-27.333333333333712, 401.11111111111097))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-24.222222222222399, 397.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-23.777777777777828, 390.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-21.555555555555657, 387.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-21.111111111111313, 382.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-18.444444444444798, 378.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-14.888888888889142, 372.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-9.5555555555556566, 367.33333333333337))
		end

	atlasov_imp: EV_MODEL_POLYGON
			-- Make the polygon
		do
			create Result
				-- Points generated by Grabber application
			Result.extend_point (create {EV_COORDINATE}.make_precise (-55.777777777777828, 343.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-45.555555555555657, 342.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-42.888888888889142, 345.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-41.555555555555657, 343.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-38.444444444444798, 346))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-36.222222222222399, 350))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-37.555555555555657, 351.33333333333337))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-36.222222222222399, 354.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-38.888888888889142, 358.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-42.444444444444798, 360.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-46.444444444444798, 359.33333333333337))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-49.555555555555657, 359.33333333333337))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-53.555555555555657, 355.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-56.222222222222399, 349.11111111111097))
		end

	onekotan_imp: EV_MODEL_POLYGON
			-- Make the polygon
		do
			create Result
				-- Points generated by Grabber application
			Result.extend_point (create {EV_COORDINATE}.make_precise (-114.88888888888914, 527.33333333333337))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-111.77777777777783, 526))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-111.33333333333371, 528.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-105.55555555555566, 529.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-107.77777777777783, 530.88888888888869))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-106.88888888888914, 536.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-108.2222222222224, 539.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-112.66666666666674, 542.88888888888869))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-114, 548.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-115.77777777777783, 550))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-116.2222222222224, 557.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-112.66666666666674, 561.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-112.66666666666674, 569.11111111111097))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-114.88888888888914, 573.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-118.4444444444448, 574.88888888888869))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-122.88888888888914, 578))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-126.88888888888914, 577.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-130.4444444444448, 577.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-133.55555555555566, 574))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-133.11111111111131, 564.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-129.55555555555566, 556.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-125.55555555555566, 550.44444444444434))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-125.55555555555566, 548.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-122, 542))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-119.77777777777783, 536.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-119.33333333333371, 532.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-115.77777777777783, 530.88888888888869))
		end

	makanrushi_imp: EV_MODEL_POLYGON
			-- Make the polygon
		do
			create Result
				-- Points generated by Grabber application
			Result.extend_point (create {EV_COORDINATE}.make_precise (-155.33333333333371, 510))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-153.11111111111131, 508.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-154.88888888888914, 506))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-152.2222222222224, 501.11111111111097))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-147.77777777777783, 499.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-145.55555555555566, 503.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-146.88888888888914, 506.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-146.4444444444448, 509.11111111111097))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-148.2222222222224, 510.88888888888869))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-152.66666666666674, 511.33333333333337))
		end

	kharimkotan_imp: EV_MODEL_POLYGON
			-- Make the polygon
		do
			create Result
				-- Points generated by Grabber application
			Result.extend_point (create {EV_COORDINATE}.make_precise (-147.77777777777783, 590.88888888888869))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-146, 593.11111111111097))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-142.88888888888914, 592.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-138.88888888888914, 592.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-137.11111111111131, 595.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-134.4444444444448, 596.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-134.4444444444448, 600.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-137.55555555555566, 604.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-139.77777777777783, 603.33333333333337))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-142, 605.11111111111097))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-145.11111111111131, 602))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-146.88888888888914, 597.55555555555554))
		end

	shiashkotan_imp: EV_MODEL_POLYGON
			-- Make the polygon
		do
			create Result
				-- Points generated by Grabber application
			Result.extend_point (create {EV_COORDINATE}.make_precise (-180.66666666666674, 630.88888888888869))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-178, 630))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-176.66666666666674, 627.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-173.55555555555566, 627.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-170.88888888888914, 630.44444444444434))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-168.66666666666674, 631.33333333333337))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-170, 632.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-170.4444444444448, 636.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-174, 637.11111111111097))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-174, 641.11111111111097))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-178.4444444444448, 642))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-181.55555555555566, 643.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-183.33333333333371, 647.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-183.33333333333371, 650.88888888888869))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-186.88888888888914, 652.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-190.4444444444448, 652.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-191.33333333333371, 649.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-190.88888888888914, 645.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-187.77777777777783, 644.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-185.55555555555566, 645.11111111111097))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-181.55555555555566, 640.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-182, 636.22222222222217))
		end

	ekarma_imp: EV_MODEL_POLYGON
			-- Make the polygon
		do
			create Result
				-- Points generated by Grabber application
			Result.extend_point (create {EV_COORDINATE}.make_precise (-195.77777777777783, 618.44444444444434))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-194, 620.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-190, 619.33333333333337))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-188.66666666666674, 623.33333333333337))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-191.77777777777783, 626))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-197.11111111111131, 626))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-197.11111111111131, 623.33333333333337))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-198.88888888888914, 620.22222222222217))
		end

	matua_imp: EV_MODEL_POLYGON
			-- Make the polygon
		do
			create Result
				-- Points generated by Grabber application
			Result.extend_point (create {EV_COORDINATE}.make_precise (-263.33333333333371, 734.88888888888869))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-258.88888888888914, 739.33333333333337))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-254, 741.11111111111097))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-256.2222222222224, 742))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-255.77777777777783, 748.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-258, 746))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-260.66666666666674, 747.33333333333337))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-262, 745.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-265.11111111111131, 743.33333333333337))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-266.4444444444448, 736.22222222222217))
		end

	rasshua_imp: EV_MODEL_POLYGON
			-- Make the polygon
		do
			create Result
				-- Points generated by Grabber application
			Result.extend_point (create {EV_COORDINATE}.make_precise (-277.11111111111131, 777.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-274, 781.11111111111097))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-273.11111111111131, 785.11111111111097))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-274.88888888888914, 789.11111111111097))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-276.2222222222224, 791.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-279.77777777777783, 793.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-280.2222222222224, 795.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-283.33333333333371, 795.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-284.2222222222224, 789.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-282.4444444444448, 788.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-283.33333333333371, 784.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-280.2222222222224, 778.88888888888869))
		end

	ketoy_imp: EV_MODEL_POLYGON
			-- Make the polygon
		do
			create Result
				-- Points generated by Grabber application
			Result.extend_point (create {EV_COORDINATE}.make_precise (-333.55555555555566, 837.11111111111097))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-329.1111111111112, 834.88888888888869))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-328.66666666666674, 837.11111111111097))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-324.2222222222224, 836.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-322, 841.11111111111097))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-320.66666666666674, 843.33333333333337))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-322.88888888888903, 846.44444444444434))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-327.77777777777783, 847.33333333333337))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-332.2222222222224, 847.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-332.66666666666674, 845.11111111111097))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-334, 842.44444444444434))
		end

	simushir_imp: EV_MODEL_POLYGON
			-- Make the polygon
		do
			create Result
				-- Points generated by Grabber application
			Result.extend_point (create {EV_COORDINATE}.make_precise (-353.55555555555566, 863.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-349.1111111111112, 864.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-343.77777777777783, 866.44444444444423))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-345.1111111111112, 869.11111111111097))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-346.88888888888903, 872.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-351.33333333333337, 875.33333333333337))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-353.1111111111112, 875.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-355.33333333333337, 879.33333333333337))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-355.33333333333337, 885.11111111111097))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-356.2222222222224, 888.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-361.55555555555566, 889.99999999999966))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-362.88888888888903, 893.11111111111097))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-365.55555555555566, 896.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-368.2222222222224, 901.11111111111097))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-371.77777777777783, 902.88888888888857))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-374, 905.11111111111097))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-377.1111111111112, 905.11111111111097))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-381.1111111111112, 908.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-383.77777777777783, 913.99999999999966))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-386.44444444444468, 917.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-390.88888888888903, 918.44444444444423))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-392.2222222222224, 917.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-395.33333333333337, 916.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-396.2222222222224, 913.11111111111097))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-398, 907.33333333333337))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-395.77777777777783, 905.99999999999966))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-389.1111111111112, 904.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-386.88888888888903, 905.99999999999966))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-383.77777777777783, 904.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-383.33333333333337, 900.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-380.66666666666674, 899.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-380.66666666666674, 895.33333333333337))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-374.44444444444468, 892.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-371.77777777777783, 888.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-367.77777777777783, 887.33333333333337))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-364.2222222222224, 881.11111111111097))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-360.2222222222224, 873.99999999999966))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-356.2222222222224, 867.77777777777771))
		end

	sakhalin_imp: EV_MODEL_POLYGON
			-- Make the polygon
		do
			create Result

				-- Clockwise from north-east corner.
				-- Points modified from Grabber so fit inside boarder.
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1155, 270))
				-- Points generated by Grabber application
--			Result.extend_point (create {EV_COORDINATE}.make_precise (-1275, 263.33333333333337))
--			Result.extend_point (create {EV_COORDINATE}.make_precise (-1155, 243.33333333333334))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1148, 282.33333333333337))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1133, 338.33333333333337))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1129.5555555555557, 360.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1126.8888888888889, 377.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1127.7777777777778, 389.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1121.1111111111111, 421.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1108.6666666666667, 455.33333333333337))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1099.3333333333333, 471.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1101.1111111111111, 475.33333333333337))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1089.1111111111111, 507.33333333333337))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1086.8888888888889, 511.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1088.6666666666667, 513.11111111111097))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1088.6666666666667, 525.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1078, 543.33333333333337))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1079.7777777777778, 546))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1078.8888888888889, 555.33333333333337))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1077.5555555555557, 562.44444444444434))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1075.7777777777778, 569.11111111111097))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1067.3333333333335, 593.11111111111097))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1068.2222222222222, 594.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1063.7777777777778, 610))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1053.5555555555557, 618.44444444444434))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1049.5555555555557, 622.44444444444434))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1045.1111111111111, 625.11111111111097))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1037.1111111111111, 633.11111111111097))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1038.4444444444443, 636.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1037.1111111111111, 640.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1035.7777777777778, 644.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1036.2222222222222, 646.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1038, 649.11111111111097))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1036.6666666666667, 655.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1034, 660.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1030.4444444444443, 662.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1032.2222222222222, 664.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1034.8888888888889, 663.33333333333337))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1037.5555555555557, 663.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1038.4444444444443, 658.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1041.5555555555557, 654))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1040.2222222222222, 646.44444444444434))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1042.8888888888889, 643.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1043.7777777777778, 640.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1044.2222222222222, 638.44444444444434))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1046.4444444444443, 636.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1049.1111111111111, 630))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1051.3333333333335, 627.33333333333337))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1053.1111111111111, 623.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1055.3333333333335, 622.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1059.3333333333335, 616.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1062.8888888888889, 613.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1069.5555555555557, 610.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1071.3333333333335, 604.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1073.5555555555557, 605.11111111111097))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1078.4444444444443, 595.33333333333337))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1080.6666666666667, 594))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1084.2222222222222, 589.11111111111097))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1086.8888888888889, 585.11111111111097))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1091.7777777777778, 582))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1102, 578))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1112.6666666666667, 574.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1126.4444444444443, 572.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1123.3333333333333, 570.44444444444434))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1124.6666666666667, 568.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1137.1111111111111, 566.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1140.2222222222222, 564.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1145.1111111111111, 566.44444444444434))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1149.1111111111111, 564.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1153.1111111111111, 558.44444444444434))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1160.6666666666667, 558))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1162, 556.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1168.6666666666667, 560.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1165.5555555555557, 566.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1162.8888888888889, 565.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1160.6666666666667, 567.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1163.3333333333333, 569.11111111111097))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1159.3333333333333, 569.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1154, 570.44444444444434))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1151.7777777777778, 569.11111111111097))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1142, 569.11111111111097))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1142.8888888888889, 570.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1150.4444444444443, 571.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1160.6666666666667, 573.11111111111097))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1174, 579.33333333333337))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1187.7777777777778, 591.33333333333337))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1193.5555555555557, 598.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1196.6666666666667, 610.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1193.1111111111111, 617.11111111111097))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1192.2222222222222, 627.33333333333337))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1194, 633.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1205.1111111111111, 655.33333333333337))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1213.1111111111111, 679.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1217.5555555555557, 697.11111111111097))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1220.2222222222222, 703.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1220.2222222222222, 707.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1223.7777777777778, 714))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1226.8888888888889, 729.11111111111097))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1232.2222222222222, 750.44444444444434))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1232.2222222222222, 762.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1234, 767.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1232.6666666666667, 770))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1233.5555555555557, 774.44444444444434))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1231.7777777777778, 788.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1224.6666666666667, 808.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1216.6666666666667, 821.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1208.2222222222222, 831.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1206, 830.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1201.5555555555557, 836.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1198.8888888888889, 836.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1192.6666666666667, 845.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1190, 850.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1186.8888888888889, 863.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1186, 868.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1188.2222222222222, 874.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1181.5555555555557, 888.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1181.5555555555557, 897.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1175.3333333333333, 905.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1177.1111111111111, 909.11111111111097))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1183.3333333333333, 905.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1183.7777777777778, 911.33333333333337))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1178.8888888888889, 913.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1178.8888888888889, 920.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1176.2222222222222, 921.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1175.7777777777778, 925.11111111111097))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1170.4444444444443, 923.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1164.2222222222222, 924.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1160.6666666666667, 927.33333333333337))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1157.1111111111111, 926.44444444444423))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1156.2222222222222, 921.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1158.8888888888889, 919.33333333333337))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1162, 918.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1166.4444444444443, 916.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1174.4444444444443, 914.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1175.7777777777778, 912.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1173.5555555555557, 908.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1168.2222222222222, 911.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1161.5555555555557, 913.11111111111097))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1155.3333333333333, 913.11111111111097))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1152.6666666666667, 911.33333333333337))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1152.6666666666667, 908.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1150.8888888888889, 907.33333333333337))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1147.7777777777778, 910.44444444444423))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1145.1111111111111, 924.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1144.6666666666667, 940.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1141.1111111111111, 952.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1138, 966.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1134.8888888888889, 969.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1135.7777777777778, 972.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1138.4444444444443, 973.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1139.3333333333333, 976.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1138, 980.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1142, 981.11111111111097))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1145.1111111111111, 989.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1147.3333333333333, 993.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1149.5555555555557, 1000.6666666666666))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1148.2222222222222, 1004.2222222222221))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1148.6666666666667, 1008.2222222222221))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1151.3333333333333, 1009.9999999999999))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1151.3333333333333, 1014.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1153.5555555555557, 1016.2222222222221))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1155.7777777777778, 1007.3333333333334))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1154.4444444444443, 1003.3333333333334))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1153.1111111111111, 997.11111111111097))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1152.2222222222222, 988.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1155.7777777777778, 980.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1157.5555555555557, 974.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1159.7777777777778, 970.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1161.1111111111111, 962.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1160.6666666666667, 957.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1164.2222222222222, 952.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1172.2222222222222, 943.33333333333337))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1176.6666666666667, 940.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1181.5555555555557, 940.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1188.6666666666667, 941.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1191.7777777777778, 939.33333333333337))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1200.2222222222222, 936.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1203.3333333333333, 938.44444444444423))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1207.3333333333333, 940.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1210.4444444444443, 940.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1212.6666666666667, 936.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1215.3333333333333, 927.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1215.3333333333333, 922.44444444444423))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1219.7777777777778, 920.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1219.3333333333333, 922.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1227.3333333333333, 924.22222222222206))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1234.4444444444443, 928.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1239.3333333333333, 933.11111111111097))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1244.6666666666667, 945.11111111111097))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1247.7777777777778, 954.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1254, 971.33333333333337))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1258, 982.44444444444423))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1258.4444444444443, 993.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1261.1111111111111, 1001.5555555555555))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1263.3333333333333, 1005.5555555555555))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1263.7777777777778, 1013.5555555555555))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1266.4444444444443, 1017.111111111111))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1270.8888888888889, 1017.9999999999999))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1273.5555555555557, 1022.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1273.5555555555557, 1033.9999999999998))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1276.6666666666667, 1031.3333333333333))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1278.8888888888889, 1029.1111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1282, 1023.3333333333334))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1284.2222222222222, 1017.111111111111))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1290.4444444444443, 1012.6666666666666))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1288.2222222222222, 1011.7777777777777))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1288.6666666666667, 1001.5555555555555))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1291.3333333333333, 983.33333333333337))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1293.5555555555557, 969.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1298, 954.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1299.7777777777778, 947.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1299.7777777777778, 939.33333333333337))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1296.6666666666667, 939.33333333333337))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1296.2222222222222, 934.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1296.6666666666667, 926.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1294, 925.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1290.4444444444443, 915.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1287.3333333333333, 905.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1282.4444444444443, 893.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1278.8888888888889, 879.33333333333337))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1276.6666666666667, 865.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1278.8888888888889, 857.99999999999989))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1283.7777777777778, 849.11111111111097))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1285.5555555555557, 845.11111111111097))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1282.4444444444443, 838.44444444444434))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1284.6666666666667, 830))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1286, 816.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1286.4444444444443, 805.11111111111097))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1282.8888888888889, 798.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1282, 790))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1275.3333333333333, 775.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1274, 770.44444444444434))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1267.7777777777778, 761.11111111111097))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1264.2222222222222, 755.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1265.5555555555557, 751.33333333333337))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1267.3333333333333, 731.33333333333337))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1266.8888888888889, 720.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1268.2222222222222, 717.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1267.7777777777778, 711.33333333333337))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1271.3333333333333, 705.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1274.8888888888889, 694))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1284.6666666666667, 679.33333333333337))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1293.5555555555557, 662.44444444444434))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1295.3333333333333, 647.33333333333337))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1293.1111111111111, 639.33333333333337))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1289.1111111111111, 636.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1285.5555555555557, 630.44444444444434))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1286.8888888888889, 625.11111111111097))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1282, 622))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1282, 612.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1279.7777777777778, 609.11111111111097))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1280.6666666666667, 597.11111111111097))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1277.5555555555557, 590.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1274.4444444444443, 582.44444444444434))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1275.7777777777778, 579.33333333333337))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1275.7777777777778, 562))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1272.6666666666667, 555.33333333333337))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1270.4444444444443, 550))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1269.1111111111111, 526))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1268.2222222222222, 521.11111111111097))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1267.3333333333333, 502.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1269.1111111111111, 501.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1270.8888888888889, 488.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1268.2222222222222, 485.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1269.5555555555557, 481.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1268.2222222222222, 472.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1266.4444444444443, 461.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1268.6666666666667, 436.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1271.3333333333333, 431.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1268.2222222222222, 429.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1269.1111111111111, 421.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1274.4444444444443, 411.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1275.7777777777778, 403.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1277.5555555555557, 400.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1278.4444444444443, 389.11111111111109))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1275.7777777777778, 376.66666666666663))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1273.5555555555557, 370.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1273.5555555555557, 358.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1271.7777777777778, 350.8888888888888))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1272.2222222222222, 345.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1265.1111111111111, 339.77777777777771))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1260.6666666666667, 329.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1259.3333333333333, 318.44444444444446))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1258.4444444444443, 309.55555555555554))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1261.5555555555557, 304.22222222222217))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1265.1111111111111, 299.33333333333337))
			Result.extend_point (create {EV_COORDINATE}.make_precise (-1266.8888888888889, 291.33333333333337))
				-- Removed to fix land inside border
--			Result.extend_point (create {EV_COORDINATE}.make_precise (-1265.5555555555557, 288.22222222222217))
--			Result.extend_point (create {EV_COORDINATE}.make_precise (-1268.2222222222222, 283.33333333333337))
--			Result.extend_point (create {EV_COORDINATE}.make_precise (-1271.3333333333333, 280.22222222222217))
--			Result.extend_point (create {EV_COORDINATE}.make_precise (-1273.5555555555557, 272.66666666666663))
--			Result.extend_point (create {EV_COORDINATE}.make_precise (-1275.3333333333333, 268.22222222222217))
		end


invariant

	is_valid_sea_area: attached target_imp implies sea_area = game.japanese_islands

end
